<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/**
 * Portfolio custom post types & Portfolio meta options
 *
 * @package Infinito
 * @author WOW Layers
 * @link https://wowlayers.com
 */

function wow_cp_portfolio() {
  
  global $wow_options;
  
  //slug for portfolio item
  $slug_portfolio = ( !empty($wow_options['slug_portfolio']) ) ? $wow_options['slug_portfolio'] : 'portfolio_item';
  
  $labels = array(
    'name'               => esc_html__( 'Portfolio', 'infinito' ),
    'singular_name'      => esc_html__( 'Portfolio', 'infinito' ),
    'add_new'            => esc_html__( 'Add New', 'infinito' ),
    'add_new_item'       => esc_html__( 'Add New Portfolio', 'infinito' ),
    'edit_item'          => esc_html__( 'Edit Portfolio', 'infinito' ),
    'new_item'           => esc_html__( 'New Portfolio', 'infinito' ),
    'all_items'          => esc_html__( 'All Portfolio Items', 'infinito' ),
    'view_item'          => esc_html__( 'View Portfolio', 'infinito' ),
    'search_items'       => esc_html__( 'Search Portfolios', 'infinito' ),
    'not_found'          => esc_html__( 'No Portfolio found', 'infinito' ),
    'not_found_in_trash' => esc_html__( 'No Portfolio found in the Trash', 'infinito' ), 
    'parent_item_colon'  => '',
  );
  $args = array(
    'labels'        => $labels,
    'public'        => true,
	'show_in_nav_menus' => true,
	'hierarchical'  => false,
	'menu_position' => null,
	'has_archive' 	=> false,
    'menu_position' => 5,
	'rewrite' 				=> array( 
		'slug' 			=> $slug_portfolio, 
	),	
    'supports'      => array( 'author', 'comments', 'editor', 'excerpt', 'page-attributes', 'thumbnail', 'title' ),
  );
  register_post_type( 'portfolio', $args ); 
	  

}
add_action( 'init', 'wow_cp_portfolio', 0 );

function wow_portfolio_tax() {

  global $wow_options;
  
  //slug for portfolio category
  $slug_category  = ( !empty($wow_options['slug_category']) )  ? $wow_options['slug_category']  : 'portfolio_category';
	
  $labels = array(
    'name'              => esc_html__( 'Portfolio Categories','infinito' ),
    'singular_name'     => esc_html__( 'Portfolio Category', 'infinito' ),
    'search_items'      => esc_html__( 'Search Portfolio Categories', 'infinito' ),
    'all_items'         => esc_html__( 'All Portfolio Categories', 'infinito' ),
    'parent_item'       => esc_html__( 'Parent Portfolio Category', 'infinito' ),
    'parent_item_colon' => esc_html__( 'Parent Portfolio Category:', 'infinito' ),
    'edit_item'         => esc_html__( 'Edit Portfolio Category', 'infinito' ), 
    'update_item'       => esc_html__( 'Update Portfolio Category', 'infinito' ),
    'add_new_item'      => esc_html__( 'Add New Portfolio Category', 'infinito' ),
    'new_item_name'     => esc_html__( 'New Portfolio Category', 'infinito' ),
    'menu_name'         => esc_html__( 'Portfolio Categories', 'infinito' ),
  );
  $args = array(
    'labels' => $labels,
    'hierarchical' => true,
	'query_var' 			=> false,
	'rewrite' => array( 'slug' => $slug_category ),
  );
  register_taxonomy( 'portfolio_category', 'portfolio', $args );
}
add_action( 'init', 'wow_portfolio_tax', 0 );

/*
=================================================================================================================
wow_add_meta_boxes_to_portfolio() - Add the meta boxes to portfolio
=================================================================================================================
*/
function wow_add_meta_boxes_to_portfolio(){
global $wow_portfolio_meta_box , $wow_options;

$menus = get_terms('nav_menu');

$menus_array = array(''	=> 'No');

foreach($menus as $menu){
 $menus_array[$menu->term_id]  = $menu->name;
} 

$opt1 = $wow_options['portfolio_d1'] != 'Client'  ? $wow_options['portfolio_d1'] : 		__('Client' , 'infinito');
$opt2 = $wow_options['portfolio_d2'] != 'Started'  ? $wow_options['portfolio_d2'] : 	__('Started' , 'infinito');
$opt3 = $wow_options['portfolio_d3'] != 'Finished'  ? $wow_options['portfolio_d3'] : 	__('Finished' , 'infinito');
$opt4 = $wow_options['portfolio_d4'] != 'Type'  ? $wow_options['portfolio_d4'] : 		__('Type' , 'infinito');
$opt5 = $wow_options['portfolio_d5'] != 'Difficulty'  ? $wow_options['portfolio_d5'] : 	__('Difficulty' , 'infinito');

$wow_portfolio_meta_box = array(
		'id' 		=> 'wow-page-options',
		'title' 	=> esc_html__('Portfolio Options','infinito'),
		'page' 		=> 'portfolio',
		'context' 	=> 'normal',
		'priority' 	=> 'high',
		'fields'	=> array(
			array(
				'id'		=> 'wow-page-gallery-image',
				'class'		=> 'wow-page-gallery-image',
				'type'		=> 'upload_gallery',
				//'title'		=> esc_html__('Gallery Image(s)', 'infinito'),
				'big_title'		=> esc_html__('Gallery Image(s)', 'infinito'),
				'desc' 		=> esc_html__('Add / Remove image(s) to your single portfolio gallery.','infinito'),
				'options' 	=> '',
				'std'		=> '',	
				//'icon'		=> 'pe-7s-upload',	
			),
			array(
				'id' 		=> 'wow-details1',
				'class' 	=> 'wow-client',
				'type' 		=> 'input',
				'big_title' 	=> esc_html__('Details', 'infinito'),
				'title' 	=> esc_html__($opt1, 'infinito'),
				'desc' 		=> esc_html__('Enter '. $opt1, 'infinito'),
				'options' 	=> '',
				'std'		=> '',
				'subsection' => 'start',
			),			
			array(
				'id' 		=> 'wow-details2',
				'class' 	=> 'wow-start-date',
				'type' 		=> 'input',
				'title' 	=> esc_html__($opt2, 'infinito'),
				'desc' 		=> esc_html__('Enter '.$opt2, 'infinito'),
				'options' 	=> '',
				'std'		=> '',
				'subsection' => false,
			),			
			array(
				'id' 		=> 'wow-details3',
				'class' 	=> 'wow-end-date',
				'type' 		=> 'input',
				'title' 	=> esc_html__($opt3, 'infinito'),
				'desc' 		=> esc_html__('Enter '.$opt3, 'infinito'),
				'options' 	=> '',
				'std'		=> '',
				'subsection' => false,
			),				
			array(
				'id' 		=> 'wow-details4',
				'class' 	=> 'wow-type',
				'type' 		=> 'input',
				'title' 	=> esc_html__($opt4, 'infinito'),
				'desc' 		=> esc_html__('Enter '.$opt4, 'infinito'),
				'options' 	=> '',
				'std'		=> '',
				'subsection' => false,
			),				
			array(
				'id' 		=> 'wow-details5',
				'class' 	=> 'wow-difficulty',
				'type' 		=> 'input',
				'title' 	=> esc_html__($opt5, 'infinito'),
				'desc' 		=> esc_html__('Enter '.$opt5, 'infinito'),
				'options' 	=> '',
				'std'		=> '',
				'subsection' => false,
			),					
			array(
				'id' 		=> 'wow-btn-text-first',
				'class' 	=> 'wow-btn-text-first',
				'type' 		=> 'input',
				'title' 	=> esc_html__('1st Button text', 'infinito'),
				'desc' 		=> esc_html__('Enter primary text on your live demo button ( Displayed only in some single layouts -> See Theme Options -> Portfolio -> Portfolio single layout)', 'infinito'),
				'options' 	=> '',
				'std'		=> '',
				'subsection' => false,
			),				
			array(
				'id' 		=> 'wow-btn-text-second',
				'class' 	=> 'wow-btn-text-second',
				'type' 		=> 'input',
				'title' 	=> esc_html__('2nd Button text', 'infinito'),
				'desc' 		=> esc_html__('Enter second text on your live demo button ( Displayed only in some single layouts -> See Theme Options -> Portfolio -> Portfolio single layout)', 'infinito'),
				'options' 	=> '',
				'std'		=> '',
				'subsection' => false,
			),			
			array(
				'id' 		=> 'wow-btn-url',
				'class' 	=> 'wow-btn-url',
				'type' 		=> 'input',
				'title' 	=> esc_html__('Button URL', 'infinito'),
				'desc' 		=> esc_html__('Enter live demo button  URL. Do not forget the http://', 'infinito'),
				'options' 	=> '',
				'std'		=> '',
				'subsection' => 'end',
			),			
			array(
				'id' 		=> 'wow-single-template',
				'class' 	=> 'wow-single-template',
				'type' 		=> 'radio_img',
				//'title' 	=> esc_html__('Single portfolio template', 'infinito'),
				'big_title' 	=> esc_html__('Single portfolio template', 'infinito'),
				'desc' 		=> esc_html__('Choose a template for displaying this portfolio ( This will override the theme options settings for this portfolio only )', 'infinito'),
				'options' 	=> array(
					'' 	=> array('title' => 'Theme Default', 'img' => WOW_INFINITO_PLUGIN_URI.'/images/page-layout/theme-default.gif'),
					'style1'=> array('title' => 'Template 1', 'img' => WOW_INFINITO_PLUGIN_URI.'/images/thumbs/portfolio/single/style1.png'),
					'style2'=> array('title' => 'Template 2', 'img' => WOW_INFINITO_PLUGIN_URI.'/images/thumbs/portfolio/single/style2.png'),
					'style3'=> array('title' => 'Template 3', 'img' => WOW_INFINITO_PLUGIN_URI.'/images/thumbs/portfolio/single/style3.png'),
					'style4'=> array('title' => 'Template 4', 'img' => WOW_INFINITO_PLUGIN_URI.'/images/thumbs/portfolio/single/style4.png'),
				),
				'std'		=> '',
			),
			array(
				'id' 		=> 'wow-video-id',
				'class' 	=> 'wow-video-id-portfolio',
				'type' 		=> 'input',
				'big_title' 	=> esc_html__('Video ID', 'infinito'),
				'title' 	=> esc_html__('Youtube / Vimeo Video ID', 'infinito'),
				'desc' 		=> esc_html__('Enter Youtube or Vimeo Video ID - i.e MoHnffhBwqs ( Youtube ) or 181612110 ( Vimeo )', 'infinito'),
				'options' 	=> '',
				'std'		=> '',
			),
			array(
				'id'		=> 'wow-repeat-image',
				'class'		=> 'wow-repeat-image',
				'type'		=> 'select',
				//'title'		=> esc_html__('Image repeat', 'infinito'),
				'big_title'		=> esc_html__('Image repeat', 'infinito'),
				'desc' 		=> esc_html__('If you are using a single image, and it is smaller in size we recommend using the repeat option. Ignore this option for Single portfolio template 4', 'infinito'),
				'options' 	=> array(
                    'no-repeat' => 'No Repeat',
                    'repeat'    => 'Repeat',
				),
				'std'		=> 'no-repeat',
				
			),
			//different header layout
			array(
				'id' 		=> 'wow-header-layout',
				'class' 	=> 'wow-header-layout',
				'type' 		=> 'radio_img',
				'big_title' 	=> esc_html__('Header layout', 'infinito'),
				'desc' 		=> esc_html__('Change header layout for this portfolio only.', 'infinito'),
				'options' 	=> array(
					'' 	=> array('title' => 'Theme Default', 'img' => WOW_INFINITO_PLUGIN_URI.'/images/page-layout/theme-default.gif'),
					'header-one' =>  array( 'title' => 'Horizontal logo left', 'img' => WOW_INFINITO_PLUGIN_URI . '/images/theme-options/headers/header_01.gif' ) ,
					'header-one-a' =>  array( 'title' => 'Horizontal logo right', 'img' => WOW_INFINITO_PLUGIN_URI . '/images/theme-options/headers/header_01a.gif' ) ,
					'header-two' =>  array( 'title' => 'Horizontal logo left with separators', 'img' => WOW_INFINITO_PLUGIN_URI . '/images/theme-options/headers/header_02.gif' ) ,
					'header-two-a' =>  array( 'title' => 'Horizontal logo right with separators', 'img' => WOW_INFINITO_PLUGIN_URI . '/images/theme-options/headers/header_02a.gif' ) ,
					'header-three' =>  array( 'title' => 'Horizontal logo left - menu bellow', 'img' => WOW_INFINITO_PLUGIN_URI . '/images/theme-options/headers/header_03.gif' ) ,
					'header-four' =>  array( 'title' => 'Horizontal logo center - menu bellow', 'img' => WOW_INFINITO_PLUGIN_URI . '/images/theme-options/headers/header_04.gif' ) ,
					'header-five' =>  array( 'title' => 'Horizontal logo right - menu bellow', 'img' => WOW_INFINITO_PLUGIN_URI . '/images/theme-options/headers/header_05.gif' ) ,
					'header-five-a' =>  array( 'title' => 'Center logo - two menus', 'img' => WOW_INFINITO_PLUGIN_URI . '/images/theme-options/headers/header_05_a.gif' ) ,							
					'header-seven' =>  array( 'title' => 'Vertical left - logo top', 'img' => WOW_INFINITO_PLUGIN_URI . '/images/theme-options/headers/header_07.gif' ) ,
					'header-eight' =>  array( 'title' => 'Vertical left - logo bottom', 'img' => WOW_INFINITO_PLUGIN_URI . '/images/theme-options/headers/header_08.gif' ) ,
					'header-nine' =>  array( 'title' => 'Vertical right - logo top', 'img' => WOW_INFINITO_PLUGIN_URI . '/images/theme-options/headers/header_09.gif' ) ,
					'header-ten' =>  array( 'title' => 'Vertical right - logo bottom', 'img' => WOW_INFINITO_PLUGIN_URI . '/images/theme-options/headers/header_10.gif' ) ,
					'header-eleven' =>  array( 'title' => 'Overlay', 'img' => WOW_INFINITO_PLUGIN_URI . '/images/theme-options/headers/header_11.gif' ) ,			
				),
				'std'		=> '',
			),				
			//different page menu
			array(
				'id'		=> 'wow-different-menu',
				'class'		=> 'wow-different-menu',
				'type'		=> 'select',
				'big_title'		=> esc_html__('Other options', 'infinito'),
				'title'		=> esc_html__('Different menu?', 'infinito'),
				'desc' 		=> sprintf( '%s<br>%s<strong>%s</strong>', 
					esc_html__( 'Allows you to add a different menu on this portfolio.', 'infinito' ), 
					esc_html__( '*Does not work with header layout - ', 'infinito' ),
					esc_html__( 'Center logo - two menus', 'infinito' )
				),
				'options' 	=> $menus_array,
				'std'		=> '',
				'subsection' => 'start',
				
			),
			array(
				'id'		=> 'wow-disable-header',
				'class'		=> 'wow-disable-header',
				'type'		=> 'radio',
				'title'		=> esc_html__('Disable header?', 'infinito'),
				'desc' 		=> esc_html__('It will disable your header on this portfolio only', 'infinito'),
				'options' 	=> array(
					''	=> 'No',
					'yes'	=> 'Yes',	
				),
				'std'		=> '',
				'subsection' => false,
			),	
			array(
				'id'		=> 'wow-disable-footer',
				'class'		=> 'wow-disable-footer',
				'type'		=> 'radio',
				'title'		=> esc_html__('Disable footer?', 'infinito'),
				'desc' 		=> esc_html__('It will disable your footer on this portfolio only', 'infinito'),
				'options' 	=> array(
					''	=> 'No',
					'yes'	=> 'Yes',	
				),
				'std'		=> '',
				'subsection' => 'end',
				
			),
			array(
				'id'		=> 'wow-page-subheader-color',
				'class'		=> 'wow-page-subheader',
				'type'		=> 'color',
				'title'		=> esc_html__('Background Color', 'infinito'),
				'desc' 		=> '',
				'options' 	=> '',
				'std'		=> '',
				'subsection' => 'start',
				'big_title' => esc_html__('Sub-Header Options', 'infinito'),
			),	

			array(
				'id'		=> 'wow-page-subheader-bg-repeat',
				'class'		=> 'wow-page-subheader-bg-repeat',
				'type'		=> 'select',
				'title'		=> esc_html__('Background Repeat', 'infinito'),
				'desc' 		=> '',
				'options' 	=> array(
                        '' => 'Inherit',
                        'no-repeat' => 'No Repeat',
                        'repeat'    => 'Repeat All',
                        'repeat-x'  => 'Repeat Horizontally',
                        'repeat-y'  => 'Repeat Vertically',
				),
				'std'		=> '',
				'subsection' => false,
				
			),
			array(
				'id'		=> 'wow-page-subheader-bg-cover',
				'class'		=> 'wow-page-subheader-bg-cover',
				'type'		=> 'select',
				'title'		=> esc_html__('Background Size', 'infinito'),
				'desc' 		=> '',
				'options' 	=> array(
                        '' => 'Inherit',
                        'cover'   => 'Cover',
                        'contain' => 'Contain',
				),
				'std'		=> '',
				'subsection' => false,
				
			),	
			array(
				'id'		=> 'wow-page-subheader-bg-attachment',
				'class'		=> 'wow-page-subheader-bg-cover',
				'type'		=> 'select',
				'title'		=> esc_html__('Background Attachment', 'infinito'),
				'desc' 		=> '',
				'options' 	=> array(
                        '' => 'Inherit',
						'fixed'   => 'Fixed',
                        'scroll'  => 'Scroll',     
				),
				'std'		=> '',
				'subsection' => false,
				
			),
			array(
				'id'		=> 'wow-page-subheader-bg-position',
				'class'		=> 'wow-page-subheader-bg-position',
				'type'		=> 'select',
				'title'		=> esc_html__('Background Position', 'infinito'),
				'desc' 		=> '',
				'options' 	=> array(
						''      => 'Inherit',
                        'left top'      => 'Left Top',
                        'left center'   => 'Left center',
                        'left bottom'   => 'Left Bottom',
                        'center top'    => 'Center Top',
                        'center center' => 'Center Center',
                        'center bottom' => 'Center Bottom',
                        'right top'     => 'Right Top',
                        'right center'  => 'Right center',
                        'right bottom'  => 'Right Bottom',
				),
				'std'		=> '',
				'subsection' => false,
				
			),	
			array(
				'id'		=> 'wow-page-subheader-image',
				'class'		=> 'wow-page-subheader-image',
				'type'		=> 'upload_img',
				'title'		=> esc_html__('Background Image', 'infinito'),
				'desc' 		=> esc_html__('Add a custom background image to this page sub-header','infinito'),
				'options' 	=> '',
				'std'		=> '',
				'subsection' => 'end',
				
			),
			array(
				'id'		=> 'wow-show-breadcumb',
				'class'		=> 'wow-show-breadcumb',
				'type'		=> 'radio',
				//'title'		=> esc_html__('Page title & breadcrumb display ?', 'infinito'),
				'big_title'		=> esc_html__('Page title & breadcrumb display ?', 'infinito'),
				'desc' 		=> '',
				'options' 	=> array(
					''	=> 'Theme Default',
					'both'	=> 'Both ( Title and Breadcrumb )',
					'breadcrumb'	=> 'Breadcrumb',
					'title'	=> 'Title',
					'none'	=> 'None',
					
				),
				'std'		=> '',
			),				
			array(
				'id' 		=> 'wow-seo-title',
				'class' 	=> 'wow-seo',
				'type' 		=> 'textarea',
				'big_title' 	=> esc_html__('SEO', 'infinito'),
				'title' 	=> esc_html__('Title', 'infinito'),
				'desc' 		=> esc_html__('Enter the SEO title for this portfolio', 'infinito'),
				'options' 	=> '',
				'std'		=> '',
				'subsection' => 'start',
			),			
			
			array(
				'id' 		=> 'wow-seo-desc',
				'class' 	=> 'wow-seo-desc',
				'type' 		=> 'textarea',
				'title' 	=> esc_html__('Description', 'infinito'),
				'desc' 		=> esc_html__('Enter the SEO description for this portfolio', 'infinito'),
				'options' 	=> '',
				'std'		=> '',
				'subsection' => false,
			),			
			
			array(
				'id' 		=> 'wow-seo-keywords',
				'class' 	=> 'wow-seo-keywords',
				'type' 		=> 'textarea',
				'title' 	=> esc_html__('Keywords', 'infinito'),
				'desc' 		=> esc_html__('Enter the SEO keywords for this portfolio separated by commas', 'infinito'),
				'options' 	=> '',
				'std'		=> '',
				'subsection' => 'end',
			),
			
			array(
				'id' 		=> 'wow-custom-css',
				'class' 	=> 'wow-custom-css',
				'type' 		=> 'textarea',
				//'title' 	=> esc_html__('Custom CSS Code', 'infinito'),
				'big_title' 	=> esc_html__('Custom CSS Code', 'infinito'),
				'desc' 		=> esc_html__('Add your custom css code here for this portfolio', 'infinito'),
				'options' 	=> '',
				'std'		=> '',
			),				
		),
);
	add_meta_box(
		$wow_portfolio_meta_box['id'], 
		$wow_portfolio_meta_box['title'], 
		'wow_page_show_meta_box_portfolio',
		$wow_portfolio_meta_box['page'], 
		$wow_portfolio_meta_box['context'], 
		$wow_portfolio_meta_box['priority']
	);
}

add_action('admin_menu', 'wow_add_meta_boxes_to_portfolio');

/*
=================================================================================================================
wow_page_show_meta_box_portfolio() - Display meta boxes to all portfolio posts
=================================================================================================================
*/
function wow_page_show_meta_box_portfolio($post_id) {
	
	global $wow_portfolio_meta_box, $post;
	$post_id = $post->ID;

	// Use nonce for verification
	echo '<div id="wow-options-wrapper">';
		echo '<input type="hidden" name="wow_page_meta_nonce" value="'. esc_attr( wp_create_nonce(basename(__FILE__)) ). '" />';	
							
							//filter
							echo '<ul class="filter">';
								foreach ( $wow_portfolio_meta_box['fields'] as $field ) {
									if ( !empty( $field['big_title'] ) && $field['big_title'] ) {
										echo '<li><a href="#" class="'.esc_attr( $field['class'] ).' filter-options">'.esc_attr($field['big_title']).'</a></li>';
									}
								}
								echo '<li><a href="#" class="show-all">'.esc_html__('Show all','infinito').'</a></li>';
							echo '</ul>';							
							
							foreach ($wow_portfolio_meta_box['fields'] as $field) {
								if( empty( $field ) ) { continue; }
								$class = $field['class'] ? 'class="'.esc_attr( $field['class'] ).'"' : '';
								$field['subsection'] = isset($field['subsection']) ? $field['subsection'] : 'show';
								
								if ( $field['subsection'] == 'show' )	{
									echo '<section '. $class .'>'; //$class escaped above
									echo ( !empty( $field['big_title'] ) && $field['big_title'] ) ? '<h2 class="big_title">' . esc_html( $field['big_title'] ) . '<a class="wow_meta_open" href="#">+</a></h2>' : '';
									echo '<div class="subsection"  data-type="'.esc_attr( $field['type'] ).'">';
								}
								elseif( $field['subsection'] == 'start' ){
									echo '<section '. $class .'>';
									echo ( !empty( $field['big_title'] ) && $field['big_title'] ) ? '<h2 class="big_title pad15">' . esc_html( $field['big_title'] ) . ' <a class="wow_meta_open" href="#">+</a></h2></h2>' : '';
									echo '<div class="subsection"  data-type="'.esc_attr( $field['type'] ).'">'; //$class escaped above			
								}								
								else{
									echo '<div class="subsection"  data-type="'.esc_attr( $field['type'] ).'">';
								}

									echo ( !empty( $field['title'] ) && $field['title'] ) ? '<h2 class="title">' . esc_html( $field['title'] ) . ' </h2>' : '';
											$post_meta = get_post_meta($post_id, $field['id'], true);
											wow_html_fields($field['options'] , $field['type'] , $field['id'] , $post_meta, $field['class'], $field['std'],$field['subsection']); // no need to escape as all variables are properly escaped in the file functions/functions-theme.php - wow_html_fields()
											echo '<p class="desc">'.$field['desc'].'</p>'; //$field['desc'] properly escaped in the $wow_portfolio_meta_box array above - escaped with esc_html__
								if ( $field['subsection'] == 'show' )	{
									echo '</div></section>';
								}
								elseif( $field['subsection'] == 'end' ){
									echo '</div></section>';
								}
								else{
									echo '</div>';
								}
							}
		echo '</div>';
}


/*
=================================================================================================================
wow_page_save_data_portfolio() - Save all the portfolio data with the options from meta boxes
=================================================================================================================
*/
function wow_page_save_data_portfolio($post_id) {
	global $wow_portfolio_meta_box;
	// verify nonce
	if( key_exists( 'wow_page_meta_nonce',$_POST ) ) {
		if ( ! wp_verify_nonce( $_POST['wow_page_meta_nonce'], basename(__FILE__) ) ) {
			return $post_id;
		}
	}
 
	// check autosave
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
		return $post_id;
	}
 
	// check the permissions
	if ( (key_exists('post_type', $_POST)) && ('page' == $_POST['post_type']) ) {
		if (!current_user_can('edit_page', $post_id)) {
			return $post_id;
		}
	} elseif (!current_user_can('edit_post', $post_id)) {
		return $post_id;
	}
	if( !empty( $wow_portfolio_meta_box['fields'] ) ) {
		// check and save the fields $wow_portfolio_meta_box['fields']
		foreach ( (array)$wow_portfolio_meta_box['fields'] as $field ) {
			
			if ( empty( $field['id'] ) ) { continue; }
			
			$old = get_post_meta($post_id, $field['id'], true);
			if( key_exists($field['id'], $_POST) ) {
				$new = $_POST[$field['id']];
			} else {
				continue;
			}
	 
			if ( isset($new) && $new != $old) {
				update_post_meta($post_id, $field['id'], $new);
			} elseif ('' == $new && $old) {
				delete_post_meta($post_id, $field['id'], $old);
			}
		}
	}
	
}
add_action('save_post', 'wow_page_save_data_portfolio');