<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/*
=================================================================================================================
wow_one_click_importer_page() - Print the importer page
=================================================================================================================
*/
function wow_one_click_importer_page(){
	?>
	<div class="infinto-wrap"><!-- infinto-wrap -->
		<div class="top-info">
			<div class="mini-logo"><img src="<?php echo esc_url( WOW_URI.'/images/admin/logo-icon.png' ); ?>" /></div>
			<h1><?php esc_html_e('Let\'s pick one.','infinito'); ?></h1>
			<p><?php esc_html_e('Choose your demo, click Import, and you are good to to.','infinito'); ?></p>
		</div>
		<?php wow_show_theme_menu(); ?>
		<?php wow_demos_list(); ?>
	</div><!--/ about-wrap -->
	<?php
}

/*
=================================================================================================================
wow_server_minimum_req() - Check if server minimum requirements are met
=================================================================================================================
*/
function wow_server_minimum_req(){

	$return='';
	$warning = array();
	$allowed_html_tags = array( 'div' => array ( 'id' => array() , 'class' => array() ),'ul' => array ( 'class' => array() ), 'i' => array ( 'class' => array() ),'span' => array ( 'class' => array() ), 'li' => array() , 'br' => array(), 'p' => array(), 'h3' => array( 'class' => array() ), 'b' => array());
	
	$titles = array(
				'memory_limit'=> esc_html__('PHP memory limit','infinito'),						
				'max_execution_time'=> esc_html__('PHP time limit','infinito'),						
				'max_input_vars'=> esc_html__('PHP max input vars','infinito'),						
				'upload_size'=> esc_html__('Max upload size','infinito'),						
			);
	
	$msg = array(
		'memory_limit'=> '<i class="wow-webapplication-exclamation-circle"></i> '.ini_get( 'memory_limit' ).'<br><span class="alert">Memory limit is good, however 256M is recommended</span>',
		'max_execution_time'=> '<i class="wow-webapplication-close-circled"></i> '.ini_get( 'max_execution_time' ).'<br><span class="alert">Mimimum is 120, recommended is 180.</span>',
		'max_input_vars'=> '<i class="wow-webapplication-close-circled"></i> '.ini_get( 'max_input_vars' ).'<br><span class="alert">Mimimum of 3000 is recommended</span>',
		'upload_size'=> '<i class="wow-webapplication-close-circled"></i> '.size_format( wp_max_upload_size() ).'<br><span class="alert">Minimum of 32 MB is required</span>',
	);
	
	
	$warning []= ini_get( 'memory_limit' ) < 256 ? 'memory_limit' : '';
	$warning []= ini_get( 'max_execution_time' ) < 120 ? 'max_execution_time' : '';
	$warning []= ini_get( 'max_input_vars' ) < 3000 ? 'max_input_vars' : '';
	$warning []= size_format( wp_max_upload_size() ) < 32 ? 'upload_size' : '';
	
	
	$warnings = array_filter( $warning ); //delete empty values from array
	
	if( !empty( $warnings ) ){
		$return .= '<div id="server_req_error" class="modal">';

			$return .=  '<h3>' . __('Server minimum requirements not met','infinito') . '</h3>';
			$return .=  '<h3 class="explanation">' . __('What does this mean?','infinito') . '</h3>';
			$return .=  '<p>' . __('This will lead to bad / incomplete imports and  <b>we really don\'t recomment it</b>. <br> You can still use the importer, however consider resolving the issues bellow for optimal results. <br/> If you are unsure on how to do this, please contact your hosting provider.','infinito') . '</p>';

			$return .= '<ul class="system_status">';		
				foreach( $warnings as $val ){
					$return .= '<li><span class="detail">'.$titles[$val].'</span><span class="info">'.$msg[$val].'</span></li>';
				}
			$return .= '</ul>';
		$return .= '</div>';
		
		return wp_kses( $return, $allowed_html_tags );
	}
	
	return false;

}

/*
=================================================================================================================
wow_delete_import_content() - Delete import content
=================================================================================================================
*/
function wow_delete_import_content(){
?>
	<div class="wow_delete_import_content modal">
		<div class="warning">
			<h2><?php _e('Pick your desired action(s)','infinito'); ?></h2>
		</div>
		<div class="options">
			<ul>
				<li>
					<h3><?php _e('Posts','infinito'); ?></h3>
					<select name="import_delete_posts">
						<option value=""><?php _e('Keep','infinito'); ?></option>
						<option value="trash"><?php _e('Trash','infinito'); ?></option>
						<option value="delete"><?php _e('Delete permanently','infinito'); ?></option>
					</select>
					<small><?php _e('Applies to all posts','infinito'); ?></small>					
				</li>
				
				<li>
					<h3><?php _e('Pages','infinito'); ?></h3>
					<select name="import_delete_pages">
						<option value=""><?php _e('Keep','infinito'); ?></option>
						<option value="trash"><?php _e('Trash','infinito'); ?></option>
						<option value="delete"><?php _e('Delete permanently','infinito'); ?></option>
					</select>
					<small><?php _e('Applies to all pages','infinito'); ?></small>
				</li>
				
				<li>
					<h3><?php _e('Portfolio','infinito'); ?></h3>
					<select name="import_delete_portfolio">
						<option value=""><?php _e('Keep','infinito'); ?></option>
						<option value="trash"><?php _e('Trash','infinito'); ?></option>
						<option value="delete"><?php _e('Delete permanently','infinito'); ?></option>
					</select>
					<small><?php _e('Applies to all portfolio','infinito'); ?></small>
				</li>

				<?php if ( class_exists ( 'WooCommerce' ) ) { ?>
				<li>
					<h3><?php _e('Products','infinito'); ?></h3>
					<select name="import_delete_products">
						<option value=""><?php _e('Keep','infinito'); ?></option>
						<option value="trash"><?php _e('Trash','infinito'); ?></option>
						<option value="delete"><?php _e('Delete permanently','infinito'); ?></option>
					</select>
					<small><?php _e('Applies to all products','infinito'); ?></small>
				</li>				
				<?php } ?>
				
				<li>
					<h3><?php _e('Widgets','infinito'); ?></h3>
					<select name="import_delete_widgets">
						<option value=""><?php _e('Keep','infinito'); ?></option>
						<option value="inactive"><?php _e('Set to inactive','infinito'); ?></option>
						<option value="delete"><?php _e('Delete permanently','infinito'); ?></option>
					</select>
					<small><?php _e('Applies to all widgets','infinito'); ?></small>
				</li>
				
				<li>
					<h3><?php _e('Menu','infinito'); ?></h3>
					<select name="import_delete_menus">
						<option value=""><?php _e('Keep','infinito'); ?></option>
						<option value="delete"><?php _e('Delete permanently','infinito'); ?></option>
					</select>
					<small><?php _e('Applies to all theme menus','infinito'); ?></small>
				</li>				
				
				<li>
					<h3><?php _e('Media attachments','infinito'); ?></h3>
					<select name="import_delete_media">
						<option value=""><?php _e('Keep','infinito'); ?></option>
						<option value="delete"><?php _e('Delete permanently','infinito'); ?></option>
					</select>
					<small><?php _e('Applies to all media attachments','infinito'); ?></small>
				</li>
			</ul>
	
		</div>	
		<p class="warning">
			<?php _e('Proceed with caution or create a backup first, if unsure!','infinito'); ?>
		</p>		
		<button class="wow-import-delete-ok"><a href="#" rel="modal:close"><?php _e('Ok','infinito'); ?></a></button>
		<button class="wow-import-delete-close"><a href="#close" rel="modal:close"><?php _e('Cancel','infinito'); ?></a></button>
	</div>
<?php
}

/*
=================================================================================================================
wow_demos_list() - Create the demos list
=================================================================================================================
*/
function wow_demos_list(){
	
	//demos file
	require_once( WOW_FUNCTIONS_DIR_ADMIN .'/demos-list.php' );
	
	$disable_button = '';
	
	$plugins = array(
		'Revolution Slider' => 'RevSliderBase', 
		'Infinito WPBakery Page Builder' => 'Vc_Manager', 
		'Contact Form 7' => 'WPCF7', 
		'WooCommerce' => 'WooCommerce', 
		'Infinito Addons' => 'wow_infinito_addons_plugin_core', 
		'Infinito Elements' => 'wow_infinito_elements_plugin_core', 
	);

	foreach ( $plugins as $plugin_name => $plugin_path  ){
		$is_active = false;
		if ( class_exists ( $plugin_path ) || function_exists ( $plugin_path ) ){
			$is_active = true;
		} 			
		$active_plugins[$plugin_name] = $is_active ;
	}
	
	
	
	echo wow_server_minimum_req();
	wow_delete_import_content();
	//let's start the array from index 1 instead of 0
	array_unshift($demos_array,"");
	unset($demos_array[0]); ?>
	
	<div class="demos">

		<div class="demos_filter">
			<ul>
				<li class="wow-demos all-demos active"><a title="Filter tag" href="#"><?php esc_html_e( 'All ','infinito' ); ?></a></li>
			<?php
				foreach ( $demos_array as $key => $val ){ 
					
					foreach( $val["tags"] as $tag ){
						$filter_array[$tag]='';
					}
				}
				ksort($filter_array);
				foreach( $filter_array as $filter=>$val ){	
					?>
						<li class="wow-demos"><a title="Filter tag" href="#"><?php echo $filter; ?></a></li>
					<?php
				}
			?>
			</ul>
			<div class="demos_search"><input type="text" class="demos_search_input" value="" placeholder="<?php esc_attr_e( 'Type to search demo...','infinito' ) ?>"/></div>
		</div>
			
		<ul class="one_click_demos">
		
		<?php foreach ( $demos_array as $id => $demo ){ 
				$disable_button = '';
				$error_msg =  false;
				?>
			<li class="<?php echo esc_attr( implode( ' ',$demo['tags'] ) ); ?>">
				
				<div class="screenshot-text">
					<a target="_blank"  href="#">
						<?php if ( wow_plugin_exists_and_is_active ( 'Infinito Elements' ) ) :
							$plugin_path 		= wow_plugin_exists_and_is_active ( 'Infinito Elements' , true );
							$plugin_dir_name 	= explode ( '/',  $plugin_path );
							$image_uri 			= get_site_url().'/wp-content/plugins/'.$plugin_dir_name[0].'/images/importer/'.esc_attr( $demo['basename'] ).'.jpg';
							$image_path 		= get_home_path().'/wp-content/plugins/'.$plugin_dir_name[0].'/images/importer/'.esc_attr( $demo['basename'] ).'.jpg';
							$final_image_uri 	=  file_exists( $image_path ) ? $image_uri : WOW_URI.'/images/dummy/missing-screenshot.png';
						?>	
						<img src="<?php echo esc_url ( $final_image_uri  ); ?>" />
						<?php else : ?>
						<img src="<?php echo esc_url( WOW_URI.'/images/dummy/inactive-infinito-elements.png' ) ?>" />
						<?php endif; ?>
					</a>
					<h1><?php echo esc_html( $demo['title'] ); ?></h1>
				</div>
				
				<div class="demos-inner pop-up-demo">
					
					<?php $wow_purchase_code = wow_get_envato_purchase_code(); if( !empty( $wow_purchase_code ) ){ ?>
					
						<h1><?php echo esc_html( $demo['title'] ); ?></h1>
						<span class="tags"><?php esc_html_e( 'Tags: ','infinito' ); echo esc_html( implode( ', ',$demo['tags'] ) );  ?></span>
						<h4><?php esc_html_e('Plugins required:','infinito'); ?></h4>
						
						<?php
							$allowed_html_tags = array( 'span' => array ( 'class' => array() ), 'br' => array () , 'a' => array( 'href' => array() ) );
							foreach( $demo['plugins']['required'] as $plugin ){ ?>
								<?php $plugins_class = strtolower( str_ireplace ( array(' '), array('-'), $plugin ) ); ?>
								<span class="<?php echo esc_attr( $plugins_class ); ?>"></span>
								<p>
									<strong><?php echo esc_html( $plugin ); ?></strong>
									<span class="info">
										<?php																				
											if( $active_plugins[$plugin] == true ){
												echo '<span class="active">'.esc_attr_e( 'Required','infinito' ).'</span><i class="active wow-webapplication-checked"></i>';
											}
											else{
												echo '<span class="inactive">'.esc_attr_e( 'Required','infinito' ).'</span><i class="inactive wow-webapplication-close-squared"></i>';
												$error_msg = true;
											}								
										?>
									</span>
								</p>
							<?php }
							foreach( $demo['plugins']['recommended'] as $plugin ){ 
							?>
								<?php $plugins_class = strtolower( str_ireplace ( array(' '), array('-'), $plugin ) ); ?>
								<span class="<?php echo esc_attr( $plugins_class ); ?>"></span>
								<p>
									<strong><?php echo esc_html( $plugin ); ?></strong>
									<span class="info">
										<?php																				
											if( $active_plugins[$plugin] == true ){
												echo '<span class="active recommended">'.esc_attr_e( 'Recommended','infinito' ).'</span><i class="recommended active wow-webapplication-checked"></i>';
											}
											else{
												echo '<span class="inactive recommended">'.esc_attr_e( 'Recommended','infinito' ).'</span><i class="recommended inactive wow-webapplication-close-squared"></i>';											
											}								
										?>
									</span>
								</p>
							<?php }
							if ( current_user_can( 'manage_options' )) {
						?>			
						<?php 	if( $error_msg == true ) {
									printf( '<span class="error_msg">%s<a href="%s" class="inline">%s</a>%s</span>', 
										esc_html__( 'Please ', 'infinito' ), 
										esc_url ( admin_url('plugins.php') ),
										esc_html__( 'install', 'infinito' ),
										esc_html__( ' required plugins before importing.', 'infinito' )
									);
									$disable_button = ' disabled';												
								}
							?>
							<?php if ( !$error_msg ) { ?>
							<div class="import-details">
								<?php echo '<h1>'.esc_attr__( 'What to import?','infinito' ).'</h1>'; ?>
								<div class="option"><input class="import-content" name="import-content" type="checkbox" checked> <?php esc_html_e( 'Content ( Pages, posts, menu etc. )','infinito' ); ?></div>
								<div class="option"><input class="import-theme_options" name="import-theme_options" type="checkbox" checked> <?php esc_html_e( 'Theme options','infinito' ); ?></div>
							</div>
							<?php } ?>
							<button class="<?php echo esc_attr($disable_button); ?>"><a class="wow-importer<?php echo esc_attr($disable_button); ?>" data-demo="<?php echo esc_attr( $demo['basename'] ); ?>"  data-title="<?php echo esc_attr( $demo['title'] ); ?>"  href="#"><i class="wow-business-files"></i><?php esc_html_e( 'Import','infinito' ); ?></a></button>
							<button class="live_demo"><a target="_blank"  href="<?php echo esc_url( $demo['live_url'] ); ?>" target="_blank"><i class="wow-webapplication-link"></i><?php esc_html_e( 'Live Demo','infinito' ); ?></a></button>
							<?php } ?>
						
					<?php } else{

						?>
					
						<div class="theme_inactive">
							<i class="wow-webapplication-lock activate"></i>
							<p class="almost"><?php esc_html_e( 'Almost there','infinito' ); ?></p>
							<h4><?php esc_html_e( 'Activate Infinito!','infinito' ); ?></h4>
							<p><?php esc_html_e( 'Please register your theme in order to use Importer and other theme cool features.','infinito' ); ?></p>
							<p><?php esc_html_e( 'You only have to do this once and it takes few seconds. Literally!','infinito' ); ?></p>
							<p><?php esc_html_e( '','infinito' ); ?></p>
							<button class="">
								<a class="wow-register" href="<?php echo esc_url( admin_url('admin.php?page=infinito-dashboard') ); ?>"><i class="wow-webapplication-lock"></i><?php esc_html_e( 'Register Infinito','infinito' ); ?></a>
							</button>							
						</div>
					
					<?php } ?>	
				</div> <!-- demos-inner -->
				
			</li>
			
			
		<?php } ?>
		
		</ul>
	</div>
	<?php
}