<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/**
 * Functions admin main file
 *
 * @package Infinito
 * @author WOW Layers
 * @link https://wowlayers.com
 */

//add the admin theme functions files
require_once( WOW_FUNCTIONS_DIR_ADMIN .'/functions-dashboard.php' );
require_once( WOW_FUNCTIONS_DIR_ADMIN .'/functions-1-click-importer.php' );
//require_once( WOW_FUNCTIONS_DIR_ADMIN .'/functions-support.php' );
require_once( WOW_FUNCTIONS_DIR_ADMIN .'/functions-status.php' );
require_once( WOW_FUNCTIONS_DIR_ADMIN .'/functions-changelog.php' );


/*
=================================================================================================================
wow_on_theme_activation() - Redirect user to welcome page on theme switch
=================================================================================================================
*/
function wow_on_theme_activation(){
    wp_safe_redirect( esc_url ( admin_url('admin.php?page=infinito-dashboard' ) ) );
}
add_action("after_switch_theme", "wow_on_theme_activation");

/*
=================================================================================================================
wow_theme_pages() - Add theme pages
=================================================================================================================
*/
function wow_theme_pages(){
    add_menu_page('Welcome', 'Infinito', 'manage_options', 'welcome', 'wow_dashboard_page', WOW_ADMIN_IMG.'/logo-icon.png', 2 );
    add_submenu_page('welcome', '', 'Dashboard', 'manage_options', 'infinito-dashboard','wow_dashboard_page' );
    add_submenu_page('welcome', '', '1 Click Importer', 'manage_options', 'infinito-importer','wow_one_click_importer_page' );
    //add_submenu_page('welcome', '', 'Support', 'manage_options', 'infinito-help','wow_support_page' );
    add_submenu_page('welcome', '', 'System Status', 'manage_options', 'infinito-system-status','wow_system_status_page' );
    add_submenu_page('welcome', '', 'Changelog', 'manage_options', 'infinito-changelog','wow_changelog_page' );
	remove_submenu_page('welcome','welcome');
}
add_action('admin_menu', 'wow_theme_pages');


/*
=================================================================================================================
wow_is_active_screen( $needle ) - Check if a url contains the needle input
=================================================================================================================
*/
function wow_is_active_screen( $needle ){
	$url = ( isset( $_SERVER['HTTPS'] ) && $_SERVER['HTTPS'] === 'on' ? "https" : "http" ) . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
	$result = stripos( $url, $needle );
	if ( $result !== false ) {
		return true;
	}
	else{
		return false;
	}
	
}
/*
=================================================================================================================
wow_welcome_admin_body_class() - add body class to admin
=================================================================================================================
*/
add_filter( 'admin_body_class', 'wow_welcome_admin_body_class' );

function wow_welcome_admin_body_class( $classes ) {
	
	if ( wow_is_active_screen( 'infinito-dashboard' ) || wow_is_active_screen( 'infinito-importer' ) || wow_is_active_screen( 'infinito-help' ) || wow_is_active_screen( 'infinito-system-status' ) || wow_is_active_screen( 'infinito-changelog' ) || wow_is_active_screen( 'infinito_options' ) ){
		$classes .= 'infinito-pages';
	}
	
	return $classes;
}


/*
=================================================================================================================
wow_theme_activation() - we activate the theme here
=================================================================================================================
*/
function wow_theme_activation() {
	if( wow_is_active_screen( 'infinito-dashboard' ) ){
		
		wp_register_script( 'wow-theme-register', WOW_URI."/js/register.js", array('jquery'), NULL, true );
		wp_localize_script( 'wow-theme-register', 'wow_purchase_code', array('ajaxurl' => esc_url( site_url() ) . '/wp-admin/admin-ajax.php') );	
		wp_enqueue_script( 'wow-theme-register' );

		wp_register_script( 'wow-theme-deregister', WOW_URI."/js/deregister.js", array('jquery'), NULL, true );
		wp_localize_script( 'wow-theme-deregister', 'wow_purchase_code', array('ajaxurl' => esc_url( site_url() ) . '/wp-admin/admin-ajax.php') );	
		wp_enqueue_script( 'wow-theme-deregister' );					
		
	}	
}
add_action( 'admin_enqueue_scripts', 'wow_theme_activation' );

/*
=================================================================================================================
wow_show_theme_menu - Show the navigation in all pages
=================================================================================================================
*/
function wow_show_theme_menu(){ ?>
		<h2 class="nav-tab-wrapper infinito">
			<a class="nav-tab welcome<?php if ( wow_is_active_screen( 'infinito-dashboard' ) ) { echo ' nav-tab-active'; } ?>" href="<?php echo esc_url( admin_url('admin.php?page=infinito-dashboard') ); ?>"><i class="wow-webapplication-dashboard"></i><?php esc_html_e('Dashboard','infinito'); ?></a>
            <a class="nav-tab importer<?php if ( wow_is_active_screen( 'infinito-importer' ) ) { echo ' nav-tab-active'; } ?>" href="<?php echo esc_url( admin_url('admin.php?page=infinito-importer') ); ?>"><i class="wow-mobileui-file"></i><?php esc_html_e('1 Click Importer','infinito'); ?></a>
            <a class="nav-tab options<?php if ( wow_is_active_screen( 'infinito_options' ) ) { echo ' nav-tab-active'; } ?>" href="<?php echo esc_url( admin_url('admin.php?page=infinito_options') ); ?>"><i class="wow-webapplication-settings"></i><?php esc_html_e('Theme Options','infinito'); ?></a>
            <a class="nav-tab status<?php if ( wow_is_active_screen( 'infinito-system-status' ) ) { echo ' nav-tab-active'; } ?>" href="<?php echo esc_url( admin_url('admin.php?page=infinito-system-status') ); ?>"><i class="wow-webapplication-server"></i><?php esc_html_e('System Status','infinito'); ?></a>
            <a class="nav-tab changelog-a<?php if ( wow_is_active_screen( 'infinito-changelog' ) ) { echo ' nav-tab-active'; } ?>" href="<?php echo esc_url( admin_url('admin.php?page=infinito-changelog') ); ?>"><i class="wow-business-list"></i><?php esc_html_e('Changelog','infinito'); ?></a>            
        </h2>
<?php }