<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/*
=================================================================================================================
Aqua Resize Function - resize images on the fly
=================================================================================================================
*/
if(!class_exists('Aq_Resize')) {
 class Aq_Resize
 {
 /**
 * The singleton instance
 */
 static private $instance = null;
 /**
 * No initialization allowed
 */
 private function __construct() {}
 /**
 * No cloning allowed
 */
 private function __clone() {}
 /**
 * For your custom default usage you may want to initialize an Aq_Resize object by yourself and then have own defaults
 */
 static public function getInstance() {
 if(self::$instance == null) {
 self::$instance = new self;
 }
 return self::$instance;
 }
 /**
 * Run, forest.
 */
 public function process( $url, $width = null, $height = null, $crop = null, $single = true, $upscale = false ) {
 // Validate inputs.
 if ( ! $url || ( ! $width && ! $height ) ) return false;
 // Caipt'n, ready to hook.
 if ( true === $upscale ) add_filter( 'image_resize_dimensions', array($this, 'aq_upscale'), 10, 6 );
 // Define upload path & dir.
 $upload_info = wp_upload_dir();
 $upload_dir = $upload_info['basedir'];
 $upload_url = $upload_info['baseurl'];
 
 $http_prefix = "http://";
 $https_prefix = "https://";
 
 /* if the $url scheme differs from $upload_url scheme, make them match 
 if the schemes differe, images don't show up. */
 if(!strncmp($url,$https_prefix,strlen($https_prefix))){ //if url begins with https:// make $upload_url begin with https:// as well
 $upload_url = str_replace($http_prefix,$https_prefix,$upload_url);
 }
 elseif(!strncmp($url,$http_prefix,strlen($http_prefix))){ //if url begins with http:// make $upload_url begin with http:// as well
 $upload_url = str_replace($https_prefix,$http_prefix,$upload_url); 
 }
 
 // Check if $img_url is local.
 if ( false === strpos( $url, $upload_url ) ) return false;
 // Define path of image.
 $rel_path = str_replace( $upload_url, '', $url );
 $img_path = $upload_dir . $rel_path;
 // Check if img path exists, and is an image indeed.
 if ( ! file_exists( $img_path ) or ! getimagesize( $img_path ) ) return false;
 // Get image info.
 $info = pathinfo( $img_path );
 $ext = $info['extension'];
 list( $orig_w, $orig_h ) = getimagesize( $img_path );
 // Get image size after cropping.
 $dims = image_resize_dimensions( $orig_w, $orig_h, $width, $height, $crop );
 $dst_w = $dims[4];
 $dst_h = $dims[5];
 // Return the original image only if it exactly fits the needed measures.
 if ( ! $dims && ( ( ( null === $height && $orig_w == $width ) xor ( null === $width && $orig_h == $height ) ) xor ( $height == $orig_h && $width == $orig_w ) ) ) {
 $img_url = $url;
 $dst_w = $orig_w;
 $dst_h = $orig_h;
 } else {
 // Use this to check if cropped image already exists, so we can return that instead.
 $suffix = "{$dst_w}x{$dst_h}";
 $dst_rel_path = str_replace( '.' . $ext, '', $rel_path );
 $destfilename = "{$upload_dir}{$dst_rel_path}-{$suffix}.{$ext}";
 if ( ! $dims || ( true == $crop && false == $upscale && ( $dst_w < $width || $dst_h < $height ) ) ) {
 // Can't resize, so return false saying that the action to do could not be processed as planned.
 return false;
 }
 // Else check if cache exists.
 elseif ( file_exists( $destfilename ) && getimagesize( $destfilename ) ) {
 $img_url = "{$upload_url}{$dst_rel_path}-{$suffix}.{$ext}";
 }
 // Else, we resize the image and return the new resized image url.
 else {
 $editor = wp_get_image_editor( $img_path );
 if ( is_wp_error( $editor ) || is_wp_error( $editor->resize( $width, $height, $crop ) ) )
 return false;
 $resized_file = $editor->save();
 if ( ! is_wp_error( $resized_file ) ) {
 $resized_rel_path = str_replace( $upload_dir, '', $resized_file['path'] );
 $img_url = $upload_url . $resized_rel_path;
 } else {
 return false;
 }
 }
 }
 // Okay, leave the ship.
 if ( true === $upscale ) remove_filter( 'image_resize_dimensions', array( $this, 'aq_upscale' ) );
 // Return the output.
 if ( $single ) {
 // str return.
 $image = $img_url;
 } else {
 // array return.
 $image = array (
 0 => $img_url,
 1 => $dst_w,
 2 => $dst_h
 );
 }
 return $image;
 }
 /**
 * Callback to overwrite WP computing of thumbnail measures
 */
 function aq_upscale( $default, $orig_w, $orig_h, $dest_w, $dest_h, $crop ) {
 if ( ! $crop ) return null; // Let the wordpress default function handle this.
 // Here is the point we allow to use larger image size than the original one.
 $aspect_ratio = $orig_w / $orig_h;
 $new_w = $dest_w;
 $new_h = $dest_h;
 if ( ! $new_w ) {
 $new_w = intval( $new_h * $aspect_ratio );
 }
 if ( ! $new_h ) {
 $new_h = intval( $new_w / $aspect_ratio );
 }
 $size_ratio = max( $new_w / $orig_w, $new_h / $orig_h );
 $crop_w = round( $new_w / $size_ratio );
 $crop_h = round( $new_h / $size_ratio );
 $s_x = floor( ( $orig_w - $crop_w ) / 2 );
 $s_y = floor( ( $orig_h - $crop_h ) / 2 );
 return array( 0, 0, (int) $s_x, (int) $s_y, (int) $new_w, (int) $new_h, (int) $crop_w, (int) $crop_h );
 }
 }
}
if(!function_exists('aq_resize')) {
 /**
 * This is just a tiny wrapper function for the class above so that there is no
 * need to change any code in your own WP themes. Usage is still the same :)
 */
 function aq_resize( $url, $width = null, $height = null, $crop = null, $single = true, $upscale = false ) {
 $aq_resize = Aq_Resize::getInstance();
 return $aq_resize->process( $url, $width, $height, $crop, $single, $upscale );
 }
}


/*
=================================================================================================================
Function wow_hex2rgba() - convert hex 2 rgba
=================================================================================================================
*/
function wow_hex2rgba($hex, $alpha = 1){
	$hex = str_replace('#', '', $hex);
	$r = $g = $b = 0;

	switch(strlen($hex)){
		case 3:
			list($r, $g, $b) = str_split($hex);
			$r = hexdec($r.$r);
			$g = hexdec($g.$g);
			$b = hexdec($b.$b);
			break;
		case 6:
			list($r1, $r2, $g1, $g2, $b1, $b2) = str_split($hex);
			$r = hexdec($r1.$r2);
			$g = hexdec($g1.$g2);
			$b = hexdec($b1.$b2);
			break;
		default:
			break;
	}

	return 'rgba('.$r.', '.$g.', '.$b.', '.$alpha.')';
}

/*
=================================================================================================================
wow_get_string_between() - Get a string based on start and end parameters
=================================================================================================================
*/
function wow_get_string_between($string, $start='', $end){
    $string = " ".$string;
	if (!$start){ $ini = 1; }
	else { $ini = strpos($string,$start); }
    if ($ini == 0) return "";
    $ini += strlen($start);   
    $len = strpos($string,$end,$ini) - $ini;
    return substr($string,$ini,$len);
}


/*
=================================================================================================================
wow_is_realy_woocommerce_page() - Check if it is a real woocommerce page
=================================================================================================================
*/
function wow_is_realy_woocommerce_page () {
	

	if( function_exists ( "is_woocommerce" ) && is_woocommerce() ){
		return true;
	}
	$page_ID = get_the_ID ();
	
	if( $page_ID == "0" ){
		return false;
	}

	global $wpdb;
	$query = "SELECT * FROM `{$wpdb->prefix}options` WHERE `option_value` =  '$page_ID' and
		  ( `option_name` = 'woocommerce_shop_page_id' or 
			`option_name` = 'woocommerce_terms_page_id' or 
			`option_name` = 'woocommerce_cart_page_id' or 
			`option_name` = 'woocommerce_checkout_page_id' or 
			`option_name` = 'woocommerce_pay_page_id' or 
			`option_name` = 'woocommerce_thanks_page_id' or 
			`option_name` = 'woocommerce_myaccount_page_id' or 
			`option_name` = 'woocommerce_edit_address_page_id' or 
			`option_name` = 'woocommerce_view_order_page_id' or 
			`option_name` = 'woocommerce_change_password_page_id' or 
			`option_name` = 'woocommerce_logout_page_id' or 
			`option_name` = 'woocommerce_lost_password_page_id' or
			
			`option_name` = 'yith_wcwl_wishlist_page_id')";
	$results = $wpdb->get_results( $query , OBJECT );

	if( isset( $results[0] )  ){ //if there are values it means it's a Woo page
		return true;
	}
	return false;
}

/*
=================================================================================================================
wow_bbp_breadcrumb() - Custom bbpress breadcrumb
=================================================================================================================
*/
function wow_bbp_breadcrumb() {
	global $wow_options;
	
	$delimiter 		= '<li class="delimiter"><i class="'.esc_attr($wow_options['breadcrumb_sep_icon']).'"></i></li>';
	$home_text = (!empty($wow_options['breadcrumb_home_title'])) ? esc_attr($wow_options['breadcrumb_home_title']) : 'Home';
	
    $args['home_text']  = $home_text;
    $args['sep']  = $delimiter;
    $args['crumb_before']  = '<li class="current">';
    $args['crumb_after']  = '</li>';
	
    return $args;
}
add_filter('bbp_before_get_breadcrumb_parse_args', 'wow_bbp_breadcrumb');

/*
=================================================================================================================
wow_yith_wishlist() - YITH - Wishlisht Plugin
=================================================================================================================
*/
if( defined( 'YITH_WCWL' ) ){
	function wow_yith_wishlist(){
		echo do_shortcode( "[yith_wcwl_add_to_wishlist 'icon'= 'wow-webapplication-heart']" );
	}
	add_action( 'woocommerce_after_shop_loop_item_title', 'wow_yith_wishlist' );
}