<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/*
=================================================================================================================
wow_theme_options_init() - Init theme options
=================================================================================================================
*/
function wow_theme_options_init(){
	wow_custom_options_init();
}
add_action('wp','wow_theme_options_init');


/*
=================================================================================================================
wow_custom_css() - used to add custom theme options css
=================================================================================================================
*/
function wow_custom_css() {
	
	//custom css code from  theme options pulled from the functions/functions-options.php file
	global $wow_css;
	echo ( !empty ( $wow_css ) ) ? '<style type="text/css">' . $wow_css . '</style>' : ''; 
	//no need to escape as all variables inside this varible are properly escaped in the file functions/functions-options.php

}
add_action( 'wp_head', 'wow_custom_css' );


/*
=================================================================================================================
wow_admin_custom_css() - add custom css to admin area
=================================================================================================================
*/
function wow_admin_custom_css() {
	global $wow_options,$admin_wow_custom_css;
	//add theme color to admin area
	if ( !empty( $wow_options['theme-color1'] ) || !empty( $wow_options['theme-color2'] ) || !empty( $wow_options['theme-color3'] )){
		
		$admin_wow_custom_css.= !empty( $wow_options['theme-color1'] ) ? '.themecolor1{color:'. esc_attr( $wow_options['theme-color1'] ) .'}' : '';
		$admin_wow_custom_css.= !empty( $wow_options['theme-color2'] ) ? '.themecolor2{color:'. esc_attr( $wow_options['theme-color2'] ) .'}' : '';
		$admin_wow_custom_css.= !empty( $wow_options['theme-color3'] ) ? '.themecolor3{color:'. esc_attr( $wow_options['theme-color3'] ) .'}' : '';
	}
	
	//global dynamic admin css
	echo !empty ( $admin_wow_custom_css ) ? '<style id="admin_custom_css" type="text/css">' . $admin_wow_custom_css . '</style>' : '';//no need to escape as all variables inside this varible are properly escaped above
}
add_action( 'admin_head', 'wow_admin_custom_css' );

/*
=================================================================================================================
wow_meta_page_custom_css() - add custom css to a specific page via Page-> Edit -> Custom CSS
=================================================================================================================
*/
function wow_meta_page_custom_css() {
	global $post;
	if (is_object($post)){
		$wow_post_id = $post->ID; 
		$wow_post_meta = get_post_meta($wow_post_id);
		if (!empty($wow_post_meta['wow-custom-css'][0])){
			echo '<style type="text/css">'.esc_attr( $wow_post_meta['wow-custom-css'][0] ) .'</style>';
		}
	}
}
add_action( 'wp_head', 'wow_meta_page_custom_css' );


/*
=================================================================================================================
wow_removeDemoModeLink() - Remove demo links and notices on Redux framework
=================================================================================================================
*/
function wow_removeDemoModeLink() {
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::get_instance(), 'plugin_metalinks'), null, 2 );
    }
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_action('admin_notices', array( ReduxFrameworkPlugin::get_instance(), 'admin_notices' ) );    
    }
}
add_action('init', 'wow_removeDemoModeLink');


/*
=================================================================================================================
wow_bg_repeat($item_id) - Adds background repeat options
=================================================================================================================
*/
function wow_bg_repeat($item_id,$meta_value){
		
	$selected=$meta_value;		
		
	$output = array (
		'0' 		=> '--Background Repeat--',
		'repeat' 	=> 'Repeat',
		'repeat-x' 	=> 'Repeat Horizontally',
		'repeat-y' 	=> 'Repeat Vertically',
		'no-repeat' => 'No Repeat',
	);
		
	foreach ($output as $key => $value){
		echo '<option value="'.esc_attr( $key ).'" '.selected($selected,$key ).'>' . esc_html( $value ) .'</option>';
	}
}	
	
/*
=================================================================================================================
wow_bg_position($item_id) - Adds background position options
=================================================================================================================
*/	
function wow_bg_position($item_id,$meta_value){
	
	$selected=$meta_value;	
	
	$output = array (
		'0' 		=> '--Background Position--',
		'left top'		=> 'Left Top',
		'left center'	=> 'Left Center',
		'left bottom'	=> 'Left Bottom',
		'right top'		=> 'Right Top',
		'right center'	=> 'Right Center',
		'right bottom'	=> 'Right Bottom',
		'center top'	=> 'Center Top',
		'center center' => 'Center Center',
		'center bottom' => 'Center Bottom',
	);
	
	foreach ($output as $key => $value){
		echo '<option value="'.esc_attr( $key ).'" '.selected($selected,$key ).'>' . esc_html( $value ) . '</option>';
	}

}

/*
=================================================================================================================
wow_bg_repeat($item_id) - Adds background repeat options
=================================================================================================================
*/
function wow_bg_size($item_id,$meta_value){
		
	$selected=$meta_value;		
		
	$output = array (
		'0' 		=> '--Background Size--',
		'auto' 	=> 'Auto',
		'cover' 	=> 'Cover',
		'contain' 	=> 'Contain',
	);
		
	foreach ($output as $key => $value){
		echo '<option value="'.esc_attr( $key ).'" '.selected($selected,$key ).'>' . esc_html( $value ) .'</option>';
	}
}	


/*
=================================================================================================================
wow_menu_columns($item_id) - Adds menu columns for mega menu in nav
=================================================================================================================
*/	
function wow_menu_columns($item_id,$meta_value){
	
	$selected=$meta_value;	
	
	$output = array (
		'12' 		=> '1',
		'6' 		=> '2',
		'4' 		=> '3',
		'3' 		=> '4',
		'2' 		=> '6',
	);
	
	foreach ($output as $key => $value){
		echo '<option value="'.esc_attr( $key ).'" '.selected($selected,$key ).'>'. esc_html( $value ).'</option>';
	}

}

/*
=================================================================================================================
wow_theme_options_anim() - Theme Options animations
=================================================================================================================
*/	
function wow_theme_options_anim($filter = "all", $none = true, $attention_seekers = true){
$return_wow_animations=array();

$all_wow_animations_none = 	array('0' => 'none');
$all_wow_animations_in =  array(
								'Bouncing Entrances' => array(
									'bounceIn' => 'bounceIn',
									'bounceInDown' => 'bounceInDown',
									'bounceInLeft' => 'bounceInLeft',
									'bounceInRight' => 'bounceInRight',
									'bounceInUp' => 'bounceInUp',

								),
								'Fading Entrances' => array(
									'fadeIn' => 'fadeIn',
									'fadeInDown' => 'fadeInDown',
									'fadeInDownBig' => 'fadeInDownBig',
									'fadeInLeft' => 'fadeInLeft',
									'fadeInLeftBig' => 'fadeInLeftBig',
									'fadeInRight' => 'fadeInRight',
									'fadeInRightBig' => 'fadeInRightBig',
									'fadeInUp' => 'fadeInUp',
									'fadeInUpBig' => 'fadeInUpBig',
								),
								'Flippers' => array(
									'flip' => 'flip',
									'flipInX' => 'flipInX',
									'flipInY' => 'flipInY',
								),
								'Lightspeed' => array(
									'lightSpeedIn' => 'lightSpeedIn',
								),
								'Rotating Entrances' => array(
									'rotateIn' => 'rotateIn',
									'rotateInDownLeft' => 'rotateInDownLeft',
									'rotateInDownRight' => 'rotateInDownRight',
									'rotateInUpLeft' => 'rotateInUpLeft',
									'rotateInUpRight' => 'rotateInUpRight',
								),
								'Sliding Entrances' => array(
									'slideInUp' => 'slideInUp',
									'slideInDown' => 'slideInDown',
									'slideInLeft' => 'slideInLeft',
									'slideInRight' => 'slideInRight',
								),
								'Zoom Entrances' => array(
									'zoomIn' => 'zoomIn',
									'zoomInDown' => 'zoomInDown',
									'zoomInLeft' => 'zoomInLeft',
									'zoomInRight' => 'zoomInRight',
									'zoomInUp' => 'zoomInUp',
								),
								'Specials' => array(
									'rollIn' => 'rollIn',
								),								

							);
$all_wow_animations_out =  array(
								'Bouncing Exits' => array(
									'bounceOut' => 'bounceOut',
									'bounceOutDown' => 'bounceOutDown',
									'bounceOutLeft' => 'bounceOutLeft',
									'bounceOutRight' => 'bounceOutRight',
									'bounceOutUp' => 'bounceOutUp',
								),
								'Fading Exits' => array(
									'fadeOut' => 'fadeOut',
									'fadeOutDown' => 'fadeOutDown',
									'fadeOutDownBig' => 'fadeOutDownBig',
									'fadeOutLeft' => 'fadeOutLeft',
									'fadeOutLeftBig' => 'fadeOutLeftBig',
									'fadeOutRight' => 'fadeOutRight',
									'fadeOutRightBig' => 'fadeOutRightBig',
									'fadeOutUp' => 'fadeOutUp',
									'fadeOutUpBig' => 'fadeOutUpBig',
								),
								'Flippers' => array(
									'flip' => 'flip',
									'flipOutX' => 'flipOutX',
									'flipOutY' => 'flipOutY',
								),
								'Lightspeed' => array(
									'lightSpeedOut' => 'lightSpeedOut',
								),
								'Rotating Exits' => array(
									'rotateOut' => 'rotateOut',
									'rotateOutDownLeft' => 'rotateOutDownLeft',
									'rotateOutDownRight' => 'rotateOutDownRight',
									'rotateOutUpLeft' => 'rotateOutUpLeft',
									'rotateOutUpRight' => 'rotateOutUpRight',
								),
								'Sliding Exits' => array(
									'slideOutUp' => 'slideOutUp',
									'slideOutDown' => 'slideOutDown',
									'slideOutLeft' => 'slideOutLeft',
									'slideOutRight' => 'slideOutRight',
								),
								'Zoom Exits' => array(
									'zoomOut' => 'zoomOut',
									'zoomOutDown' => 'zoomOutDown',
									'zoomOutLeft' => 'zoomOutLeft',
									'zoomOutRight' => 'zoomOutRight',
									'zoomOutUp' => 'zoomOutUp',
								),
								'Specials' => array(
									'hinge' => 'hinge',
									'rollOut' => 'rollOut',
								),								

							);							
$all_wow_animations_att =  array(
								'Attention Seekers' => array(
									'bounce' => 'bounce',
									'flash' => 'flash',
									'pulse' => 'pulse',
									'rubberBand' => 'rubberBand',
									'shake' => 'shake',
									'swing' => 'swing',
									'tada' => 'tada',
									'wobble' => 'wobble',
									'jello' => 'jello',
								),
						);				

	if($none == true){
		$return_wow_animations[]= $all_wow_animations_none;
	}
	
	if( $filter == "in"){
		$return_wow_animations[]= $all_wow_animations_in;
	}
	elseif($filter == "out"){
		
		$return_wow_animations[]= $all_wow_animations_out;
	}
	else{
		$return_wow_animations[]= $all_wow_animations_in;
		$return_wow_animations[]= $all_wow_animations_out;
		
	}
	
	if($attention_seekers == true){
		$return_wow_animations[]= $all_wow_animations_att;
	}
	
	foreach($return_wow_animations as $keys=>$values)
		if (is_array($values))
			{
			foreach($values as $key=>$value)
				{
					$return[$key] = $value;
				}
	
			}
		else{
			$return[$keys] = $values;
		}
	return $return;
}

/*
=================================================================================================================
wow_upload_types($existing_mimes=array()) - Allow specific file types upload in wordpress media uploader
=================================================================================================================
*/

function wow_upload_types($existing_mimes){
	$existing_mimes['woff'] = 'application/font/woff';
	$existing_mimes['ttf']  = 'application/x-font-ttf';
	$existing_mimes['eot']  = 'application/vnd.ms-fontobject';
	return $existing_mimes;
}
add_filter('upload_mimes', 'wow_upload_types');


	
/*
=================================================================================================================
wow_custom_fonts() - Allow users to upload a specific font to theme
=================================================================================================================
*/
function wow_custom_fonts(){
	global $wow_options;
	
	//font #1
	if (!empty($wow_options['custom-font-name'])){
		$wow_font_name = $wow_options['custom-font-name'];
		
		$wow_font_custom = array ();
		$wow_font_custom[] =  (!empty($wow_options['custom-font-woff']['url'])) ?  'src:url("'.esc_url( $wow_options['custom-font-woff']['url'] ).'")' : '';
		$wow_font_custom[] =  (!empty($wow_options['custom-font-ttf']['url']))  ?  'url("'.esc_url( $wow_options['custom-font-ttf']['url'] ).'")'  : '';
		$wow_font_custom[] =  (!empty($wow_options['custom-font-eot']['url']))  ?  'url("'.esc_url( $wow_options['custom-font-eot']['url'] ).'")' : '';
		
		$wow_font_src_clean = array_values(array_filter($wow_font_custom));
	 
		$wow_font_css_output = implode($wow_font_src_clean, ',').';';

		echo '
		<style type="text/css">
			@font-face{font-family:'.esc_attr( $wow_font_name ).';';
				echo $wow_font_css_output;
				echo 'font-weight: normal; font-style: normal}
		</style>';
	}	
	
	//font #2
	if (!empty($wow_options['custom-font-name1'])){
		$wow_font_name1 = $wow_options['custom-font-name1'];
		
		$wow_font_custom1 = array ();
		$wow_font_custom1[] =  (!empty($wow_options['custom-font-woff1']['url'])) ?  'src:url("'.esc_url( $wow_options['custom-font-woff1']['url'] ).'")' : '';
		$wow_font_custom1[] =  (!empty($wow_options['custom-font-ttf1']['url']))  ?  'url("'.esc_url( $wow_options['custom-font-ttf1']['url'] ).'")'  : '';
		$wow_font_custom1[] =  (!empty($wow_options['custom-font-eot1']['url']))  ?  'url("'.esc_url( $wow_options['custom-font-eot1']['url'] ).'")' : '';
		
		$wow_font_src_clean1 = array_values(array_filter($wow_font_custom1));
	 
		$wow_font_css_output1 = implode($wow_font_src_clean1, ',').';';

		echo '
		<style type="text/css">
			@font-face{font-family:'.esc_attr( $wow_font_name1 ).';';
				echo $wow_font_css_output1;
				echo 'font-weight: normal; font-style: normal}
		</style>';
	}	
	
	//font #3
	if (!empty($wow_options['custom-font-name2'])){
		$wow_font_name2 = $wow_options['custom-font-name2'];
		
		$wow_font_custom2 = array ();
		$wow_font_custom2[] =  (!empty($wow_options['custom-font-woff2']['url'])) ?  'src:url("'.esc_url( $wow_options['custom-font-woff2']['url'] ).'")' : '';
		$wow_font_custom2[] =  (!empty($wow_options['custom-font-ttf2']['url']))  ?  'url("'.esc_url( $wow_options['custom-font-ttf2']['url'] ).'")'  : '';
		$wow_font_custom2[] =  (!empty($wow_options['custom-font-eot2']['url']))  ?  'url("'.esc_url( $wow_options['custom-font-eot2']['url'] ).'")' : '';
		
		$wow_font_src_clean2 = array_values(array_filter($wow_font_custom2));
	 
		$wow_font_css_output2 = implode($wow_font_src_clean2, ',').';';

		echo '
		<style type="text/css">
			@font-face{font-family:'.esc_attr( $wow_font_name2 ).';';
				echo $wow_font_css_output2;
				echo 'font-weight: normal; font-style: normal}
		</style>';
	}
}
add_action('wp_head', 'wow_custom_fonts');


/*
=================================================================================================================
wow_admin_custom_fonts() - Add admin custom font
=================================================================================================================
*/
function wow_admin_custom_fonts(){
	global $wow_options;
	
	//font #1
	if (!empty($wow_options['custom-font-name'])){
		$wow_font_name = $wow_options['custom-font-name'];
		
		$wow_font_custom = array ();
		$wow_font_custom[] =  (!empty($wow_options['custom-font-woff']['url'])) ?  'src:url("'.esc_url( $wow_options['custom-font-woff']['url'] ).'")' : '';
		$wow_font_custom[] =  (!empty($wow_options['custom-font-ttf']['url']))  ?  'url("'.esc_url( $wow_options['custom-font-ttf']['url'] ).'")'  : '';
		$wow_font_custom[] =  (!empty($wow_options['custom-font-eot']['url']))  ?  'url("'.esc_url( $wow_options['custom-font-eot']['url'] ).'")' : '';
		
		$wow_font_src_clean = array_values(array_filter($wow_font_custom));
	 
		$wow_font_css_output = implode($wow_font_src_clean, ',').';';

		echo '
		<style type=\"text/css\">
			@font-face{font-family:'.esc_attr( $wow_font_name ).';';
				echo $wow_font_css_output;
				echo 'font-weight: normal; font-style: normal}
		</style>';
	}	
	
	//font #2
	if (!empty($wow_options['custom-font-name1'])){
		$wow_font_name1 = $wow_options['custom-font-name1'];
		
		$wow_font_custom1 = array ();
		$wow_font_custom1[] =  (!empty($wow_options['custom-font-woff1']['url'])) ?  'src:url("'.esc_url( $wow_options['custom-font-woff1']['url'] ).'")' : '';
		$wow_font_custom1[] =  (!empty($wow_options['custom-font-ttf1']['url']))  ?  'url("'.esc_url( $wow_options['custom-font-ttf1']['url'] ).'")'  : '';
		$wow_font_custom1[] =  (!empty($wow_options['custom-font-eot1']['url']))  ?  'url("'.esc_url( $wow_options['custom-font-eot1']['url'] ).'")' : '';
		
		$wow_font_src_clean1 = array_values(array_filter($wow_font_custom1));
	 
		$wow_font_css_output1 = implode($wow_font_src_clean1, ',').';';

		echo '
		<style type=\"text/css\">
			@font-face{font-family:'.esc_attr( $wow_font_name1 ).';';
				echo $wow_font_css_output1;
				echo 'font-weight: normal; font-style: normal}
		</style>';
	}	
	
	//font #3
	if (!empty($wow_options['custom-font-name2'])){
		$wow_font_name2 = $wow_options['custom-font-name2'];
		
		$wow_font_custom2 = array ();
		$wow_font_custom2[] =  (!empty($wow_options['custom-font-woff2']['url'])) ?  'src:url("'.esc_url( $wow_options['custom-font-woff2']['url'] ).'")' : '';
		$wow_font_custom2[] =  (!empty($wow_options['custom-font-ttf2']['url']))  ?  'url("'.esc_url( $wow_options['custom-font-ttf2']['url'] ).'")'  : '';
		$wow_font_custom2[] =  (!empty($wow_options['custom-font-eot2']['url']))  ?  'url("'.esc_url( $wow_options['custom-font-eot2']['url'] ).'")' : '';
		
		$wow_font_src_clean2 = array_values(array_filter($wow_font_custom2));
	 
		$wow_font_css_output2 = implode($wow_font_src_clean2, ',').';';

		echo '
		<style type=\"text/css\">
			@font-face{font-family:'.esc_attr( $wow_font_name2 ).';';
				echo $wow_font_css_output2;
				echo 'font-weight: normal; font-style: normal}
		</style>';
	}
}
add_action('admin_head', 'wow_admin_custom_fonts');



/*
=================================================================================================================
wow_footer_widgets - Get all footer widgets
=================================================================================================================
*/
function wow_footer_widgets(){
	global $wow_options;
	//footer widget(s)
	if(!empty($wow_options['footer-layout-rows'])){
	
		$counter = 0;
		for($i=1;$i<=$wow_options['footer-layout-rows'];$i++){
			
			if ( !empty($wow_options['footer-layout-rows'.$i]) && $wow_options['footer-layout-rows'.$i] != 'custom'){
			
				echo '<div class="vc_row vc_row-fluid row-eq-height">';
				
				$row_layouts=explode('+',$wow_options['footer-layout-rows'.$i]);
				
				if(count($row_layouts) > 0){
					for($j=0; $j<count($row_layouts); $j++){	
							
							$counter++;
							$widget_id = 'footer_'.$i.'_'.$counter;
							$get_widget_width = $row_layouts[$j];
							$widget_width = (is_int($get_widget_width)) ? 12 : $get_widget_width;
								
								echo '<div class="vc_column_container vc_col-lg-'.esc_attr( $widget_width ).' vc_col-md-'.esc_attr( $widget_width ).'  vc_col-xs-12">';
										echo '<div class="vc_column-inner ">';
											if ( is_active_sidebar( $widget_id ) ){
												dynamic_sidebar( esc_html( $widget_id ) );
											}
										echo '</div>';
								echo '</div>';	
							
					}
					$counter = 0;	
					
				}

				echo '</div>';	
		
			}			
			
			elseif (!empty($wow_options['footer-layout-rows'.$i]) && $wow_options['footer-layout-rows'.$i] == 'custom'){
			
				echo '<div class="vc_row vc_row-fluid row-eq-height">';
				
				$row_layouts=explode('+',$wow_options['footer-custom-layout-rows'.$i]);
				
				if(count($row_layouts) > 0){
					for($j=0; $j<count($row_layouts); $j++){	
							
							$counter++;
							$widget_id = 'footer_'.$i.'_'.$counter;
							$get_widget_width = $row_layouts[$j];
							$widget_width = (is_int($get_widget_width)) ? 12 : $get_widget_width;
	
								echo '<div class="vc_column_container vc_col-lg-'.esc_attr( $widget_width ).' vc_col-md-'.esc_attr( $widget_width ).' vc_col-xs-12">';
										echo '<div class="vc_column-inner ">';
											if ( is_active_sidebar( $widget_id ) ){
												dynamic_sidebar( esc_html( $widget_id ) );
											}
										echo '</div>';
								echo '</div>';								
					}
					$counter = 0;	
					
				}

				echo '</div>';	
		
			}
		
		}//end for
		
	}//end !empty footer-layout-rows
}

/*
=================================================================================================================
wow_body_google_font_load() - Enqueue all the font weights from google to head
=================================================================================================================
*/
function wow_body_google_font_load(){
	global $wow_options;
	
	if ( ( isset( $wow_options['ptypography'] ) && isset ( $wow_options['ptypography']['font-family'] ) )  || isset ( $wow_options['ptypography']['google']) ){
		
		$font_name = $wow_options['ptypography']['font-family'];
		$gFile = WOW_DIR . '/theme-options/ReduxCore/inc/fields/typography/googlefonts.php';
		$fonts = include $gFile;
		
		if (isset ($fonts[$font_name]['variants'])){
			foreach ($fonts[$font_name]['variants'] as $variants) {
				$final_variants[] = $variants['id'];
			}
	
			$implode_variants  = implode(',',$final_variants);
			$url = 'https://fonts.googleapis.com/css?family='.str_replace(' ','+',$font_name).':'.$implode_variants;
	
			wp_enqueue_style( 'ptypography' , $url , array(), NULL, 'all');
		}
		unset($final_variants);
	}

	if ( ( isset( $wow_options['bhtypography'] ) && isset ( $wow_options['bhtypography']['font-family'] ) )  || isset ( $wow_options['bhtypography']['google']) ){
		
		$font_name = $wow_options['bhtypography']['font-family'];
		$gFile = WOW_DIR . '/theme-options/ReduxCore/inc/fields/typography/googlefonts.php';
		$fonts = include $gFile;
		
		if (isset ($fonts[$font_name]['variants'])){
			foreach ($fonts[$font_name]['variants'] as $variants) {
				$final_variants[] = $variants['id'];
			}
	
			$implode_variants  = implode(',',$final_variants);
			$url = 'https://fonts.googleapis.com/css?family='.str_replace(' ','+',$font_name).':'.$implode_variants;
	
			wp_enqueue_style( 'bhtypography' , $url , array(), NULL, 'all');
		}
		unset($final_variants);
	}
	if ( ( isset( $wow_options['ctypography'] ) && isset ( $wow_options['ctypography']['font-family'] ) )  || isset ( $wow_options['ctypography']['google']) ){
		
		$font_name = $wow_options['ctypography']['font-family'];
		$gFile = WOW_DIR . '/theme-options/ReduxCore/inc/fields/typography/googlefonts.php';
		$fonts = include $gFile;
		
		if (isset ($fonts[$font_name]['variants'])){
			foreach ($fonts[$font_name]['variants'] as $variants) {
				$final_variants[] = $variants['id'];
			}
			
			$implode_variants  = implode(',',$final_variants);
			$url = 'https://fonts.googleapis.com/css?family='.str_replace(' ','+',$font_name).':'.$implode_variants;
	
			wp_enqueue_style( 'ctypograpghy' , $url , array(), NULL, 'all');
		}
		unset($final_variants);
	}	
	
	if ( ( isset( $wow_options['ctypography2'] ) && isset ( $wow_options['ctypography2']['font-family'] ) )  || isset ( $wow_options['ctypography2']['google']) ){
		
		$font_name = $wow_options['ctypography2']['font-family'];
		$gFile = WOW_DIR . '/theme-options/ReduxCore/inc/fields/typography/googlefonts.php';
		$fonts = include $gFile;
		
		if (isset ($fonts[$font_name]['variants'])){
			foreach ($fonts[$font_name]['variants'] as $variants) {
				$final_variants[] = $variants['id'];
			}
	
			$implode_variants  = implode(',',$final_variants);
			$url = 'https://fonts.googleapis.com/css?family='.str_replace(' ','+',$font_name).':'.$implode_variants;
	
			wp_enqueue_style( 'ctypograpghy2' , $url , array(), NULL, 'all');
		}
		unset($final_variants);
	}	
}
add_action('wp_enqueue_scripts', 'wow_body_google_font_load');

/*
=================================================================================================================
wow_preloader() - display a preloader until the page it's loaded
=================================================================================================================
*/
function wow_preloader() {
	
	global $wow_options;
	
	if ( $wow_options['preloader'] == 1 and !empty( $wow_options['preloader-animation'] ) ){
		
		
		$html_output = '';
		$html_output = '<div class="preloader-wrap">';
							
			if ($wow_options['preloader-animation'] == 'pulse'){
				$html_output .= '
					<div class="pulse">
						<span></span>
						<span></span>
						<span></span>
						<span></span>
						<span></span>
						<span></span>
						<span></span>
						<span></span>
						<span></span>
						<span></span>
						<span></span>
						<span></span>
						<span></span>
						<span></span>
						<span></span>
					</div>';
			}						
			if ($wow_options['preloader-animation'] == 'spinner'){
				$html_output .= '  
				 <div class="spinner">
					<i></i>
					<i></i>
					<i></i>
					<i></i>
					<i></i>
					<i></i>
					<i></i>
				  </div>';
			}			
			if ($wow_options['preloader-animation'] == 'unswerving'){
				$html_output .= '  
				  <div class=circles-holder>
					  <div class=circle-1>
						<div class=circle-2>
						  <div class=circle-3>
							<div class=circle-4>
							  <div class=circle-5>
								<div class=circle-6>
								  <div class=circle-7>
									<div class=circle-8>
									</div>
								  </div>
								</div>
							  </div>
							</div>
						  </div>
						</div>
					</div>
				  </div>';
			}
		
		$html_output .= '</div>';
		
		echo $html_output; //no need to sanitize as it only outputs static text/html
		
	}
	
}

/*
=================================================================================================================
wow_current_url() - output the current url
=================================================================================================================
*/
function wow_current_url(){
	$page_nr = get_query_var('paged');
	$pageURL = 'http';
	if( is_ssl() ) $pageURL .= "s";
	$pageURL .= "://";
	
	if( $_SERVER["SERVER_PORT"] != "80" ) {
		if ($page_nr < 1){
			$pageURL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"].$_SERVER["REQUEST_URI"];
		}
		elseif ($page_nr > 1){
			$pageURL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"].$_SERVER["REQUEST_URI"];
			$pageURL  = str_replace ('/page/'.$page_nr.'/','',$pageURL);
		}
		else{
			$pageURL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"].$_SERVER["REQUEST_URI"];
		}
	} 
	
	else {
		if ($page_nr < 1){
			$pageURL .= $_SERVER["SERVER_NAME"].$_SERVER["REQUEST_URI"];
		}
		elseif ($page_nr > 1){
			$pageURL .= $_SERVER["SERVER_NAME"].$_SERVER["REQUEST_URI"];
			$pageURL  = str_replace ('/page/'.$page_nr.'/','',$pageURL);
		}
		else{
			$pageURL .= $_SERVER["SERVER_NAME"].$_SERVER["REQUEST_URI"];
		}
	}
	return $pageURL;
}

/*
=================================================================================================================
wow_gap_portfolio() - add gap to portfolio items
=================================================================================================================
*/
function wow_gap_portfolio(){
	
	global $wow_options;
	
	$style = '.'.$wow_options['portfolio-style'];
	
	$css_output = '';
	
	$grid = $wow_options['grid_portfolio'] == '1/5' ? '1\/5' : $wow_options['grid_portfolio'];
	
	if ( is_page_template('portfolio.php') || is_tax('portfolio_category') ){
	
		if (!empty($wow_options['gap_portfolio'])){
			$gap = intval($wow_options['gap_portfolio']);
			$gap_2 = intval(round($gap/2));
			$gap_minus = intval(round($gap/2));
			$css_output.='<style type="text/css">';
				$css_output.= '.portfolio .vc_col-lg-'.esc_attr($grid).'.gap{padding-left:'.esc_attr($gap_2).'px; padding-right:'.esc_attr($gap_2).'px;}';
				$css_output.= '.portfolio .vc_col-lg-'.esc_attr($grid).'.gap{margin-bottom:'.esc_attr($gap).'px;}';
				$css_output.= '.portfolio'.esc_attr($style).'.gap .portfolio-grid{margin-left:-'.esc_attr($gap_minus).'px; margin-right:-'.esc_attr($gap_minus).'px;}';
			$css_output.='</style>';
		}
		else{
			$css_output.='<style type="text/css">';
				$css_output.= '.portfolio .vc_col-lg-'.esc_attr($grid).'{padding:0}';
				$css_output.= '.portfolio div[class*=\' vc_col-md-\']{padding:0}';
				$css_output.= '.portfolio div[class*=\' vc_col-sm-\']{padding:0}';
				$css_output.= '.portfolio div[class*=\' vc_col-xs-\']{padding:0}';
			$css_output.='</style>';
		}
	}
	
	if ( is_singular('portfolio') ){
		$css_output.='<style type="text/css">';
			$css_output.= '.portfolio .vc_col-lg-'.esc_attr($grid).'.gap{padding-left:0px; padding-right:0px;}';
			$css_output.= '.portfolio .vc_col-lg-'.esc_attr($grid).'{padding-left:0px; padding-right:0px;}';
			$css_output.= '.portfolio .vc_col-lg-'.esc_attr($grid).'.gap{margin-bottom:0px;}';
			$css_output.= '.portfolio'.esc_attr($style).'.gap{margin-left:0px; margin-right:0px;}';
		$css_output.='</style>';	
	}
	
	echo $css_output; //all data is escaped above

}
add_action('wp_head','wow_gap_portfolio');

/*
=================================================================================================================
wow_gap_blog() - add gap to blog posts
=================================================================================================================
*/
function wow_gap_blog(){
	
	global $wow_options;
	
	$style = '.'.$wow_options['blog_style'];
	
	$is_fancy = $wow_options['fancy_sidebar'] == 1 ? true : false;

	$css_output = $css_responsive_output = '';
	
	$grid = $wow_options['grid'] == '1/5' ? '1\/5' : $wow_options['grid'];

	$gap = ( !empty( $wow_options['gap'] ) ) ? intval($wow_options['gap']) : '';
	$gap_2 = ( !empty( $wow_options['gap'] ) ) ? intval(round($gap/2)) : '';
	
	//if gap is empty we set some padding between sidebar and posts
	if ( empty( $gap ) ){
		if ( $wow_options['blog_layout'] == 'left-sidebar' && !$is_fancy  ){
			$css_output.= '.is-blog-page.has-left-sidebar .posts-block'.esc_attr($style).' .vc_col-md-4.left_sidebar {padding-right:30px}';
		}
		elseif ( $wow_options['blog_layout'] == 'right-sidebar' && !$is_fancy  ){
			$css_output.= '.is-blog-page.has-right-sidebar .posts-block'.esc_attr($style).' .vc_col-md-4.right_sidebar {padding-left:30px}';
		}
		elseif ( $wow_options['blog_layout'] == 'both-sidebars' ){
			$css_output.= '.is-blog-page.has-right-sidebar .posts-block'.esc_attr($style).' .vc_col-md-3.right_sidebar {padding-left:30px;}';
			$css_output.= '.is-blog-page.has-left-sidebar .posts-block'.esc_attr($style).' .vc_col-md-3.left_sidebar {padding-right:30px;}';			
		}
	}
	
	if(!empty($wow_options['gap']) and $wow_options['blog_layout'] == 'no-sidebar' ){
		$css_output.= '.is-blog-page .posts-block .vc_col-lg-'.esc_attr($grid).'.gap{padding-left:'.esc_attr($gap_2).'px; padding-right:'.esc_attr($gap_2).'px;}';
		$css_output.= '.is-blog-page .posts-block .vc_col-lg-'.esc_attr($grid).'.gap{margin-bottom:'.esc_attr($gap).'px;}';
		$css_output.= '.is-blog-page .posts-block.style4 .vc_col-lg-'.esc_attr($grid).'.gap{padding-left:'.esc_attr($gap_2).'px; padding-right:'.esc_attr($gap_2).'px;}';
		$css_output.= '.is-blog-page .posts-block.style4 .vc_col-lg-'.esc_attr($grid).'.gap{margin-bottom:'.esc_attr($gap).'px;}';
		$css_output.= '.is-blog-page .posts-block'.esc_attr($style).'.gap{margin-left:-'.esc_attr($gap_2).'px; margin-right:-'.esc_attr($gap_2).'px;}';
		
		//for no sidebar we customize the gap on responsive also
		$css_responsive_output.= '.is-blog-page .posts-block .vc_col-lg-'.esc_attr($grid).'.gap{padding-left:'.esc_attr($gap_2).'px !important; padding-right:'.esc_attr($gap_2).'px !important;}';
		$css_responsive_output.= '.is-blog-page .posts-block .vc_col-lg-'.esc_attr($grid).'.gap{margin-bottom:'.esc_attr($gap).'px !important;}';
		$css_responsive_output.= '.is-blog-page .posts-block.style4 .vc_col-lg-'.esc_attr($grid).'.gap{padding-left:'.esc_attr($gap_2).'px !important; padding-right:'.esc_attr($gap_2).'px !important;}';
		$css_responsive_output.= '.is-blog-page .posts-block.style4 .vc_col-lg-'.esc_attr($grid).'.gap{margin-bottom:'.esc_attr($gap).'px !important;}';
		$css_responsive_output.= '.is-blog-page .posts-block'.esc_attr($style).'.gap{margin-left:-'.esc_attr($gap_2).'px !important; margin-right:-'.esc_attr($gap_2).'px !important}';
	}	
	
	elseif(!empty($wow_options['gap']) and $wow_options['blog_layout'] == 'left-sidebar'){
		$css_output.= '.is-blog-page .posts-block .vc_col-lg-'.esc_attr($grid).'.gap{padding-left:'.esc_attr($gap_2).'px; padding-right:'.esc_attr($gap_2).'px;}';
		$css_output.= '.is-blog-page .posts-block .vc_col-lg-'.esc_attr($grid).'.gap{margin-bottom:'.esc_attr($gap).'px;}';
		$css_output.= '.is-blog-page .posts-block.style4 .vc_col-lg-'.esc_attr($grid).'.gap{padding-left:'.esc_attr($gap_2).'px; padding-right:'.esc_attr($gap_2).'px;}';
		$css_output.= '.is-blog-page .posts-block.style4 .vc_col-lg-'.esc_attr($grid).'.gap{margin-bottom:'.esc_attr($gap).'px;}';
		$css_output.= '.is-blog-page.has-left-sidebar .posts-block'.esc_attr($style).'.gap{margin-left:0px; margin-right:-'.esc_attr($gap_2).'px;}';
		if ( !$is_fancy ){
			if ( $gap < 30 ){
				$css_output.= '.is-blog-page.has-left-sidebar .posts-block'.esc_attr($style).'.gap .vc_col-md-4.left_sidebar {padding-right:30px}';
			}
			else{
				$css_output.= '.is-blog-page.has-left-sidebar .posts-block'.esc_attr($style).'.gap .vc_col-md-4.left_sidebar {padding-right:'.esc_attr($gap_2).'px;}';
			}
		}
		else{
			$css_output.= 'body.is-blog-page.has-left-fancy-sidebar .blog-start{padding-left:'.esc_attr($gap_2).'px;}';
		}
	}
	
	elseif(!empty($wow_options['gap']) and $wow_options['blog_layout'] == 'right-sidebar'){
		$css_output.= '.is-blog-page .posts-block .vc_col-lg-'.esc_attr($grid).'.gap{padding-left:'.esc_attr($gap_2).'px; padding-right:'.esc_attr($gap_2).'px;}';
		$css_output.= '.is-blog-page .posts-block .vc_col-lg-'.esc_attr($grid).'.gap{margin-bottom:'.esc_attr($gap).'px;}';		
		$css_output.= '.is-blog-page .posts-block.style4 .vc_col-lg-'.esc_attr($grid).'.gap{padding-left:'.esc_attr($gap_2).'px; padding-right:'.esc_attr($gap_2).'px;}';
		$css_output.= '.is-blog-page .posts-block.style4 .vc_col-lg-'.esc_attr($grid).'.gap{margin-bottom:'.esc_attr($gap).'px;}';
		$css_output.= '.is-blog-page.has-right-sidebar .posts-block'.esc_attr($style).'.gap{margin-left:-'.esc_attr($gap_2).'px; margin-right:0px;}';	
		if ( !$is_fancy ){
			if ( $gap < 30 ){
				$css_output.= '.is-blog-page.has-right-sidebar .posts-block'.esc_attr($style).'.gap .vc_col-md-4.right_sidebar {padding-left:30px}';
			}			
			else {
				$css_output.= '.is-blog-page.has-right-sidebar .posts-block'.esc_attr($style).'.gap .vc_col-md-4.right_sidebar {padding-left:'.esc_attr($gap_2).'px;}';
			}
		}
		else{
			$css_output.= 'body.is-blog-page.has-right-fancy-sidebar .blog-start{padding-right:'.esc_attr($gap_2).'px;}';
		}
	}		
	
	elseif(!empty($wow_options['gap']) and $wow_options['blog_layout'] == 'both-sidebars'){
		$css_output.= '.is-blog-page .posts-block .vc_col-lg-'.esc_attr($grid).'.gap{padding-left:'.esc_attr($gap_2).'px; padding-right:'.esc_attr($gap_2).'px;}';
		$css_output.= '.is-blog-page .posts-block .vc_col-lg-'.esc_attr($grid).'.gap{margin-bottom:'.esc_attr($gap).'px;}';		
		$css_output.= '.is-blog-page .posts-block.style4 .vc_col-lg-'.esc_attr($grid).'.gap{padding-left:'.esc_attr($gap_2).'px; padding-right:'.esc_attr($gap_2).'px;}';
		$css_output.= '.is-blog-page .posts-block.style4 .vc_col-lg-'.esc_attr($grid).'.gap{margin-bottom:'.esc_attr($gap).'px;}';
		$css_output.= '.is-blog-page.has-right-sidebar .posts-block'.esc_attr($style).'.gap{margin-left:0px; margin-right:0px;}';
		if ( $gap < 15 ){
			$css_output.= '.is-blog-page.has-right-sidebar .posts-block'.esc_attr($style).'.gap .vc_col-md-3.right_sidebar {padding-left:30px;}';
			$css_output.= '.is-blog-page.has-left-sidebar .posts-block'.esc_attr($style).'.gap .vc_col-md-3.left_sidebar {padding-right:30px;}';
		}
		else{
			$css_output.= '.is-blog-page.has-right-sidebar .posts-block'.esc_attr($style).'.gap .vc_col-md-3.right_sidebar {padding-left:'.esc_attr($gap).'px;}';
			$css_output.= '.is-blog-page.has-left-sidebar .posts-block'.esc_attr($style).'.gap .vc_col-md-3.left_sidebar {padding-right:'.esc_attr($gap).'px;}';
		}

	}
	
	else{
		$css_output.= '.is-blog-page .posts-block .vc_col-lg-'.esc_attr($grid).'{padding:0}';
		$css_output.= '.is-blog-page .posts-block.style4 .vc_col-lg-'.esc_attr($grid).'{padding:0}';
		$css_output.= '.is-blog-page .posts-block div[class*=\' vc_col-md-\']{padding:0}';
		$css_output.= '.is-blog-page .posts-block div[class*=\' vc_col-sm-\']{padding:0}';
		$css_output.= '.is-blog-page .posts-block div[class*=\' vc_col-xs-\']{padding:0}';
	}
	
	echo '<style type="text/css">@media (min-width: 1201px) {'.$css_output.' } </style>'; //all data is escaped above
	echo '<style type="text/css">@media (max-width: 1200px) {'.$css_responsive_output.' } </style>'; //all data is escaped above
}
add_action('wp_head','wow_gap_blog');

/*
=================================================================================================================
wow_show_portfolio_filter() - Display the portfolio filter on portfolio pages
=================================================================================================================
*/
function wow_show_portfolio_filter(){

	global $wow_options;

	//we create the html list for isotope sorting and only display it if selected from theme options
	if ($wow_options['show_filter'] == '1'){
		$wow_filter_li='<li><button class="themecolor_bg" data-filter="">'.esc_html__( 'All', 'infinito' ).'</button></li>';
		$wow_filter_ul = $wow_filter_li_array = array();

		global $wp_query,$wow_filter_ul,$post,$paged;
		query_posts( array('post_type' => array( 'portfolio' ),'posts_per_page' => intval( $wow_options['per_page_portfolio'] ), 'paged'=>$paged, 'orderby' => $wow_options['order_by_portfolio'], 'order' => $wow_options['order_portfolio'] ));
		if( have_posts() ) {
			while( have_posts() ) {
			the_post();
				$wow_term_list = wp_get_post_terms($post->ID, 'portfolio_category', array("fields" => "all"));
				foreach($wow_term_list as $wow_term){
					if(!isset($wow_filter_li_array[0][$wow_term->term_id])){
						$wow_filter_li.='<li><button class="themecolor_bg" data-filter=".filter-term-'.esc_attr($wow_term->term_id).'">'.esc_attr($wow_term->name).'</button></li>';
						$wow_filter_li_array[0][$wow_term->term_id]=1;
					}	
				}		  
			}
		}
		wp_reset_query();

		if (!is_tax('portfolio_category')){
			$wow_filter_ul.= '<ul class="filter-portfolio-element iso-filters button-group align_center"  data-filter-group="">';
				$wow_filter_ul.= $wow_filter_li;
			$wow_filter_ul.= "</ul>";
		}

		wp_enqueue_script( 'isotope');
		wp_enqueue_script( 'portfolio_init');
	}
}

/*
=================================================================================================================
wow_page_fancy_overlay_css() - output custom css for fancy hover effects on portfolio and blog pages
=================================================================================================================
*/
function wow_page_fancy_overlay_css(){
	
	global $wow_options;
	$css_output = '';
	
	//lily efect
	if ($wow_options['style4_blog_hover'] == 'lily' || $wow_options['style4_hover'] == 'lily'){
	}
	
	//honey efect	
	if ($wow_options['style4_blog_hover'] == 'honey' || $wow_options['style4_hover'] == 'honey' ){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-honey figcaption::before{background:#ffc600 }';
			$css_output.= 'figure.effect-honey p{display:none;}';
		}
		else{
			$css_output.= 'figure.effect-honey figcaption::before{background:'.esc_attr($wow_options['theme-color1']).' }';
			$css_output.= 'figure.effect-honey p{display:none;}';
		}
	}


	//layla efect
	if ($wow_options['style4_blog_hover'] == 'layla' || $wow_options['style4_hover'] == 'layla'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-layla figcaption::before{border-top: 1px solid #ffc600 ; border-bottom: 1px solid #ffc600 ;}';
			$css_output.= 'figure.effect-layla figcaption::after {border-left: 1px solid #ffc600 ; border-right: 1px solid #ffc600 ;}';
		}
		else{
			$css_output.= 'figure.effect-layla figcaption::before{border-top: 1px solid '.esc_attr($wow_options['theme-color1']).' ; border-bottom: 1px solid '.esc_attr($wow_options['theme-color1']).' ;}';
			$css_output.= 'figure.effect-layla figcaption::after {border-left: 1px solid '.esc_attr($wow_options['theme-color1']).' ; border-right: 1px solid '.esc_attr($wow_options['theme-color1']).' ;}';
		}
	}	
	
	//oscar efect
	if ($wow_options['style4_blog_hover'] == 'oscar' || $wow_options['style4_hover'] == 'oscar'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-oscar figcaption::before{border: 1px solid #ffc600 }';
		}
		else{
			$css_output.= 'figure.effect-oscar figcaption::before{border: 1px solid '.esc_attr($wow_options['theme-color1']).' }';
		}
	}	
	
	//marley efect
	if ($wow_options['style4_blog_hover'] == 'marley' || $wow_options['style4_hover'] == 'marley'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-marley h2::after{background: #ffc600 }';
		}
		else{
			$css_output.= 'figure.effect-marley h2::after{background: '.esc_attr($wow_options['theme-color1']).' }';
		}
	}
	
	//ruby efect
	if ($wow_options['style4_blog_hover'] == 'ruby' || $wow_options['style4_hover'] == 'ruby'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-ruby p{border: 1px solid #ffc600 }';
		}
		else{
			$css_output.= 'figure.effect-ruby p{border: 1px solid '.esc_attr($wow_options['theme-color1']).' }';
		}
	}		
	
	//roxy efect
	if ($wow_options['style4_blog_hover'] == 'roxy' || $wow_options['style4_hover'] == 'roxy'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-roxy figcaption::before{border: 1px solid #ffc600 }';
		}
		else{
			$css_output.= 'figure.effect-roxy figcaption::before{border: 1px solid '.esc_attr($wow_options['theme-color1']).' }';
		}
	}
	
	//bubba efect
	if ($wow_options['style4_blog_hover'] == 'bubba' || $wow_options['style4_hover'] == 'bubba'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-bubba figcaption::before{border-top: 1px solid #ffc600 ; border-bottom: 1px solid #ffc600 ;}';
			$css_output.= 'figure.effect-bubba figcaption::after {border-left: 1px solid #ffc600 ; border-right: 1px solid #ffc600 ;}';
		}
		else{
			$css_output.= 'figure.effect-bubba figcaption::before{border-top: 1px solid '.esc_attr($wow_options['theme-color1']).' ; border-bottom: 1px solid '.esc_attr($wow_options['theme-color1']).' ;}';
			$css_output.= 'figure.effect-bubba figcaption::after {border-left: 1px solid '.esc_attr($wow_options['theme-color1']).' ; border-right: 1px solid '.esc_attr($wow_options['theme-color1']).' ;}';
		}
	}	

	//romeo efect
	if ($wow_options['style4_blog_hover'] == 'romeo' || $wow_options['style4_hover'] == 'romeo'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-romeo figcaption::before, figure.effect-romeo figcaption::after{background: #ffc600 ;}';
		}
		else{
			$css_output.= 'figure.effect-romeo figcaption::before, figure.effect-romeo figcaption::after{background: '.esc_attr($wow_options['theme-color1']).' ;}';
		}
	}
	
	//dexter efect
	if ($wow_options['style4_blog_hover'] == 'dexter' || $wow_options['style4_hover'] == 'dexter'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-dexter:hover figcaption::after{border: 1px solid #ffc600 ;}';
		}
		else{
			$css_output.= 'figure.effect-dexter:hover figcaption::after{border: 1px solid '.esc_attr($wow_options['theme-color1']).' ;}';
		}
	}	
	
	//sarah efect
	if ($wow_options['style4_blog_hover'] == 'sarah' || $wow_options['style4_hover'] == 'sarah'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-sarah h2::after{background: #ffc600 ;}';
		}
		else{
			$css_output.= 'figure.effect-sarah h2::after{background: '.esc_attr($wow_options['theme-color1']).' ;}';
		}
	}
	
	//chico efect
	if ($wow_options['style4_blog_hover'] == 'chico' || $wow_options['style4_hover'] == 'chico'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-chico figcaption::before{border: 1px solid #ffc600 }';
		}
		else{
			$css_output.= 'figure.effect-chico figcaption::before{border: 1px solid '.esc_attr($wow_options['theme-color1']).' }';
		}
	}	
	
	//milo efect
	if ($wow_options['style4_blog_hover'] == 'milo' || $wow_options['style4_hover'] == 'milo'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-milo p{border-color: #ffc600 }';
		}
		else{
			$css_output.= 'figure.effect-milo p{border-color: '.esc_attr($wow_options['theme-color1']).' !important }';
		}
	}	
	
	//hera efect
	if ($wow_options['style4_blog_hover'] == 'hera' || $wow_options['style4_hover'] == 'hera'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-hera figcaption::before{border: 2px solid #ffc600 }';
		}
		else{
			$css_output.= 'figure.effect-hera figcaption::before{border: 2px solid '.esc_attr($wow_options['theme-color1']).' }';
		}
	}	
	
	//phoebe efect
	if ($wow_options['style4_blog_hover'] == 'phoebe' || $wow_options['style4_hover'] == 'phoebe'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-phoebe p a {background: #ffc600 }';
		}
		else{
			$css_output.= 'figure.effect-phoebe p a {background:'.esc_attr($wow_options['theme-color1']).' }';
		}
	}	

	//jazz efect
	if ($wow_options['style4_blog_hover'] == 'jazz' || $wow_options['style4_hover'] == 'jazz'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-jazz figcaption::after{border-top: 1px solid #ffc600 ; border-bottom: 1px solid #ffc600 ;}';	
		}			
		else{
			$css_output.= 'figure.effect-jazz figcaption::after{border-top: 1px solid '.esc_attr($wow_options['theme-color1']).' ; border-bottom: 1px solid '.esc_attr($wow_options['theme-color1']).' ;}';
		}
	}		
	
	//lexi efect
	if ($wow_options['style4_blog_hover'] == 'lexi' || $wow_options['style4_hover'] == 'lexi'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-lexi figcaption::before{border: 2px solid #ffc600 }';
		}			
		else{
			$css_output.= 'figure.effect-lexi figcaption::before{border: 2px solid '.esc_attr($wow_options['theme-color1']).' }';
		}
	}		
	
	//lexi efect
	if ($wow_options['style4_blog_hover'] == 'goliath' || $wow_options['style4_hover'] == 'goliath'){
		if (!$wow_options['theme-color1']){
			$css_output.= 'figure.effect-goliath p{background: #ffc600}';
		}			
		else{
			$css_output.= 'figure.effect-goliath p{background: '.esc_attr($wow_options['theme-color1']).' }';
		}
	}	

	echo '<style type="text/css">'.$css_output.'</style>';
	
}
add_action('wp_head','wow_page_fancy_overlay_css'); //all data is escaped above

   
/*
=================================================================================================================
wow_adjust_brightness() - adjust the brightness up/down from a given color
=================================================================================================================
*/
function wow_adjust_brightness($hex, $steps) {
    
	// Steps should be between -255 and 255. Negative = darker, positive = lighter
    $steps = max(-255, min(255, $steps));

    // Normalize into a six character long hex string
    $hex = str_replace('#', '', $hex);
    if (strlen($hex) == 3) {
        $hex = str_repeat(substr($hex,0,1), 2).str_repeat(substr($hex,1,1), 2).str_repeat(substr($hex,2,1), 2);
    }

    // Split into three parts: R, G and B
    $color_parts = str_split($hex, 2);
    $return = '#';

    foreach ($color_parts as $color) {
        $color   = hexdec($color); // Convert to decimal
        $color   = max(0,min(255,$color + $steps)); // Adjust color
        $return .= str_pad(dechex($color), 2, '0', STR_PAD_LEFT); // Make two char hex code
    }

    return $return;
}

/*
=================================================================================================================
wow_output_3d_style() - output the 3d style text via css
=================================================================================================================
*/
function wow_output_3d_style($color){

	$hex = str_replace('#', '', $color);
	if (strlen($hex) == 3) {
        $hex = str_repeat(substr($hex,0,1), 2).str_repeat(substr($hex,1,1), 2).str_repeat(substr($hex,2,1), 2);
    }
	
	//break up the color in its RGB components
	$r = hexdec(substr($hex,0,2));
	$g = hexdec(substr($hex,2,2));
	$b = hexdec(substr($hex,4,2));
	
	$color = str_replace('#', '', $color);
	if (strlen($color) == 3) {
        $color = str_repeat(substr($color,0,1), 2).str_repeat(substr($color,1,1), 2).str_repeat(substr($color,2,1), 2);
    }
	$color = '#'.$color;
		
	//do simple weighted avarage
	//
	//(This might be overly simplistic as different colors are perceived
	// differently. That is a green of 128 might be brighter than a red of 128.
	
	if(($r > 217 and  $g > 217 and $b > 217) and ($r + $g + $b > 653) ){
		//white lo light grey
		return '{
			text-shadow: 0 1px 0 rgb(204,204,204), 0 2px 0 rgb(201,201,201), 0 3px 0 rgb(187,187,187), 0 4px 0 rgb(185,185,185), 0 5px 0 rgb(170,170,170), 0 6px 1px rgba(0,0,0,0.0980392), 0 0 5px rgba(0,0,0,0.0980392), 0 1px 3px rgba(0,0,0,0.298039), 0 3px 5px rgba(0,0,0,0.2), 0 5px 10px rgba(0,0,0,0.247059), 0 10px 10px rgba(0,0,0,0.2), 0 20px 20px rgba(0,0,0,0.14902);
		}';	
	}
	elseif(($r < 51 and  $g < 51 and $b < 51) and ($r + $g + $b < 154)){
		//black to dark grey
		return '{
			text-shadow: 
			0 1px 0 #373737, 
			0 2px 0 #343434, 
			0 3px 0 #2a2a2a, 
			0 4px 0 #232323, 
			0 5px 0 #161616, 
			0 6px 1px rgba(0,0,0,0.4980392),
			0 0 5px rgba(0,0,0,0.1980392), 
			0 1px 3px rgba(0,0,0,0.398039), 
			0 3px 5px rgba(0,0,0,0.4), 
			0 5px 10px rgba(0,0,0,0.347059), 
			0 10px 10px rgba(0,0,0,0.4), 
			0 20px 20px rgba(0,0,0,0.24902);
		}';	
	}
	elseif($r + $g + $b > 382){
		//light color case
		$darker_color = wow_adjust_brightness($color, -230);
		return '{
			text-shadow:
			0 1px 0 '.wow_adjust_brightness($color, -70).',
			0 2px 0 '.wow_adjust_brightness($color, -90).',
			0 3px 0 '.wow_adjust_brightness($color, -120).',
			0 4px 0 '.wow_adjust_brightness($color, -150).',
			0 5px 0 '.wow_adjust_brightness($color, -180).',
			0 6px 1px '.wow_hex2rgba($darker_color, $alpha = .1).',
			0 5px '.wow_hex2rgba($darker_color, $alpha = .1).',
			0 1px 3px '.wow_hex2rgba($darker_color, $alpha = .3).',
			0 3px 5px '.wow_hex2rgba($darker_color, $alpha = .2).',
			0 5px 10px '.wow_hex2rgba($darker_color, $alpha = .25).',
			0 10px 10px '.wow_hex2rgba($darker_color, $alpha = .2).',
			0 20px 20px '.wow_hex2rgba($darker_color, $alpha = .15).';
		}';	
	}
	else{
		//dark color case
		$lighter_color = wow_adjust_brightness($color, 130);
		return '{
			text-shadow:
			0 1px 0 '.wow_adjust_brightness($color, 70).',
			0 2px 0 '.wow_adjust_brightness($color, 90).',
			0 3px 0 '.wow_adjust_brightness($color, 120).',
			0 4px 0 '.wow_adjust_brightness($color, 150).',
			0 5px 0 '.wow_adjust_brightness($color, 180).',
			0 6px 1px '.wow_hex2rgba($lighter_color, $alpha = .1).',
			0 5px '.wow_hex2rgba($lighter_color, $alpha = .1).',
			0 1px 3px '.wow_hex2rgba($lighter_color, $alpha = .3).',
			0 3px 5px '.wow_hex2rgba($lighter_color, $alpha = .2).',
			0 5px 10px '.wow_hex2rgba($lighter_color, $alpha = .25).',
			0 10px 10px '.wow_hex2rgba($lighter_color, $alpha = .2).',
			0 20px 20px '.wow_hex2rgba($lighter_color, $alpha = .15).';
		}';
	}
	
}


/*
=================================================================================================================
wow_output_single_portfolio_image() - Ouput the portfolio single image as a background via custom css code
=================================================================================================================
*/
function wow_output_single_portfolio_image( $image_src ){
	
	$meta = get_post_meta(wow_get_the_post_id());	
	$repeat = ( !empty( $meta['wow-repeat-image'][0] )  &&  $meta['wow-repeat-image'][0] == 'repeat' ) ? 'background-repeat:repeat; background-size:auto;' : 'background-repeat:no-repeat; background-size:cover;background-position: center;';
		echo 
		'<style type="text/css">
			body.postid-'.esc_attr(wow_get_the_post_id()).' .portfolio-single .image_wrapper.single{ background:url('.esc_url($image_src[0]).');'.esc_attr( $repeat ).' }
		</style>';
	
}

/*
=================================================================================================================
wow_custom_header_bg() - Ouput the custom background for header via custom css code
=================================================================================================================
*/
function wow_custom_header_bg(){
	
	//post meta
	$meta 		= get_post_meta(wow_get_the_post_id());

	$bg_color 		= (!empty($meta['wow-page-subheader-color'][0])) 			? $meta['wow-page-subheader-color'][0] : '';
	$bg_image 		= (!empty($meta['wow-page-subheader-image'][0])) 			? $meta['wow-page-subheader-image'][0] : '';
	$bg_repeat 		= (!empty($meta['wow-page-subheader-bg-repeat'][0])) 		? $meta['wow-page-subheader-bg-repeat'][0] : '';
	$bg_size 		= (!empty($meta['wow-page-subheader-bg-cover'][0])) 		? $meta['wow-page-subheader-bg-cover'][0] : '';
	$bg_attachment  = (!empty($meta['wow-page-subheader-bg-attachment'][0]))    ? $meta['wow-page-subheader-bg-attachment'][0] : '';
	$bg_position 	= (!empty($meta['wow-page-subheader-bg-position'][0])) 		? $meta['wow-page-subheader-bg-position'][0] : '';

	//background color and/or image
	if     (  $bg_color  and  $bg_image )  { $bg_color_echo = 'background: '.$bg_color.' url('.$bg_image.');';  }
	elseif (  $bg_color  and !$bg_image )  { $bg_color_echo = 'background-color: '.$bg_color.'; background-image:none;';  }
	elseif ( !$bg_color  and  $bg_image )  { $bg_color_echo = 'background: url('.$bg_image.');';  }
	elseif ( !$bg_color  and !$bg_image )  { $bg_color_echo = '';  }

	if ( !empty($bg_image) || !empty($bg_color) ){

		//background repeat
		$bg_repeat_echo 	= (!empty($bg_repeat)) ? 'background-repeat:'.$bg_repeat.';' : '';

		//background size
		$bg_size_echo 		= (!empty($bg_size)) ? 'background-size:'.$bg_size.';' : '';

		//background attachment
		$bg_attachment_echo = (!empty($bg_attachment)) ? 'background-attachment:'.$bg_attachment.';' : '';

		//background attachment
		$bg_position_echo 	= (!empty($bg_position)) ? 'background-position:'.$bg_position.';' : '';

			
		
		echo 
			'<style type="text/css">
				.horizontal-header.not-home header,  
				.header-wrap-vertical #wrap > .header_breadcrumb  { '.esc_attr( $bg_color_echo ), esc_attr( $bg_repeat_echo ), esc_attr( $bg_size_echo ), esc_attr( $bg_attachment_echo ), esc_attr( $bg_position_echo ).' }
			</style>';
	}
}


/*
=================================================================================================================
wow_custom_page_bg() - Ouput the custom background for page via custom css code
=================================================================================================================
*/
function wow_custom_page_bg(){
	
	global $wow_options;
	$page_body='';	
	//post meta
	$meta 		= get_post_meta(wow_get_the_post_id());

	$bg_color 		= (!empty($meta['wow-page-body-color'][0])) 			? $meta['wow-page-body-color'][0] : '';
	$bg_image 		= (!empty($meta['wow-page-body-image'][0])) 			? $meta['wow-page-body-image'][0] : '';
	$bg_repeat 		= (!empty($meta['wow-page-body-bg-repeat'][0])) 		? $meta['wow-page-body-bg-repeat'][0] : '';
	$bg_size 		= (!empty($meta['wow-page-body-bg-cover'][0])) 		    ? $meta['wow-page-body-bg-cover'][0] : '';
	$bg_attachment  = (!empty($meta['wow-page-body-bg-attachment'][0]))     ? $meta['wow-page-body-bg-attachment'][0] : '';
	$bg_position 	= (!empty($meta['wow-page-body-bg-position'][0])) 	    ? $meta['wow-page-body-bg-position'][0] : '';

	//background color and/or image
	if     (  $bg_color  and  $bg_image )  { $bg_color_echo = 'background: '.$bg_color.' url('.$bg_image.');';  }
	elseif (  $bg_color  and !$bg_image )  { $bg_color_echo = 'background-color: '.$bg_color.'; background-image:none;';  }
	elseif ( !$bg_color  and  $bg_image )  { $bg_color_echo = 'background: url('.$bg_image.');';  }
	elseif ( !$bg_color  and !$bg_image )  { $bg_color_echo = '';  }

	if ( !empty($bg_image) || !empty($bg_color) || !empty( $wow_options['body-bg']['background-image'] )  || !empty( $wow_options['body-bg']['background-color']) ){

		$page_body = '#page-body{ background:transparent; background-color:transparent }';
	
		//background repeat
		$bg_repeat_echo 	= (!empty($bg_repeat)) ? 'background-repeat:'.$bg_repeat.';' : '';

		//background size
		$bg_size_echo 		= (!empty($bg_size)) ? 'background-size:'.$bg_size.';' : '';

		//background attachment
		$bg_attachment_echo = (!empty($bg_attachment)) ? 'background-attachment:'.$bg_attachment.';' : '';

		//background attachment
		$bg_position_echo 	= (!empty($bg_position)) ? 'background-position:'.$bg_position.';' : '';

		echo 
			'<style type="text/css">
				body{ '.esc_attr( $bg_color_echo ), esc_attr( $bg_repeat_echo ), esc_attr( $bg_size_echo ), esc_attr( $bg_attachment_echo ), esc_attr( $bg_position_echo ).' }
				'.$page_body.'
			</style>';
	}
}

/*
=================================================================================================================
wow_abs_header() - Remove the background from header and make the header absolute
=================================================================================================================
*/
function wow_abs_header(){
	
	global $wow_options;
	
	//post meta
	$meta 		= get_post_meta(wow_get_the_post_id());
	
	if ( !empty( $meta['wow-abs-header'][0] ) and $meta['wow-abs-header'][0] == 'yes' ){
	
	$allowed_layouts = in_array($wow_options['header-layout'], array('header-one','header-one-a','header-two','header-two-a','header-three','header-four','header-five','header-five-a'));
	$padding_top = !empty( $wow_options['header-padding-top']['padding-top'] ) && $allowed_layouts ? 'padding-top:'.$wow_options['header-padding-top']['padding-top'].';' : '';
	
		if ( $allowed_layouts ){
	
			echo '<style type="text/css">
			.absolute-header.not-home header{ background:none; position: relative; z-index:2; margin-top:0; padding-top:0; padding-bottom:0 !important } 
			.absolute-header.horizontal-header.not-home header .header-inner{ position:absolute; width:100%;'.esc_attr( $padding_top ).' } @media (max-width: 1200px) { body.header-wrap-horizontal header { padding-top: 0; } body.header-wrap-horizontal header .header-inner { padding-top: 50px; } }
			
			@media (max-width: 1200px) {
				.absolute-header.not-home header{ z-index:100001 }
				.absolute-header.horizontal-header.not-home header .header-inner{
					margin-top: 0;
					padding-top:50px
				}
				.top_responsive_menu.header-overlay.horizontal-header.not-home header,
				.short_responsive_menu.header-overlay.horizontal-header.not-home header,
				.side_responsive_menu.header-overlay.horizontal-header.not-home header{
					padding-top:0
				}			
				.top_responsive_menu.header-overlay.horizontal-header.not-home header .header-inner,
				.short_responsive_menu.header-overlay.horizontal-header.not-home header .header-inner,
				.side_responsive_menu.header-overlay.horizontal-header.not-home header .header-inner{
					margin-top:50px
					padding-top:0
				}			
				.top_responsive_menu.header-overlay.horizontal-header.full-abs-bg.not-home header nav.menu{
					margin-top:0
				}
				#wrap {
					z-index:100000; 
					position:relative 
				}

			}
			</style>';
		}
	}
}


/*
=================================================================================================================
wow_fancy_sidebar() - output css for fancy sidebar
=================================================================================================================
*/
function wow_fancy_sidebar(){
	
	global $wow_options;
	
	//vertical layouts
	$wow_vertical_layout   = in_array($wow_options['header-layout'],      array('header-seven','header-eight','header-nine','header-ten')); 
	
	//post meta
	$wow_post_meta = get_post_meta(wow_get_the_post_id());
	$blog_single_layout = ( !empty($wow_post_meta['wow-blog-single-layout'][0]) &&  $wow_post_meta['wow-blog-single-layout'][0] != 'default' ) ? $wow_post_meta['wow-blog-single-layout'][0] : $wow_options['blog_single_layout'];

	//corner colors for left sidebar on blog page
	$fls_cl_blog = ( !empty ( $wow_options['fls_cl_blog'] ) ) ? 'border-color: transparent '.esc_attr($wow_options['fls_cl_blog']).' '.esc_attr($wow_options['fls_cl_blog']).' transparent;' : 'border-color: transparent #e3e3e3 #e3e3e3 transparent;' ;
	$fls_cr_blog = ( !empty ( $wow_options['fls_cr_blog'] ) ) ? 'border-color: transparent transparent '.esc_attr($wow_options['fls_cr_blog']).' '.esc_attr($wow_options['fls_cr_blog']).';' : 'border-color: transparent transparent #e3e3e3 #e3e3e3 ;' ;	
	
	//corner colors for right sidebar on blog page
	$frs_cl_blog = ( !empty ( $wow_options['frs_cl_blog'] ) ) ? 'border-color: transparent '.esc_attr($wow_options['frs_cl_blog']).' '.esc_attr($wow_options['frs_cl_blog']).' transparent;' : 'border-color: transparent #e3e3e3 #e3e3e3 transparent;' ;
	$frs_cr_blog = ( !empty ( $wow_options['frs_cr_blog'] ) ) ? 'border-color: transparent transparent '.esc_attr($wow_options['frs_cr_blog']).' '.esc_attr($wow_options['frs_cr_blog']).';' : 'border-color: transparent transparent #e3e3e3 #e3e3e3 ;' ;
	
	//corner colors for left sidebar on blog single
	$fls_cl_blog_single = ( !empty ( $wow_options['fls_cl_blog_single'] ) ) ? 'border-color: transparent '.esc_attr($wow_options['fls_cl_blog_single']).' '.esc_attr($wow_options['fls_cl_blog_single']).' transparent;' : 'border-color: transparent #e3e3e3 #e3e3e3 transparent;' ;
	$fls_cr_blog_single = ( !empty ( $wow_options['fls_cr_blog_single'] ) ) ? 'border-color: transparent transparent '.esc_attr($wow_options['fls_cr_blog_single']).' '.esc_attr($wow_options['fls_cr_blog_single']).';' : 'border-color: transparent transparent #e3e3e3 #e3e3e3 ;' ;	

	//corner colors for right sidebar on blog single
	$frs_cl_blog_single = ( !empty ( $wow_options['frs_cl_blog_single'] ) ) ? 'border-color: transparent '.esc_attr($wow_options['frs_cl_blog_single']).' '.esc_attr($wow_options['frs_cl_blog_single']).' transparent;' : 'border-color: transparent #e3e3e3 #e3e3e3 transparent;' ;
	$frs_cr_blog_single = ( !empty ( $wow_options['frs_cr_blog_single'] ) ) ? 'border-color: transparent transparent '.esc_attr($wow_options['frs_cr_blog_single']).' '.esc_attr($wow_options['frs_cr_blog_single']).';' : 'border-color: transparent transparent #e3e3e3 #e3e3e3 ;' ;

	//calculate the position of corners depending on the padding of blog page / single post
	$distance = '';
	if ( is_front_page() || wow_is_any_blog_page() ) {
		$distance =!empty( $wow_options['blog_padding']['padding-top'] ) ? abs($wow_options['blog_padding']['padding-top']) + 59 : '139';
		if ( $wow_vertical_layout && is_front_page() && is_home() ){
			echo '<style type="text/css">@media only screen and (min-width : 1201px) { .is-blog-page.has-left-fancy-sidebar #page-body .left_sidebar, .is-blog-page.has-right-fancy-sidebar #page-body .right_sidebar{ margin-top: -77px !important } }</style>';
		}		
	}
	else {
		$distance =!empty( $wow_options['blog_padding']['padding-top'] ) ? abs($wow_options['blog_padding']['padding-top']) + 59 : '109';
	}
	$distance_single =!empty( $wow_options['blog_padding_single']['padding-top'] ) ? abs($wow_options['blog_padding_single']['padding-top']) + 59 : '139';
	
	if ( $wow_options['blog_layout'] == 'left-sidebar' and !is_single() and $wow_options['fancy_sidebar'] == 1){
		echo 
			'<style type="text/css">
				.is-blog-page.has-left-fancy-sidebar #page-body .left_sidebar { margin-top: -'.esc_attr($distance).'px ; background:#f8f8f8;-webkit-box-shadow: -1px 1px 25px 1px rgba(0,0,0,0.06); -moz-box-shadow: -1px 1px 25px 1px rgba(0,0,0,0.06); box-shadow: -1px 1px 25px 1px rgba(0,0,0,0.06)}
				.is-blog-page.has-left-fancy-sidebar #page-body .left_sidebar:before{ content: ""; width: 0; height: 0;border-style: solid; border-width: 54px 14px 0 0; '.esc_attr($fls_cl_blog).' position: absolute; top: 5px; left: -14px; }
				.is-blog-page.has-left-fancy-sidebar #page-body .left_sidebar:after{ content: ""; width: 0; height: 0;border-style: solid; border-width: 54px 0 0 14px; '.esc_attr($fls_cr_blog).' position: absolute; top: 5px;right: -14px; }				
				.is-blog-page.has-left-fancy-sidebar #page-body .left_sidebar .left_sidebar_container { padding: 40px 30px 40px 30px; }
				.is-blog-page.has-left-fancy-sidebar .blog-start { padding-left:30px }
				.is-blog-page.has-left-fancy-sidebar .header_breadcrumb_inner{ padding-bottom:150px }
			</style>';		
	}	
	
	if ( $wow_options['blog_layout'] == 'right-sidebar' and !is_single() and $wow_options['fancy_sidebar'] == 1 ){
		echo 
			'<style type="text/css">
				.is-blog-page.has-right-fancy-sidebar #page-body .right_sidebar {  margin-top: -'.esc_attr($distance).'px ; background:#f8f8f8; -webkit-box-shadow: -1px 1px 25px 1px rgba(0,0,0,0.06); -moz-box-shadow: -1px 1px 25px 1px rgba(0,0,0,0.06); box-shadow: -1px 1px 25px 1px rgba(0,0,0,0.06)}
				.is-blog-page.has-right-fancy-sidebar #page-body .right_sidebar:before{ content: ""; width: 0; height: 0;border-style: solid; border-width: 54px 14px 0 0; '.esc_attr($frs_cl_blog).' position: absolute; top: 5px; left: -14px; }
				.is-blog-page.has-right-fancy-sidebar #page-body .right_sidebar:after{ content: ""; width: 0; height: 0;border-style: solid; border-width: 54px 0 0 14px; '.esc_attr($frs_cr_blog).' position: absolute; top: 5px;right: -14px; }
				.is-blog-page.has-right-fancy-sidebar #page-body .right_sidebar .right_sidebar_container { padding: 40px 30px 40px 30px; }
				.is-blog-page.has-right-fancy-sidebar .blog-start { padding-right:30px }
				.is-blog-page.has-right-fancy-sidebar .header_breadcrumb_inner{ padding-bottom:150px }
			</style>';
	}	
	
	if ( $blog_single_layout == 'left-sidebar' and is_single() and $wow_options['fancy_sidebar'] == 1 ) {
		echo 
			'<style type="text/css">
				.is-blog-page-single.has-left-fancy-sidebar #page-body .left_sidebar {  margin-top: -'.esc_attr($distance_single).'px ; background:#f8f8f8; -webkit-box-shadow: -1px 1px 25px 1px rgba(0,0,0,0.06); -moz-box-shadow: -1px 1px 25px 1px rgba(0,0,0,0.06); box-shadow: -1px 1px 25px 1px rgba(0,0,0,0.06)}
				.is-blog-page-single.has-left-fancy-sidebar #page-body .left_sidebar:before{ content: ""; width: 0; height: 0;border-style: solid; border-width: 54px 14px 0 0; '.esc_attr($fls_cl_blog_single).' position: absolute; top: 5px; left: -14px; }
				.is-blog-page-single.has-left-fancy-sidebar #page-body .left_sidebar:after{ content: ""; width: 0; height: 0;border-style: solid; border-width: 54px 0 0 14px; '.esc_attr($fls_cr_blog_single).' position: absolute; top: 5px;right: -14px; }	
				.is-blog-page-single.has-left-fancy-sidebar #page-body .left_sidebar .left_sidebar_container { padding:40px 0 40px 40px; }
				.is-blog-page-single.has-left-fancy-sidebar .blog-single-start, .is-blog-page-single.has-left-fancy-sidebar .post-details { padding-left:40px }
				.is-blog-page-single.has-left-fancy-sidebar .header_breadcrumb_inner{ padding-bottom:150px }
			</style>';
	}	
	
	if ( $blog_single_layout == 'right-sidebar' and is_single() and $wow_options['fancy_sidebar'] == 1 ) {
		echo		
		'<style type="text/css">
				.is-blog-page-single.has-right-fancy-sidebar #page-body .right_sidebar{ margin-top: -'.esc_attr($distance_single).'px ; background:#f8f8f8;-webkit-box-shadow: -1px 1px 25px 1px rgba(0,0,0,0.06); -moz-box-shadow: -1px 1px 25px 1px rgba(0,0,0,0.06); box-shadow: -1px 1px 25px 1px rgba(0,0,0,0.06) }
				.is-blog-page-single.has-right-fancy-sidebar #page-body .right_sidebar:before{ content: ""; width: 0; height: 0;border-style: solid; border-width: 54px 14px 0 0; '.esc_attr($frs_cl_blog_single).' position: absolute; top: 5px; left: -14px; }
				.is-blog-page-single.has-right-fancy-sidebar #page-body .right_sidebar:after{ content: ""; width: 0; height: 0;border-style: solid; border-width: 54px 0 0 14px; '.esc_attr($frs_cr_blog_single).' position: absolute; top: 5px;right: -14px; }
				.is-blog-page-single.has-right-fancy-sidebar #page-body .right_sidebar .right_sidebar_container { padding:40px 40px 40px 0; }
				.is-blog-page-single.has-right-fancy-sidebar .blog-single-start, .is-blog-page-single.has-right-fancy-sidebar .post-details { padding-right:40px }
				.is-blog-page-single.has-right-fancy-sidebar .header_breadcrumb_inner{ padding-bottom:150px }
			</style>';		
	}
	
}
add_action('wp_head','wow_fancy_sidebar');



/*
=================================================================================================================
wow_responsive() - calculate responsive
=================================================================================================================
*/
function wow_responsive( $args = array() ){
$responsive_fonts = $css_output = '';	
$factor = 1;
	
	if( empty( $args ) ) return false;

	if( isset( $args[0]['responsive_typography_factor'] ) ){
		$factor = (float) $args[0]['responsive_typography_factor'];
		unset( $args[0] );
	}

	foreach( $args as $val ){
			
		if( is_array( $val['css_atts'] ) ){
			$css_atts_array = array_filter( $val['css_atts'] ); //delete empty values if any
		}
		if( isset( $css_atts_array ) && is_array( $css_atts_array ) ){
			
			foreach($css_atts_array as $value){
				$x = explode(":",$value);
				
				if( strpos($x[0], "margin-") !== false ){
					
					if( intval( $x[1] ) ){
						$key= str_replace("margin-","",$x[0]);
						$new_array['margins'][trim($key)] = trim($x[1]);
					}

				}
				elseif( strpos($x[0], "padding-") !== false ){
					
					if( intval( $x[1] ) ){
						$key= str_replace("padding-","",$x[0]);
						$new_array['paddings'][trim($key)] = trim($x[1]);	
					}
				}
				else{
					$new_array[$x[0]] = trim($x[1]);
				}
			}				
		}
		
		if( isset( $new_array["font-size"] ) ){
			
			$font_size_numeric =  wow_px_em_rem( $new_array['font-size'] , wow_calc_default_font_size( $val['default_font_size'] ) );
			
		}
		elseif( isset( $val['default_font_size'] ) ){
			$font_size_numeric =   wow_calc_default_font_size( $val['default_font_size']  );
		}
		else{
			$font_size_numeric = 0;
		}
		
		if( $font_size_numeric > 32 ){  //letter spacing and line height goes together with font size so don't do without it

			if( $font_size_numeric < 45 ){
				$min_font_size = intval( $font_size_numeric / 1.6 );
			}
			elseif( $font_size_numeric < 65 ){
				$min_font_size = intval( $font_size_numeric / 1.8 );
			}
			elseif( $font_size_numeric < 85 ){
				$min_font_size = intval( $font_size_numeric / 2 );
			}
			elseif( $font_size_numeric < 100 ){
				$min_font_size = intval( $font_size_numeric / 2.2 );
			}
			elseif( $font_size_numeric < 120 ){
				$min_font_size = intval( $font_size_numeric / 2.4 );
			}
			elseif( $font_size_numeric < 200 ){
				$min_font_size = intval( $font_size_numeric / 2.6 );
			}
			else{
				$min_font_size = intval( $font_size_numeric / 3.5 );
			}
			
			$responsive_fonts .= "font-size: calc(".esc_attr($min_font_size)."px + (".esc_attr( round( $font_size_numeric / $factor ) )." - ".esc_attr($min_font_size).") * ((100vw - 300px) / (1890 - 300)));"; 

			if( isset( $new_array["letter-spacing"] )  ){
				
				$ls_numeric =  wow_px_em_rem( $new_array['letter-spacing'] , $font_size_numeric );
				
				$ls_ratio =  $ls_numeric / $font_size_numeric;
				$responsive_fonts .= "letter-spacing: calc((".esc_attr($min_font_size)."px + (".esc_attr(  round( $font_size_numeric / $factor ) )." - ".esc_attr($min_font_size).") * ((100vw - 300px) / (1890 - 300))) *  ".esc_attr($ls_ratio).");";
			}
			if( isset( $new_array["line-height"] )  ){

				$lh_numeric = wow_px_em_rem( $new_array['line-height'] , $font_size_numeric );
				$lh_ratio =  $lh_numeric / $font_size_numeric;
				$responsive_fonts .= "line-height: calc((".esc_attr($min_font_size)."px + (".esc_attr( round( $font_size_numeric / $factor ) )." - ".esc_attr($min_font_size).") * ((100vw - 300px) / (1890 - 300))) *  ".esc_attr($lh_ratio).");";
			}
		}
		if( $responsive_fonts ){
			
			//we can't escape ">" sign, so if we have it, we won't escape
			if ( strpos($val['selector'], ">") !== false) {
				$css_output.= $val['selector'] . "{" . $responsive_fonts . "}";
			} else {
				 
				 $css_output.= esc_attr( $val['selector'] ) . "{" . $responsive_fonts . "}" ; 
			}
		}
		unset($new_array);
		$responsive_fonts = '';
	}
	
	$css_output = "\n\n\n".'@media only screen and (max-width : 1890px) {
						'. $css_output  . 
					'}'."\n\n\n";

	return $css_output;

}

/*
=================================================================================================================
wow_calc_default_font_size() - if no font size is enter determine the default size for responsive
=================================================================================================================
*/
function wow_calc_default_font_size( $font ){
	if( !$font ) return false;
	global $wow_options;
	$h1 = !empty( $wow_options['h1-font']['font-size'] ) ? $wow_options['h1-font']['font-size'] : 42;
	$h2 = !empty( $wow_options['h2-font']['font-size'] ) ? $wow_options['h2-font']['font-size'] : 32;
	$h3 = !empty( $wow_options['h3-font']['font-size'] ) ? $wow_options['h3-font']['font-size'] : 22;
	$h4 = !empty( $wow_options['h4-font']['font-size'] ) ? $wow_options['h4-font']['font-size'] : 19;
	$h5 = !empty( $wow_options['h5-font']['font-size'] ) ? $wow_options['h5-font']['font-size'] : 18;
	$h6 = !empty( $wow_options['h6-font']['font-size'] ) ? $wow_options['h6-font']['font-size'] : 16;
	$p = !empty( $wow_options['p-font']['font-size'] ) ? $wow_options['p-font']['font-size'] : 15;

	$needs_processing = in_array($font,array('h1','h2','h3','h4','h5','h6','p'));	
	if( $needs_processing ){
		
		switch ($font) {
			case 'p':
				return intval( $p );			
			case 'h1':
				return intval( $h1 );
			case 'h2':
				return intval( $h2 );
			case 'h3':
				return intval( $h3 );
			case 'h4':
				return intval( $h4 );
			case 'h5':
				return intval( $h5 );
			case 'h6':
				return intval( $h6 );
		}
		
	}
	else return intval( $font );

}

/*
=================================================================================================================
wow_px_em_rem() - calculate sizes in px even if em or rem is entered for responsive
=================================================================================================================
*/
function wow_px_em_rem( $font_size , $default_font_size ){
	$font_size_numeric='';	
	if( !$font_size ) return false;

	if( strpos($font_size, "px") !== false ){
		$font_size_numeric =  intval( $font_size);
	}
	elseif( strpos($font_size, "rem") !== false ){
			$font_size_numeric = 16;
	}
	elseif( strpos($font_size, "em") !== false ){
		$default_font_size =  intval( $default_font_size);
		$font_size_numeric =  $default_font_size * floatval( $font_size);
	}	
	return $font_size_numeric;
	
}

/*
=================================================================================================================
wow_page_padding() - Add padding / left right on page
=================================================================================================================
*/
function wow_page_padding(){
	
	//post meta
	$wow_post_meta['wow-page-width'][0] = '';
	$wow_post_meta = get_post_meta(wow_get_the_post_id());

	//desktop paddings
	$desktop_padding_lr = !empty($wow_post_meta['desktop_padding_left_right'][0]) ? $wow_post_meta['desktop_padding_left_right'][0] : '';
	$desktop_padding_tp = !empty($wow_post_meta['desktop_padding_top_bottom'][0]) ? $wow_post_meta['desktop_padding_top_bottom'][0] : '';	
	
	//mobile paddings
	$mobile_padding_lr = !empty($wow_post_meta['mobile_padding_left_right'][0]) ? $wow_post_meta['mobile_padding_left_right'][0] : '';
	$mobile_padding_tp = !empty($wow_post_meta['mobile_padding_top_bottom'][0]) ? $wow_post_meta['mobile_padding_top_bottom'][0] : '';
	
	
	if (  $desktop_padding_lr || $desktop_padding_tp ||  $mobile_padding_lr || $mobile_padding_tp   ){
		
		echo '<style type="text/css">';
		
			if ( $wow_post_meta['wow-page-width'][0] != 'container' ){
				echo '@media (min-width: 1201px) {
					#page-body, .not-edited-with-vc #page-body{ padding-left:'.esc_attr( $desktop_padding_lr ).'; padding-right:'.esc_attr( $desktop_padding_lr ).' }
				}';
			}
		
			echo '@media (min-width: 1201px) {
			    #page-body, .not-edited-with-vc #page-body, .is-portfolio-page #page-body{ padding-top:'.esc_attr( $desktop_padding_tp ).'; padding-bottom:'.esc_attr( $desktop_padding_tp ).' }
			}';
			echo'@media (max-width: 1200px) {
				#page-body, .not-edited-with-vc #page-body{ padding-left:'.esc_attr( $mobile_padding_lr ).'; padding-right:'.esc_attr( $mobile_padding_lr ).' }
				#page-body, .not-edited-with-vc #page-body{ padding-top:'.esc_attr( $mobile_padding_tp ).'; padding-bottom:'.esc_attr( $mobile_padding_tp ).' }
			}';
			
			
		echo '</style>';
	}	
	
}
add_action('wp_head', 'wow_page_padding');


/*
=================================================================================================================
wow_abs_spacer() - Add padding top to absolute header
=================================================================================================================
*/
function wow_abs_spacer( ){
	
	//post meta
	$post_id = wow_get_the_post_id();
	$wow_post_meta = get_post_meta( $post_id );
	
	if ( ( isset($wow_post_meta['wow-abs-header'][0]) && $wow_post_meta['wow-abs-header'][0] == 'yes' ) ){
		
		$space = $wow_post_meta['wow-abs-spacer'][0] ? $wow_post_meta['wow-abs-spacer'][0] : '';
		
		
		//determine if first in page is a row or section
		$post_content = get_post_field('post_content', $post_id);

		$pos = strpos($post_content, "vc_row");
		$pos2 = strpos($post_content, "vc_section");		
		
		if( $pos !== false &&  $pos2 !== false ){
			
			if( $pos < $pos2 ){  //vc_row is first
				$tag = 'div';
			}
			else{
				$tag = 'section';
			}
		}
		elseif( $pos !== false ){
			$tag = 'div';
		}		
		elseif( $pos2 !== false ){
			$tag = 'section';
		}
		else{
			$tag = wow_first_tag_in_text( $post_content );
		}
		echo '<style type="text/css">';
			echo '.absolute-header > #wrap > #page-body > '.esc_attr( $tag ).':first-of-type{ padding-top:'.esc_attr( $space ).' }';
		echo '</style>';
	}	
	
}
add_action('wp_head', 'wow_abs_spacer');

/*
=================================================================================================================
wow_first_tag_in_text() -  get first html tag in any given text
=================================================================================================================
*/
function wow_first_tag_in_text( $string ){
	
	if( !$string ){ return; }
	
	$text = str_replace("<!--","",$string);
	
	$tag_open = strpos($text, "<");
	$tag_close = strpos($text, ">", $tag_open);
	$space = strpos($text, " " , $tag_open);
	
	if( $tag_close < $space ){ //if tag is closed
		$lenght = $tag_close - $tag_open - 1;		
	}
	else{ //tag has space( probably has class or other attributes  )
		$lenght = $space - $tag_open - 1;
	}
	$tag = substr( $text, $tag_open + 1, $lenght );
	return $tag;
}
/*
=================================================================================================================
wow_social_footer() -  social list html output
=================================================================================================================
*/
function wow_social_footer(){
	global $wow_options;
	$social_html = $social_style_class = '';
	if(!empty($wow_options['copyright-social']) && $wow_options['copyright-social'] == '1'){
		wp_enqueue_style( 'social', WOW_URI.'/fonts/icons/social/style.css');
		if (!empty($wow_options['copyright-social-style'])){
			if ($wow_options['copyright-social-style'] == 'simple'){
				$social_style_class = 'simple';
			}			
			if ($wow_options['copyright-social-style'] == 'square'){
				$social_style_class = 'square';
			}			
			if ($wow_options['copyright-social-style'] == 'rounded'){
				$social_style_class = 'rounded';
			}			
			if ($wow_options['copyright-social-style'] == 'circle'){
				$social_style_class = 'circle';
			}
		}
	
		$socials = array('facebook' , 'skype' ,'google-plus' ,'twitter' ,'vimeo' ,'youtube' ,'flickr' ,'linkedin' ,'pinterest' ,'dribbble' ,'instagram' ,'behance' ,'tumblr' ,'viadeo' , 'xing' );
		foreach( $socials as $social ){
			if ( !empty( $wow_options[$social] ) ){
				$social_html.=  '<li><a href="'.esc_url( $wow_options[$social] ).'"><i class="wow-social-'. esc_attr( strtolower( $social ) ).'"></i></a></li>';
			}
		}
	}
	
	if($social_html){
		$social_html = '<ul class="'.esc_attr($social_style_class).'">' . $social_html . '</ul>';
		return $social_html;
	}
}

/*
=================================================================================================================
wow_social_footer_show() -  social list html output for footer
=================================================================================================================
*/
function wow_social_footer_show(){
	global $wow_options;
	$allowed_html_tags =  array( 'ul'=> array( 'class'=>array() ), 'li'=>array() , 'a'=>array( 'href'=>array() ), 'i' => array( 'class' => array() ) );
	echo '<div class="social">'.wp_kses( wow_social_footer(), $allowed_html_tags ).'</div>';
}

/*
=================================================================================================================
wow_fancy_no_breadcrumb() -  check if blog/blog single has fancy sidebar and no breadcumb
=================================================================================================================
*/
function wow_fancy_no_breadcrumb(){
	
	global $wow_options;
	
	if ( $wow_options['fancy_sidebar'] == '1' ){
		
		$post_meta = get_post_meta(wow_get_the_post_id());
	
		//single blog layout
		$blog_single_layout = (!empty($post_meta['wow-blog-single-layout'][0]) && $post_meta['wow-blog-single-layout'][0] != 'default') ? $post_meta['wow-blog-single-layout'][0] : $wow_options['blog_single_layout'];
	
		if 
		(
			( !wow_has_breadcrumb() && $wow_options['blog_layout'] == 'left-sidebar' && !is_single() && wow_is_any_blog_page() )
			||
			( !wow_has_breadcrumb() && $wow_options['blog_layout'] == 'right-sidebar' && !is_single() && wow_is_any_blog_page() )
			||
			( !wow_has_breadcrumb() && $blog_single_layout == 'left-sidebar' && is_single() )
			||
			( !wow_has_breadcrumb() && $blog_single_layout == 'right-sidebar' && is_single() )
		){
			echo '
			<style type="text/css">
				header{ padding-bottom:60px !important }
			</style>
			';
		}

	}
		

}

/*
=================================================================================================================
wow_per_row_responsive() -  how many portfolio/blog posts on row on responsive devices
=================================================================================================================
*/
function wow_per_row_responsive(){
	global $wow_options;
	$output = '';
		
		//posts
		if ( isset ( $wow_options['grid_1600'] ) && !empty( $wow_options['grid_1600'] )  ){
			$output .= '@media (max-width: 1600px) {  .is-blog-page article[class^="vc_col-lg"] {  width:'.esc_attr( $wow_options['grid_1600']  ).'% !important  }  }';
		}
		if (  isset ( $wow_options['grid_1200'] ) && !empty($wow_options['grid_1200']  ) ){
			$output .= '@media (max-width: 1200px) {  .is-blog-page article[class^="vc_col-lg"] {  width:'.esc_attr( $wow_options['grid_1200']  ).'% !important  }  }';
		}
		if (  isset ( $wow_options['grid_992'] ) && !empty( $wow_options['grid_992'] ) ){
			$output .= '@media (max-width: 992px) {  .is-blog-page article[class^="vc_col-lg"] {  width:'.esc_attr( $wow_options['grid_992']  ).'% !important  }  }';
		}
		if (  isset ( $wow_options['grid_768'] ) && !empty( $wow_options['grid_768'] ) ){
			$output .= '@media (max-width: 768px) {  .is-blog-page article[class^="vc_col-lg"] {  width:'.esc_attr( $wow_options['grid_768']  ).'% !important  }  }';
		}			
		if (  isset ( $wow_options['grid_480'] ) && !empty( $wow_options['grid_480'] ) ){
			$output .= '@media (max-width: 480px) {  .is-blog-page article[class^="vc_col-lg"] {  width:'.esc_attr( $wow_options['grid_480']  ).'% !important  }  }';
		}		
	
		//portfolio
		if (  isset ( $wow_options['grid_1600_p'] ) && !empty( $wow_options['grid_1600_p'] ) ){
			$output .= '@media (max-width: 1600px) {  .is-portfolio-page .portfolio [class^="vc_col"], .is-portfolio-tax .portfolio [class^="vc_col"] {  width:'.esc_attr( $wow_options['grid_1600_p']  ).'% !important  }  }';
		}
		if (  isset ( $wow_options['grid_1200_p'] ) && !empty( $wow_options['grid_1200_p'] ) ){
			$output .= '@media (max-width: 1200px) {  .is-portfolio-page .portfolio [class^="vc_col"], .is-portfolio-tax .portfolio [class^="vc_col"] {  width:'.esc_attr( $wow_options['grid_1200_p']  ).'% !important  }  }';
		}			
		if (  isset ( $wow_options['grid_992_p'] ) && !empty( $wow_options['grid_992_p'] ) ){
			$output .= '@media (max-width: 992px) {  .is-portfolio-page .portfolio [class^="vc_col"], .is-portfolio-tax .portfolio [class^="vc_col"] {  width:'.esc_attr( $wow_options['grid_992_p']  ).'% !important  }  }';
		}			
		if (  isset ( $wow_options['grid_768_p'] ) && !empty( $wow_options['grid_768_p'] ) ){
			$output .= '@media (max-width: 768px) {  .is-portfolio-page .portfolio [class^="vc_col"], .is-portfolio-tax .portfolio [class^="vc_col"] {  width:'.esc_attr( $wow_options['grid_768_p']  ).'% !important  }  }';
		}
		if (  isset ( $wow_options['grid_480_p'] ) && !empty( $wow_options['grid_480_p'] ) ){
			$output .= '@media (max-width: 480px) {  .is-portfolio-page .portfolio [class^="vc_col"], .is-portfolio-tax .portfolio [class^="vc_col"] {  width:'.esc_attr( $wow_options['grid_480_p']  ).'% !important  }  }';
		}

		if( $output ){
			echo '<style type="text/css">' . $output . '</style>';
		}
}

/*
=================================================================================================================
wow_grid_calc() -  Calculate dynamic grid sizes on desktop and responsive
=================================================================================================================
*/
function wow_grid_calc( $value, $css_selector, $second = false ){

	global $wow_options;
	$custom_css = '';
	$wow_value =  absint( $wow_options[$value] );
	
	//vertical layouts
	$vertical_layout   = in_array($wow_options['header-layout'], array('header-seven','header-eight','header-nine','header-ten')); 
	
	//screen res for for blog page
	$screen_res = $wow_value + 70;

	if ( $vertical_layout ){
	
		//vertical header width
		$header_width = empty($wow_options['header-vertical-width']) ? 250 : intval( $wow_options['header-vertical-width'] );				
				
		//screen res for vertical layouts
		$screen_res = $wow_value + $header_width + 70;
		
		if ( $screen_res <= 1200 ){
				$custom_css.= '@media only screen and (min-width: 1201px) {';			
		}
		else{
			//until the min resolution for desired grid size is achieved we calculate the grid in percents
			$custom_css.= '@media only screen and (min-width:1201px) and (max-width:'.esc_attr( $screen_res  - 1 ).'px) {';
			$custom_css.=  esc_attr( $css_selector ).'{ width:calc(100% - 100px) }';
			$custom_css.= ( $second ) ? '.header-wrap-vertical .container-inner{ margin-left:0; margin-right:0 }' : '';
			$custom_css.= '}';					
						
			//from this screen size we display the user desired grid size
			$custom_css.= '@media only screen and (min-width: '.esc_attr( $screen_res ).'px) {';
		}
			$custom_css.= esc_attr( $css_selector ).'{ width:'.esc_attr( $wow_value ).'px; }';
			$custom_css.= '}';
		
	}//end if vertical layouts
	
	else{
		
		//screen res for horizontal layouts
		$screen_res = $wow_value + 70;
		
		if ( $screen_res <= 1200 ){
			$custom_css.= '@media only screen and (min-width:1201px) {'.esc_attr( $css_selector ).'{width:'.esc_attr($wow_value).'px}}';	
		}
				
		else{
			$custom_css.= '@media only screen and (min-width: '.esc_attr($screen_res).'px) {'.esc_attr( $css_selector ).'{width:'.esc_attr($wow_value).'px}}';
		}		
		
	}//end if horizontal layouts
	
	return $custom_css;

}

/*
=================================================================================================================
wow_page_is_edited_with_vc() -  Determine if a page is edited with WPBakery
=================================================================================================================
*/
function wow_page_is_edited_with_vc(){
	
	//get the post/page content
	$post = get_post( wow_get_the_post_id() ); 
	$content = ( is_object( $post ) ) ? $post->post_content : '';
	
	if( class_exists("bbPress") && is_bbpress() ){ return true; }

	if ( get_post_type(wow_get_the_post_id()) != 'page' ){ return false; }
	
	if ( is_page_template() ) { return false; }
	
	if ( wow_is_any_blog_page() ) { return false; }
	
	if ( is_search() ) { return false; }

	if ( wow_is_realy_woocommerce_page() ) { return false; }
	
	if ( get_post_type( wow_get_the_post_id() ) == 'page' and stripos( $content, '[/vc_row]' ) === false ){
		return true;
	}
	
	return false;

}


/*
=================================================================================================================
wow_get_rev_sliders() Get all the Rev Sliders
=================================================================================================================
*/
function wow_get_rev_sliders(){
		global $wpdb;
	
		$sliders = array( ''  => esc_html__('Select Slider', 'infinito') );
	
		if( function_exists( 'rev_slider_shortcode' ) ){
			
			
			// table prefix
			$table_prefix ='';
			if( $table_prefix == 'base_prefix' ){
				$table_prefix = $wpdb->base_prefix;
			} else {
				$table_prefix = $wpdb->prefix;
			}
			
			$table_name = $table_prefix . "revslider_sliders";
			
			
			$rs5 = $wpdb->get_results("SHOW COLUMNS FROM $table_name LIKE 'type'");
			if( $rs5 ){			
				// Revolution Slider 5.x
				$array = $wpdb->get_results("SELECT * FROM $table_name WHERE type != 'template' ORDER BY title ASC");
			} else {			
				// Revolution Slider 4.x
				$array = $wpdb->get_results("SELECT * FROM $table_name ORDER BY title ASC");
			}
			
			
			if( is_array( $array ) ){
				foreach( $array as $slider ){
					$sliders[$slider->alias] = $slider->title;
				}
			}
			
		}
		
		return $sliders;
}

/*
=================================================================================================================
wow_widget_heading_icon() - Adds icon to a widget heading ( for theme custom widgets )
=================================================================================================================
*/
function wow_widget_heading_icon( $title ){
	global $wow_options;
	$output = '';
	
	//add icon to widget title from theme options
	$icon = (!empty($wow_options['blog-widget-heading-icon'])) ? '<i class="widget-icon '.esc_attr($wow_options['blog-widget-heading-icon']).'"></i>' : '';
	
	if ( is_rtl() ){
		$output = '<h3>'.esc_attr( $title ).$icon.'</h3>';
	}
	else{
		$output = '<h3>'.$icon.esc_attr( $title ).'</h3>';
	}
	return $output; //sanitized above
}

/*
=================================================================================================================
wow_widget_register_on_theme_switch() - Register sidebars on theme switch
=================================================================================================================
*/
function wow_widget_register_on_theme_switch () {
	do_action( 'widgets_init', 'wow_sidebars_init' );
}
add_action('after_switch_theme', 'wow_widget_register_on_theme_switch');


/*
=================================================================================================================
Function wow_font_icons_enqueue() - enqueue icon fonts
=================================================================================================================
*/
function wow_font_icons_enqueue( $font ){
	
	$icon_suffix = '';

	if( $font ){
		if( strpos($font, 'wow-') !== false ){
			
			$xplode = explode( '-', $font );
			$font_class = $xplode[0].'-'.$xplode[1];
			$url = WOW_URI . '/fonts/icons/' . $xplode[1] . '/style.css';
			wp_enqueue_style( $font_class, $url);
		}
		elseif ( strpos( $font, 'pe-7s' ) !== false){
			wp_enqueue_style( 'pe-7s', WOW_URI.'/fonts/icons/pe-7s/style.css' );
		}
		else{
			wp_enqueue_style( 'pe-7f', WOW_URI.'/fonts/icons/pe-7f/style.css' );
		}
	}
}

/*
=================================================================================================================
wow_break_word() - Break word via css if title is longer than 20 characters
=================================================================================================================
*/
function wow_break_word( ){
	$pieces = explode(' ',get_the_title());
	foreach ( $pieces as $piece ){
		if ( strlen ( $piece ) > 20 ){
			echo '
			<style type="text/css">
				.header_breadcrumb h1 , .header_breadcrumb ul.nav_crumb li:last-child, .blog-single h1{ word-break: break-all; -ms-word-wrap: break-word; }
			</style>';
		}
	}
}
add_action('wp_head', 'wow_break_word');

/*
=================================================================================================================
wow_break_word_loop() - Break word via css if title is longer than 20 characters
=================================================================================================================
*/
function wow_break_word_loop( $text ){
	$pieces = explode(' ', $text );
	foreach ( $pieces as $piece ){
		if ( strlen ( $piece ) > 20 ){
			return "post-title word-break";
		}
	}
	return "post-title";
}

/*
=================================================================================================================
wow_is_theme_active_infinito() - Used for checks in plugins to determine if the active theme is infinito 
=================================================================================================================
*/
function wow_is_theme_active_infinito( ){
	//do nothing
}