<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
//remove the woocomerce default breadcrumb
remove_action( 'woocommerce_before_main_content','woocommerce_breadcrumb', 20, 0);
remove_action( 'woocommerce_before_shop_loop_item','woocommerce_template_loop_product_link_open', 10);

/*
=================================================================================================================
wow_woo_support() - Declare woocommerce support, and also product gallery, zoom and slider support
=================================================================================================================
*/
function wow_woo_support() {
    add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
add_action( 'after_setup_theme', 'wow_woo_support' );


/*
=================================================================================================================
wow_woo_wrapper_start() - Modify the woocommerce wrapper start
=================================================================================================================
*/
function wow_woo_wrapper_start() {
	global $wow_options;
	$woo_container = ( $wow_options['woo_container'] == 'container' ) ? 'container' : '';
	if(is_product()){
		return false;
	}
	elseif(is_cart()){
		echo '<div class="woocommerce-start"><!-- woocommerce-start -->';
		echo '<div class= "'.esc_attr($woo_container).' wrapper"><!-- container wrapper-->';	
	}
	else{
		echo '<div id="page-body" class="content-wrapper"><!-- page-body -->';
		echo '<div class="woocommerce-start"><!-- woocommerce-start -->';
		echo '<div class= "'.esc_attr($woo_container).' wrapper"><!-- container wrapper-->';		
	}
		
}
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
add_action('woocommerce_before_main_content', 'wow_woo_wrapper_start', 10);
add_action('woocommerce_before_cart', 'wow_woo_wrapper_start', 10);



/*
=================================================================================================================
wow_woo_wrapper_end() - Modify the woocommerce wrapper end
=================================================================================================================
*/
function wow_woo_wrapper_end() {

	if(is_product()){
		return false;
	}
	elseif(is_cart()){
		echo '</div><!--/ container wrapper -->';
		echo '</div><!--/ woocommerce-start -->';
	}
	else{
		echo '</div><!--/ container wrapper -->';
		echo '</div><!--/ woocommerce-start -->';
		echo '</div><!--/ page-body -->';		
	}
}
add_action('woocommerce_after_main_content', 'wow_woo_wrapper_end', 10);
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);
add_action('woocommerce_after_cart', 'wow_woo_wrapper_end', 10);
add_action('woocommerce_after_cart_empty', 'wow_woo_wrapper_end', 10);


/*
=================================================================================================================
wow_woo_breadcrumbs() - Modify the woocommerce breadcrumb output
=================================================================================================================
*/
add_filter( 'woocommerce_breadcrumb_defaults', 'wow_woo_breadcrumbs' );
function wow_woo_breadcrumbs() {
	global $wow_options;
   	
	//home text pulled from theme options
	$home_text = (!empty($wow_options['breadcrumb_home_title'])) ? esc_attr($wow_options['breadcrumb_home_title']) :  __('Home','infinito'); 
	
	return array(
            'delimiter'   => '<li class="delimiter"><i class="'.esc_attr($wow_options['breadcrumb_sep_icon']).'"></i></li>',
            'wrap_before' => '',
            'wrap_after'  => '',
            'before'      => '<li>',
            'after'       => '</li>',
            'home'        => $home_text,
        );
}

/*
=================================================================================================================
wow_woo_dequeue_styles() - Dequeue the original woocommerce css files
=================================================================================================================
*/
function wow_woo_dequeue_styles( $enqueue_styles ) {
	unset( $enqueue_styles['woocommerce-general'] );	// Remove the gloss
	unset( $enqueue_styles['woocommerce-layout'] );		// Remove the layout
	unset( $enqueue_styles['woocommerce-smallscreen'] );	// Remove the smallscreen optimisation
	return $enqueue_styles;
}
add_filter( 'woocommerce_enqueue_styles', 'wow_woo_dequeue_styles' );

/*
=================================================================================================================
wow_woo_enqueue_styles() - Enquque the new woocommerce css files
=================================================================================================================
*/
function wow_woo_enqueue_styles(){
	
	//load in header of select2.css fix
	wp_deregister_style( 'select2' );
	wp_enqueue_style( 'select2', plugins_url().'/woocommerce/assets/css/select2.css', '', '' );

	wp_enqueue_style( 'woocommerce-layout', WOW_URI . '/css/woocommerce/woocommerce-layout.css' );
	wp_enqueue_style( 'woocommerce-smallscreen', WOW_URI . '/css/woocommerce/woocommerce-smallscreen.css' );
	wp_enqueue_style( 'woocommerce-general', WOW_URI . '/css/woocommerce/woocommerce.css' );
	wp_enqueue_style( 'responsive-woo', WOW_URI . '/css/woocommerce/responsive-woo.css' );
	wp_enqueue_style( 'pe-7f', WOW_URI.'/fonts/icons/pe-7f/style.css' );
	wp_enqueue_style( 'pe-7s', WOW_URI.'/fonts/icons/pe-7f/style.css' );
}


/*
=================================================================================================================
wow_woo_show_cat() - Display the product category on shop page
=================================================================================================================
*/
function wow_woo_show_cat() {
    global $post;
	$terms = get_the_terms( $post->ID, 'product_cat' );
	echo '<div class="cat-holder">';
	foreach ($terms as $term) {
		$product_cat_name[]= '<span class="category"><a title="'.esc_attr( $term->name ).'" href="' . esc_url( get_term_link( $term->slug, 'product_cat' ) ) . '" class="themecolor1">'.esc_attr( $term->name ).'</a></span>';
    }
	
	$all_terms = ( !empty ( $product_cat_name ) ) ? implode(' ',$product_cat_name) :  esc_html__( 'Uncategorized', 'infinito' )  ;
	
	echo wp_kses($all_terms , array('span' => array('class' => array()),'a' => array('title' => array() ,'href' => array() ,'class' => array() ) ));

	echo '</div >';
}
add_action('woocommerce_before_shop_loop_item', 'wow_woo_show_cat', 50);

/*
=================================================================================================================
wow_woo_resize_thumbnail_on_shop_page() - Display the resized image on shop page / archive product page
=================================================================================================================
*/
function wow_woo_resize_thumbnail_on_shop_page() {
	
	if ( has_post_thumbnail()){
		global $post,$product;
		
		$product_thumbnail_arr = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'single-post-thumbnail' );
		$product_thumbnail = $product_thumbnail_arr[0];
		
		$post_thumbnail_id = get_post_thumbnail_id( $post->ID );
		
		$alt_title = get_the_title( $post_thumbnail_id );
		
		$img_alt_title = ( !empty ( $alt_title ) ) ? $alt_title : get_the_title( $post->ID ) ;
		
		$attachment_ids = $product->get_gallery_image_ids();


		$product_thumbnail_2 = '';
		
		if ( $attachment_ids ){
			
			$title = get_the_title( $attachment_ids[0] );
			
			$product_thumbnail_2 = wp_get_attachment_url( $attachment_ids[0] );
			$img_alt_title_2 = ( !empty ( $title ) ) ? $title : get_the_title( $post->ID ) ;
		}
		
		if ( $product_thumbnail_2 ){
			
			echo '<div class="images-holder"><!-- images-holder -->';
				echo '<a href="'.esc_url( get_the_permalink() ).'"><img src="'.esc_url( aq_resize( $product_thumbnail,420,420,true,true,true,true ) ).'" alt="'.esc_attr( $img_alt_title ).'" class="first"></a>';
				echo '<a href="'.esc_url( get_the_permalink() ).'"><img src="'.esc_url( aq_resize( $product_thumbnail_2,420,420,true,true,true,true ) ).'" alt="'.esc_attr( $img_alt_title_2 ).'" class="second"></a>';
			echo '</div><!-- images-holder -->';
		}		
		else{
			echo '<a href="'.esc_url( get_the_permalink() ).'"><img src="'.esc_url( aq_resize( $product_thumbnail,420,420,true,true,true,true ) ).'" alt="'.esc_attr( $img_alt_title ).'"></a>';
		}
	}
}
remove_action( 'woocommerce_before_shop_loop_item_title','woocommerce_template_loop_product_thumbnail',10);
add_action('woocommerce_before_shop_loop_item_title', 'wow_woo_resize_thumbnail_on_shop_page', 10);

/*
=================================================================================================================
wow_woo_before_shop_loop() - Add a div before shop loop
=================================================================================================================
*/
function wow_woo_before_shop_loop() {
	global $wow_options, $wow_woo_prod_display_style;
	$prod_style = ( !empty( $wow_woo_prod_display_style ) ) ? $wow_woo_prod_display_style : $wow_options['styling-woo-prod-display-style'];
	if ( $prod_style == 'with_bg' ) { 
		echo '<div class="product-inner"><!-- product-inner -->' ;
	}
}

add_action('woocommerce_before_shop_loop_item', 'wow_woo_before_shop_loop', 10);

/*
=================================================================================================================
wow_woo_after_shop_loop() - Add a div after shop loop
=================================================================================================================
*/
function wow_woo_after_shop_loop() {
	global $wow_options, $wow_woo_prod_display_style;
	$prod_style = ( !empty( $wow_woo_prod_display_style ) ) ? $wow_woo_prod_display_style : $wow_options['styling-woo-prod-display-style'];
	if ( $prod_style == 'with_bg' ) {
		echo '</div><!-- product-inner -->';
	}
}

add_action('woocommerce_after_shop_loop_item', 'wow_woo_after_shop_loop', 10);

/*
=================================================================================================================
wow_woo_loop_product_title() - Product title in loop
=================================================================================================================
*/
function wow_woo_loop_product_title() {
	echo '<h2><a href="'.esc_url( get_the_permalink() ).'">'.get_the_title().'</a></h2>';
}
remove_action('woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10);
add_action('woocommerce_shop_loop_item_title', 'wow_woo_loop_product_title', 10);

/*
=================================================================================================================
wow_woo_add_to_cart() - add to cart button
=================================================================================================================
*/
function wow_woo_add_to_cart() {
	global $product,$wow_options;
	$add_to_cart 		  = ( !empty( $wow_options['add_to_cart'] ) ) ? $wow_options['add_to_cart'] : 'Add to cart';
	$add_to_cart_variable = ( !empty( $wow_options['add_to_cart_variable'] ) ) ? $wow_options['add_to_cart_variable'] : 'Select options';
	
	$id = $product->get_id();
	$variable_product = $product->is_type( 'variable' );
	
	echo '<div class="price-holder-wrap"><!-- price-holder-wrap --><div class="price-holder"><!-- price-holder -->';
		if ( $variable_product ){
			echo '<a href="'.esc_url( get_the_permalink() ).'" class="button themecolor1_bg add_to_cart_button"><i class="wow-business-cart-alt from_top"></i><i class="wow-webapplication-check-alt from_top second"></i>'.esc_html(  $add_to_cart_variable ).'</a>';
		}
		else {
			echo '<a href="'.esc_url( get_permalink( wc_get_page_id( 'shop' ) ) .'?add-to-cart='.esc_attr( $id ) ). '" data-product_id="'.esc_attr( $id ).'" class="button themecolor1_bg add_to_cart_button ajax_add_to_cart"><i class="wow-business-cart-alt from_top"></i><i class="wow-webapplication-check-alt from_top second"></i>'.esc_html( $add_to_cart ).'</a>';
		}
		echo '<a href="'.esc_url( get_the_permalink() ).'" class="rounded"><i class="wow-texteditor-link-alt"></i></a>';
	echo '</div><!-- /price-holder --></div><!-- /price-holder-wrap -->';
}	
remove_action('woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10);	
add_action('woocommerce_after_shop_loop_item_title', 'wow_woo_add_to_cart', 10);	

/*
=================================================================================================================
wow_change_product_price_display() - change price output 
=================================================================================================================
*/
function wow_change_product_price_display( $price ) {
	$explode = explode ('</del>',$price);
	if(count($explode) > 1){
		$return = '<div class="price-new">'.$explode[1].$explode[0].'</del></div>';
	}
	else return '<div class="price-new">'.$price.'</div>'; 
	return $return ;
}
add_filter( 'woocommerce_get_price_html', 'wow_change_product_price_display' );
//add_filter( 'woocommerce_cart_item_price', 'sv_change_product_price_display' ); - sa verific cand ajung la cart !!!

/*
=================================================================================================================
wow_new_loop_shop_per_page() - How many products will be displayed per page
=================================================================================================================
*/
function wow_new_loop_shop_per_page( $cols ) {
  global $wow_options;
  $cols = ( !empty( $wow_options['woo_per_page'] ) ) ? esc_attr(intval($wow_options['woo_per_page'])) : 8 ;
  return $cols;
}
add_filter( 'loop_shop_per_page', 'wow_new_loop_shop_per_page', 20 );

/*
=================================================================================================================
wow_woo_tags() - Display the tags and url's
=================================================================================================================
*/
function wow_woo_tags() {
	
	$terms = get_the_terms( get_the_ID(), 'product_tag' );
	$term_array = array();
	
	if ( ! empty( $terms ) && ! is_wp_error( $terms ) ){
		echo '<div class="tags"><!-- tags -->';
			foreach ( $terms as $tag ) {
				$tag_url = get_term_link( $tag->term_id );
				echo '<a href="'.esc_url( $tag_url ).'">'.esc_attr( $tag->name ).'</a>';
			}
		echo '</div><!-- tags -->';	
	}
}
/*
=================================================================================================================
wow_woo_has_tags() - Check if a product has tags
=================================================================================================================
*/
function wow_woo_has_tags() {
	
	$terms = get_the_terms( get_the_ID(), 'product_tag' );
	
	if ( $terms ) { return true; }
	else { return false; }

}

/*
=================================================================================================================
wow_woo_is_filter() - Determine if a filter page is displayed ( i.e rating filter, color filter, price filter )
=================================================================================================================
*/
function wow_woo_is_filter(){

	$url = $_SERVER["REQUEST_URI"];

	$is_rating = strpos($url, 'rating_filter');
	$is_color = strpos($url, 'filter_color');
	$is_price_min = strpos($url, 'min_price');
	$is_price_max = strpos($url, 'max_price');

	if ( $is_rating !== false or $is_color !== false or $is_price_min !== false or $is_price_max !== false )
	{
		return true;
	}
	
	return false;
}

function wow_header_add_to_cart_fragment( $fragments ) {
 
    ob_start();
    $count = WC()->cart->cart_contents_count;
    ?><a class="cart-contents" href="<?php echo esc_url( wc_get_cart_url() ); ?>" title="<?php esc_html_e( 'View your shopping cart','infinito' ); ?>"><?php
    if ( $count > 0 ) {
        ?>
        <span class="cart-contents-count"><?php echo esc_html( $count ); ?></span>
        <?php            
    }
        ?></a><?php
 
    $fragments['a.cart-contents'] = ob_get_clean();
     
    return $fragments;
}
add_filter( 'woocommerce_add_to_cart_fragments', 'wow_header_add_to_cart_fragment' );

/*
=================================================================================================================
wow_override_woocommerce_widgets() - Override some woocommerce default widgets
=================================================================================================================
*/
function wow_override_woocommerce_widgets() {
	if ( class_exists( 'WC_Widget_Recent_Reviews' ) ) {
		unregister_widget( 'WC_Widget_Recent_Reviews' );
		register_widget( 'Wow_WC_Widget_Recent_Reviews' );
	}
}
add_action( 'widgets_init', 'wow_override_woocommerce_widgets', 15 );


//moving the coupon discount block
remove_action( 'woocommerce_before_checkout_form', 'woocommerce_checkout_coupon_form');
add_action( 'wow_woocommerce_review_order_between_cart_and_totals', 'woocommerce_checkout_coupon_form' );

//moving the price bellow add to cart button in single product
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10 );
add_action( 'woocommerce_before_add_to_cart_button', 'woocommerce_template_single_price', 10 );

/*
=================================================================================================================
wow_woocommerce_register_menu() - Register top menu for Woocommerce
=================================================================================================================
*/
function wow_woocommerce_register_menu() {
	 register_nav_menu( 'woo_nav' ,  __( 'Woocommerce Top')  );
}
add_action('init', 'wow_woocommerce_register_menu'); // Register menu

/*
=================================================================================================================
wow_woocommerce_info_bar() - Woocommerce Top menu html output
=================================================================================================================
*/
function wow_woocommerce_info_bar(){
		
		if ( has_nav_menu( 'woo_nav' ) ) {
			global $wow_options;
			$width = !empty( $wow_options['woo-info-bar-width'] ) ? ' container' : '';
			echo '<div class="woocommerce_info_bar">';	
				echo !empty( $wow_options['woo-info-bar-width'] ) ? '<div class="container">': '';
					echo '<ul>';				
						$array_menus = get_nav_menu_locations();
						$menu_ID = $array_menus['woo_nav'];
						$menu_obj = wp_get_nav_menu_items( $menu_ID );
						foreach($menu_obj as $menu_item){
							echo '<li>';
								$meta = get_post_meta($menu_item->ID);
								if( !empty( $meta["menu-item-nav-add_icon"][0] ) ){
									wow_font_icons_enqueue($meta["menu-item-nav-add_icon"][0]);
								}
								echo '<a href="'.esc_url($menu_item->url).'"><i class="'.esc_attr( $meta["menu-item-nav-add_icon"][0] ).'"></i>'.esc_attr($menu_item->title).'</a>';
							echo '</li>';
						}
						if ( is_user_logged_in() ){
							global $current_user;
							echo '<li class="go_right"><a href="'.esc_url( get_permalink( get_option('woocommerce_myaccount_page_id') ) ).'">'.esc_html__("Welcome", "infinito").' <strong>'.$current_user->display_name.'.</strong></a></li>';
						}
						else{
							echo '<li class="go_right"><span>'.esc_html__("Welcome", "infinito").' <strong>'.esc_html__("visitor", "infinito").'.</strong></span></li>';
						}
					echo '</ul>';
				echo !empty( $wow_options['woo-info-bar-width'] ) ? '</div>': '';
			echo '</div>';			
		} 
}

/*
=================================================================================================================
wow_woo_per_row_responsive() -  how many shop posts on row on responsive devices
=================================================================================================================
*/
function wow_woo_per_row_responsive(){
	
	global $wow_options;
	$output = '';

	//shop products
	if (  isset ( $wow_options['grid_1600_w'] ) && !empty( $wow_options['grid_1600_w'] ) ){
		$output .= '@media (max-width: 1600px) {  .woocommerce ul.products li.product[class^="vc_col-lg"] {  width:'.esc_attr( $wow_options['grid_1600_w']  ).'% !important  }  }';
	}
	if (  isset ( $wow_options['grid_1200_w'] ) && !empty( $wow_options['grid_1200_w'] ) ){
		$output .= '@media (max-width: 1200px) {   .woocommerce ul.products li.product[class^="vc_col-lg"] {  width:'.esc_attr( $wow_options['grid_1200_w']  ).'% !important  }  }';
	}			
	if (  isset ( $wow_options['grid_992_w'] ) && !empty( $wow_options['grid_992_w'] ) ){
		$output .= '@media (max-width: 992px) { .woocommerce ul.products li.product[class^="vc_col-lg"] {  width:'.esc_attr( $wow_options['grid_992_w']  ).'% !important  }  }';
	}			
	if (  isset ( $wow_options['grid_768_w'] ) && !empty( $wow_options['grid_768_w'] ) ){
				$output .= '@media (max-width: 768px) { .woocommerce ul.products li.product[class^="vc_col-lg"] {  width:'.esc_attr( $wow_options['grid_768_w']  ).'% !important  }  }';
	}
	if (  isset ( $wow_options['grid_480_w'] ) && !empty( $wow_options['grid_480_w'] ) ){
		$output .= '@media (max-width: 480px) {   .woocommerce ul.products li.product[class^="vc_col-lg"] {  width:'.esc_attr( $wow_options['grid_480_w']  ).'% !important  }  }';
	}			
		
	if( $output ){
		echo '<style type="text/css">' . $output . '</style>';
	}
}

/*
=================================================================================================================
wow_related_products() -  display related products
=================================================================================================================
*/
function wow_woo_related_products(){
	
	global $wow_options;
	$show_product = '';
	$post_meta = get_post_meta(wow_get_the_post_id());

	if( !empty( $post_meta['wow-related-prod'][0] ) ){
		if ( $post_meta['wow-related-prod'][0] == 'yes' ) { $show_product = '1'; }
		elseif ( $post_meta['wow-related-prod'][0] == 'no' ) { $show_product = '0'; }
	}
	else{
		$show_product = $wow_options['wow-related-prod'];
	}
	return $show_product;
}

/*
=================================================================================================================
wow_woo_upsell_products() -  display us-sells products
=================================================================================================================
*/
function wow_woo_upsell_products(){
	
	global $wow_options;
	$show_product = '';
	$post_meta = get_post_meta(wow_get_the_post_id());

	if( !empty( $post_meta['wow-upsell-prod'][0] ) ){
		if ( $post_meta['wow-upsell-prod'][0] == 'yes' ) { $show_product = '1'; }
		elseif ( $post_meta['wow-upsell-prod'][0] == 'no' ) { $show_product = '0'; }
	}
	else{
		$show_product = $wow_options['wow-upsell-prod'];
	}
	return $show_product;
}