<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/*
=================================================================================================================
wow_content_nav() - Displays navigation to next/previous pages when applicable.
=================================================================================================================
*/
if ( ! function_exists( 'wow_content_nav' ) ) :
function wow_content_nav() {
	global $wp_query;
	if ( $wp_query->max_num_pages > 1 ) : ?>
		<?php previous_posts_link( '<i class="fa fa-angle-left"></i>' ); ?>
		<?php next_posts_link( '<i class="fa fa-angle-right"></i>' ); ?>
	<?php endif;
}
endif;


/*
=================================================================================================================
wow_comment() - Template for comments and pingbacks.
=================================================================================================================
*/
if ( ! function_exists( 'wow_comment' ) ) :
function wow_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php esc_html_e( 'Pingback:', 'infinito' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( esc_html__( 'Edit', 'infinito' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
	?>
	<!-- comment level 1 -->
	<div class="comment-container"><!-- comment-container -->
		<div class="comment-author-img"><!-- comment-author-img -->
			<?php echo get_avatar( $comment, 64 ); ?>
		</div><!--/ comment-author-img -->
		<div class="comment-big-holder"><!-- comment-big-holder -->
			<div class="comment-details-holder"><!-- comment-details-holder -->
				<div class="comment-author"><?php if ( is_rtl() ) : ?><?php comment_author_link(); ?><i class="wow-person-boy"></i><?php else : ?><i class="wow-person-boy"></i><?php comment_author_link(); ?><?php endif; ?><span class="separator">|</span></div>
				<div class="comment-date"><i class="wow-webapplication-calendar"></i><?php comment_date("d M Y"); ?></div>
				<div class="comment-reply"><?php echo comment_reply_link(array('depth' => $depth, 'max_depth' => $args['max_depth'],'reply_text'=>'Reply')); ?></div>
			</div><!--/ comment-details-holder -->
			<div class="comment-holder"><!-- comment-holder -->
				<div class="the-comment"><?php comment_text(); ?></div>
			</div><!--/ comment-holder -->
		</div><!--/ comment-big-holder -->
		
	</div><!--/ comment-container -->
	<?php
			break;
	endswitch;
}
endif;


/*
=================================================================================================================
wow_admin_notice() - Admin notice/error
=================================================================================================================
*/
function wow_admin_notice($class, $msg=''){
	ob_start();
		if (current_user_can('manage_options')) {
			echo '<div class="'.esc_attr($class).'">
					<p>'.esc_html($msg).'</p>    
				</div>';    
			}
	
}
add_action('admin_notices', 'wow_admin_notice');

/*
=================================================================================================================
wow_sidebars_init() - Register sidebar locations
=================================================================================================================
*/
function wow_sidebars_init() {
	global $wow_options;
	
	
	//add icon to widget title from theme options
	$icon = (!empty($wow_options['blog-widget-heading-icon'])) ? '<i class="widget-icon '.esc_attr($wow_options['blog-widget-heading-icon']).'"></i>' : '';
	$allowed_html_tags = array( 'i' => array( 'class' => array() ) );
	
	//regular sidebars
	register_sidebar( array(
		'name' => 'Left Sidebar',
		'id' => 'left_sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => is_rtl() ? '<h3>'  : '<h3>'.wp_kses( $icon, $allowed_html_tags ),
		'after_title' =>  is_rtl() ? wp_kses( $icon, $allowed_html_tags ).'</h3>' : '</h3>',
	) );	
	register_sidebar( array(
		'name' => 'Right Sidebar',
		'id' => 'right_sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => is_rtl() ? '<h3>'  : '<h3>'.wp_kses( $icon, $allowed_html_tags ),
		'after_title' =>  is_rtl() ? wp_kses( $icon, $allowed_html_tags ).'</h3>' : '</h3>',
	) );
	
	//woocommerce sidebar
	if ( class_exists( 'WooCommerce' ) ){
		register_sidebar( array(
			'name' => 'WooCommerce Sidebar',
			'id' => 'woo_sidebar',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
		'before_title' => is_rtl() ? '<h3>'  : '<h3>'.wp_kses( $icon, $allowed_html_tags ),
		'after_title' =>  is_rtl() ? wp_kses( $icon, $allowed_html_tags ).'</h3>' : '</h3>',
		) );
	}	
	
	//bbpress sidebar
	if ( class_exists( 'bbpress' ) ){
		register_sidebar( array(
			'name' => 'bbPress Sidebar',
			'id' => 'bbpress_sidebar',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
		'before_title' => is_rtl() ? '<h3>'  : '<h3>'.wp_kses( $icon, $allowed_html_tags ),
		'after_title' =>  is_rtl() ? wp_kses( $icon, $allowed_html_tags ).'</h3>' : '</h3>',
		) );
	}
	
	//footer sidebar(s)
	if(!empty($wow_options['footer-layout-rows'])){
		$counter = 0;
		for($i=1;$i<=$wow_options['footer-layout-rows'];$i++){

			if ( $i == 1 ) { $suffix = 'st'; }
			elseif ( $i == 2 ) { $suffix = 'nd'; }
			elseif ( $i == 3 ) { $suffix = 'rd'; }
			elseif ( $i == 4 ) { $suffix = 'th'; }
		
			if ( !empty($wow_options['footer-layout-rows'.$i]) && $wow_options['footer-layout-rows'.$i] != 'custom'){
				
				$row_layouts=explode('+',$wow_options['footer-layout-rows'.$i]);
				
				if(count($row_layouts) > 0){
			
					for($j=0; $j<count($row_layouts); $j++){
						
						$counter++;
						$widget_id = 'footer_'.$i.'_'.$counter;
						register_sidebar( array(
							'name' => esc_attr($i).esc_attr($suffix).' Footer Sidebar : Column '.(esc_attr($j)+1).'  ',
							'id' => esc_attr($widget_id),
							'before_widget' => '<div id="%1$s" class="widget %2$s">',
							'after_widget' => '</div>',
							'before_title' => is_rtl() ? '<div class="title"><h3>'  : '<div class="title"><h3>'.wp_kses( $icon, $allowed_html_tags ).'',
							'after_title' =>  is_rtl() ? wp_kses( $icon, $allowed_html_tags ).'</h3></div>' : '</h3></div>',
						) );					
					}
					$counter = 0;
				}
				else{
						register_sidebar( array(
							'name' => esc_attr($i).esc_attr($suffix).' Footer Sidebar',
							'id' => 'footer_'.esc_attr($i),
							'before_widget' => '<div id="%1$s" class="widget %2$s">',
							'after_widget' => '</div>',
							'before_title' => is_rtl() ? '<div class="title"><h3>'  : '<div class="title"><h3>'.wp_kses( $icon, $allowed_html_tags ).'',
							'after_title' =>  is_rtl() ? wp_kses( $icon, $allowed_html_tags ).'</h3></div>' : '</h3></div>',
						) );					
				}
			}			
			
			elseif ( !empty($wow_options['footer-layout-rows'.$i]) &&  $wow_options['footer-layout-rows'.$i] == 'custom'){
				
				$row_layouts=explode('+',$wow_options['footer-custom-layout-rows'.$i]);
				
				if(count($row_layouts) > 0){
			
					for($j=0; $j<count($row_layouts); $j++){
						
						$counter++;
						$widget_id = 'footer_'.$i.'_'.$counter;
						register_sidebar( array(
							'name' => esc_attr($i).esc_attr($suffix).' Footer Sidebar : Column '.(esc_attr($j)+1).'  ',
							'id' => esc_attr($widget_id),
							'before_widget' => '<div id="%1$s" class="widget %2$s">',
							'after_widget' => '</div>',
							'before_title' => is_rtl() ? '<div class="title"><h3>'  : '<div class="title"><h3>'.wp_kses( $icon, $allowed_html_tags ).'',
							'after_title' =>  is_rtl() ? wp_kses( $icon, $allowed_html_tags ).'</h3></div>' : '</h3></div>',
						) );					
					}
					$counter = 0;
				}
				else{
						register_sidebar( array(
							'name' => esc_attr($i).esc_attr($suffix).' Footer Sidebar',
							'id' => 'footer_'.esc_attr($i),
							'before_widget' => '<div id="%1$s" class="widget %2$s">',
							'after_widget' => '</div>',
							'before_title' => is_rtl() ? '<div class="title"><h3>'  : '<div class="title"><h3>'.wp_kses( $icon, $allowed_html_tags ).'',
							'after_title' =>  is_rtl() ? wp_kses( $icon, $allowed_html_tags ).'</h3></div>' : '</h3></div>',
						) );					
				}
			}
		
		}//end for
	}

}
add_action( 'widgets_init', 'wow_sidebars_init' );

/*
=================================================================================================================
wow_tag_cloud_same_size() - set tags to same font size no matter how many times is being used
=================================================================================================================
*/
function wow_tag_cloud_same_size($args) {
    $args['largest']  = 15;   // largest tag
    $args['smallest'] = 15;   // smallest tag
    $args['unit']     = 'px';
    return $args;
}
add_filter( 'widget_tag_cloud_args', 'wow_tag_cloud_same_size' );


/*
=================================================================================================================
wow_excerpt() - limit excerpt to how many characters it's set
=================================================================================================================
*/
function wow_excerpt($limit, $post_opt =null) {
		$limit = $limit + 1;
		$excerpt = explode(' ', get_the_excerpt($post_opt), $limit);
			if (count($excerpt)>=$limit) {
				array_pop($excerpt);
				$excerpt = implode(" ",$excerpt).'...';
			}
			else {
				$excerpt = implode(" ",$excerpt);
			}
		return $excerpt;
}




/*
=================================================================================================================
wow_excerpt_filter() - get good excerpt even if VC is enabled
=================================================================================================================
*/

function wow_excerpt_filter( $text , $strip_shortcodes = false) {

	$excerpt_length = apply_filters( 'excerpt_length', 55 );
	
	if( $text){
		
		if( $strip_shortcodes == true  ){
			$content = wow_get_string_between($text,'[vc_column_text]','[/vc_column_text]');
			$return = wp_trim_words($content,$excerpt_length);
			if($return){
				return $return;
			}
			else{
				
				return wp_trim_words($text,$excerpt_length);
			}					
		}
		
		return wp_trim_words($text,$excerpt_length);
		
	}
	else{
		$wow_post_content = get_the_content();
		$content = wow_get_string_between($wow_post_content,'[vc_column_text]','[/vc_column_text]');
		$return = wp_trim_words($content,$excerpt_length);
		if($return){
			return $return;
		}
		elseif(  strpos($wow_post_content, "[/vc_row]")  === false ){
			
			return wp_trim_words($wow_post_content,$excerpt_length);
		}
		else{
			return false;
		}
	}

}

add_filter('get_the_excerpt', 'wow_excerpt_filter');



/*
=================================================================================================================
wow_is_blog_page() - check if we are on any archive/author/category/tag page
=================================================================================================================
*/
function wow_is_blog_page() {
    return ( is_archive() || is_author() || is_category() || is_tag() ) ? true : false;
}

/*
=================================================================================================================
wow_is_any_blog_page() - check if we are on any blog page
=================================================================================================================
*/
function wow_is_any_blog_page() {
    return ( is_archive() || is_author() || is_category() || is_tag() || is_home() ) ? true : false;
}

/*
=================================================================================================================
wow_pagination() - custom pagination
=================================================================================================================
*/
function wow_pagination() {
	
	if( is_singular())
		return;
	
	global $wp_query;

	/** Stop execution if there's only 1 page */
	if( $wp_query->max_num_pages <= 1 )
		return;

	$paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
	$max   = intval( $wp_query->max_num_pages );

	/**	Add current page to the array */
	if ( $paged >= 1 )
		$links[] = $paged;

	/**	Add the pages around the current page to the array */
	if ( $paged >= 3 ) {
		$links[] = $paged - 1;
		$links[] = $paged - 2;
	}

	if ( ( $paged + 2 ) <= $max ) {
		$links[] = $paged + 2;
		$links[] = $paged + 1;
	}

	echo '<div class="pagination"><ul>' . "\n";

	/**	Previous Post Link */
	if ( get_previous_posts_link() )
		printf( '<li>%s</li>' . "\n", get_previous_posts_link('&laquo;') );

	/**	Link to first page, plus ellipses if necessary */
	if ( ! in_array( 1, $links ) ) {
		$class = 1 == $paged ? ' class="active"' : '';

		printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( 1 ) ), '1' );

		if ( ! in_array( 2, $links ) )
			echo '<li><a>...</a></li>';
	}

	/**	Link to current page, plus 2 pages in either direction if necessary */
	sort( $links );
	foreach ( (array) $links as $link ) {
		$class = $paged == $link ? ' class="active"' : '';
		printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $link ) ), $link );
	}

	/**	Link to last page, plus ellipses if necessary */
	if ( ! in_array( $max, $links ) ) {
		if ( ! in_array( $max - 1, $links ) )
			echo '<li><a>...</a></li>' . "\n";

		$class = $paged == $max ? ' class="active"' : '';
		printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $max ) ), $max );
	}

	/**	Next Post Link */
	if ( get_next_posts_link() )
		printf( '<li>%s</li>' . "\n", esc_url( get_next_posts_link('&raquo;') ) );

	echo '</ul></div>' . "\n";
}


/*
=================================================================================================================
wow_gravatar() - Custom Gravatar in Settings > Discussion
=================================================================================================================
*/
function wow_gravatar ($avatar_defaults){
	$myavatar = WOW_URI . '/img/gravatar.jpg';
	$avatar_defaults[$myavatar] = "Custom Gravatar";
	return $avatar_defaults;
}


/*
=================================================================================================================
wow_enable_threaded_comments() - Threaded Comments
=================================================================================================================
*/
function wow_enable_threaded_comments(){
	if (!is_admin()) {
		if (is_singular() AND comments_open() AND (get_option('thread_comments') == 1)) {
			wp_enqueue_script('comment-reply');
		}
	}
}

/*
=================================================================================================================
wow_search_form() - Modify the default wordpress search form
=================================================================================================================
*/
function wow_search_form( $form ) {
    $form = '
	<form role="search" method="get" id="searchform" class="searchform" action="' . esc_url( home_url( '/' ) ) . '" >
		<div class="search-widget">
			<input type="text" placeholder="'.esc_html__('Find something...','infinito').'" value="' . esc_attr( get_search_query() ) . '" name="s" id="s" />
			<input type="submit" class="themecolor1_bg" id="searchsubmit" value="'. esc_attr__( 'GO','infinito' ) .'" />
		</div>
    </form>';

    return $form;
}

add_filter( 'get_search_form', 'wow_search_form', 100 );

/*
=================================================================================================================
wow_show_breadcrumb() - wordpress custom breadcrumbs
=================================================================================================================
*/
function wow_show_breadcrumb( array $options = array() ) {

	global $wow_options;
	
	//breadcrumb effect class for hover links 
	$breadcrumb_effect_class = ($wow_options['breadcrumb_link_decoration'] != 'none') ? ' '.esc_attr( $wow_options['breadcrumb_link_decoration'] ) : '';

	//home text pulled from theme options
	$home_text = (!empty($wow_options['breadcrumb_home_title'])) ? esc_attr($wow_options['breadcrumb_home_title']) : 'Home';

	//slug for portfolio category
	$slug_portfolio = ( !empty($wow_options['slug_portfolio']) ) ? esc_attr( $wow_options['slug_portfolio'] ) : 'portfolio_item';
	
	// default values assigned to options
	$options = array_merge(array(
    'crumbId' => 'nav_crumb', // id for the breadcrumb Div
	'crumbClass' => 'nav_crumb', // class for the breadcrumb Div
	'beginningText' => '', // text showing before breadcrumb starts
	'showOnHome' => 0,// 1 - show breadcrumbs on the homepage, 0 - don't show
	'homePageText' => $home_text, // text for the 'Home' link
	'showCurrent' => 1, // 1 - show current post/page title in breadcrumbs, 0 - don't show
	'showTitle'=> 1 // showing post/page title or slug if title to show then 1
   ), $options);
   
    //let's escape them here as we have a large number of use for this variables
    $crumbId 		= esc_attr( $options['crumbId'] );
	$crumbClass 	= esc_attr( $options['crumbClass'] );
	$beginningText  = esc_attr( $options['beginningText'] ) ;
	$showOnHome 	= esc_attr( $options['showOnHome'] );
	$delimiter 		= '<li class="delimiter"><i class="'.esc_attr($wow_options['breadcrumb_sep_icon']).'"></i></li>';
	$homePageText	= esc_attr ( $options['homePageText'] ); 
	$showCurrent	= esc_attr( $options['showCurrent'] ); 
	$beforeTag		= '<li class="current">'; // tag before the current breadcrumb
	$afterTag 		= '</li>'; // tag after the current crumb
	$showTitle 		=  esc_attr( $options['showTitle'] ); 
	
	global $post;

	$wp_query = $GLOBALS['wp_query'];

	//escape here the home URL as we use it multiple times
	$homeLink = esc_url( home_url() ) ;
	
	//get first category name and URL
	$category = get_the_category();
    if ( !empty( $category ) ){
		$first_category = $category[0];
		$cat_url = get_category_link( $first_category );
		$cat_name = $first_category->cat_name;
		$cat_link = '<a href="'.esc_url( $cat_url ).'">'.esc_attr( $cat_name ).'</a>';
	}
	else{
		$cat_link = '';
	}
	
	echo '<div class="breadcrumb_holder"><!-- breadcrumb_holder -->';
		echo '<ul id="'.$crumbId.'" class="'.$crumbClass.$breadcrumb_effect_class.'" >'.$beginningText;

		//if it's a woocommerce page we display the woocommerce breadcrumb
		if ( class_exists( 'WooCommerce' ) &&  wow_is_realy_woocommerce_page () ) {
				woocommerce_breadcrumb();
		}
		
		//if it's bbpress page we display the bbpress breadcrumb
		elseif ( class_exists( 'bbpress' ) && is_bbpress() ){
				bbp_breadcrumb();
		}
		
		//else our theme breadrcumb
		else{
			
			// homepage
			if (is_home() || is_front_page()) {
			  if ($showOnHome == 1){
				  echo $beforeTag . $homePageText . $afterTag;
				}
			}	
			
			// blog
			if( get_post_type() == 'post' && !is_search()){
				
				if( get_option( 'show_on_front' ) == 'posts'){
					echo '<li><a href="' . $homeLink . '">' . $homePageText . '</a></li>'.$delimiter.'<li>'.$cat_link.'</li>';
				}		
				if( get_option( 'show_on_front' ) == 'posts' and is_single()){
					echo $delimiter;
				}		
				elseif( get_option( 'show_on_front' ) == 'page'){
					echo '<li><a href="' . $homeLink . '">' . $homePageText . '</a></li> ' . $delimiter . ' ';
				}
					
				$blog_page_ID = false;
				if( get_option( 'page_for_posts' ) ){
					$blog_page_ID = get_option( 'page_for_posts' );	// Setings / Reading
				}
				
				// Blog page has parent
				$blog_post = get_post( $blog_page_ID );
					
				if( $blog_post->post_parent ){
					
					$parent_id  = $blog_post->post_parent;
					$parents = array();
					
					while( $parent_id ) {
						$page = get_page( $parent_id );
						$parents[] = '<a href="' . esc_url( get_permalink( $page->ID ) ) . '">' . get_the_title( $page->ID ) . '</a>';  //https://developer.wordpress.org/reference/functions/get_the_title/#comment-1653 - it should not be escaped as it may contain html
						$parent_id  = $page->post_parent;
					}
					$parents = array_reverse( $parents );
					$breadcrumbs = array_merge_recursive($breadcrumbs, $parents);
					
				}
				
				$pagination = ( get_query_var('paged') != 0 ) ? $delimiter.'<li>'.esc_html__( 'Page ', 'infinito' ).get_query_var('paged').'</li>' : '';
				$single_title = ( is_single() ) ? $delimiter.'<li>'.get_the_title().'</li>' : '';
				

				if( $blog_page_ID ) {
					
					//we get the blog page title from theme options
					$blog_page_title = ( $wow_options['blog_page_title'] != 'Blog' ) ? esc_attr( $wow_options['blog_page_title'] ) : __('Blog','infinito');	
					
					//output category url and name only in single and category page
					$cat_final =  is_single() || is_category()  ? $delimiter.$beforeTag.$cat_link.$afterTag : '';
		
					echo '<li><a href="'. esc_url( get_permalink( $blog_page_ID ) ) .'">'.$blog_page_title.'</a>'.$cat_final.'</li>'.$single_title.$pagination.'';
				}
		

				if ( is_category() || is_day() || is_month() || is_year() || is_tag() || is_author()  ){
					echo $delimiter;
				}

				// blog set to latest posts
				if( get_post_type() == 'post' and get_option( 'show_on_front' ) == 'posts' ){	
					$single_title = ( is_single() ) ? '<li>'.get_the_title().'</li>' : '';	
					echo $single_title;
				}
			  
				 // category
				if ( is_category() ) {
					echo $beforeTag .esc_html__('Archive by category ','infinito') . single_cat_title('', false) . $afterTag; 
				} 
			  
				// blog day archive
				elseif ( is_day() ) {
					echo '<li><a href="' . esc_url( get_year_link(get_the_time('Y')) ) . '">' . get_the_time('Y') . '</a></li> ' . $delimiter . ' ';
					echo '<li><a href="' . esc_url( get_month_link(get_the_time('Y'),get_the_time('m')) ) . '">' . get_the_time('F') . '</a></li> ' . $delimiter . ' ';
					echo $beforeTag . get_the_time('d') . $afterTag;  
				} 
			  
				// blog month archive
				elseif ( is_month() ) {
					echo '<li><a href="' . esc_url( get_year_link(get_the_time('Y')) ) . '">' . get_the_time('Y') . '</a></li> ' . $delimiter . ' ';
					echo $beforeTag . get_the_time('F') . $afterTag;
				} 
			  
				// blog year archive
				elseif ( is_year() ) {
					echo $beforeTag . get_the_time('Y') . $afterTag;
				} 
			  
				//tag page
				elseif ( is_tag() ) {
					echo $beforeTag .esc_html__('Posts tagged ','infinito') . single_tag_title('', false) . $afterTag;
				} 
			  
				// author page
				elseif ( is_author() ) {
					global $author;
					$userdata = get_userdata($author);
					echo $beforeTag .esc_html__('Articles posted by ','infinito') . esc_html( $userdata->display_name ) . $afterTag;
				}
			}	
			
			else{
			
				echo '<li><a href="' . $homeLink . '">' . $homePageText . '</a></li> ' . $delimiter . ' ';
			
				// search page
				if ( is_search() ) {
					echo $beforeTag .esc_html__('Search results for ','infinito').' "' . esc_attr( get_search_query() ) . '"' . $afterTag;	  
				}
			  
				//portfolio
				elseif ( is_single() && !is_attachment() ) {
				  
					// custom post type portfolio
					if( get_post_type() != 'post' ){
						
						$post_type 			= get_post_type_object(get_post_type());
						$slug 				= $post_type->rewrite;
						$portfolio_page_id 	= $wow_options['portfolio_page'];
						
						//we get the portfolio page title from theme options
						$portfolio_page_title = ( $wow_options['portfolio_page_title'] != 'Portfolio' ) ? esc_attr( $wow_options['portfolio_page_title'] ) : __('Portfolio','infinito');
					
						// portfolio page
						if( $slug['slug'] == $slug_portfolio && $portfolio_page_id ){
							echo '<li><a href="' . esc_url( get_page_link( $portfolio_page_id ) ) . '">'. $portfolio_page_title .'</a></li>'.$delimiter;	
						}
						
						// portfolio category
						if( $portfolio_page_id ){
							
							$terms = get_the_terms( get_the_ID(), 'portfolio_category' );
							if ( ! empty( $terms ) && ! is_wp_error( $terms ) ) {	
								$term = $terms[0];
								echo '<li><a href="'. esc_url( get_term_link( $term ) ) .'">'. esc_html( $term->name ) .'</li></a>'.$delimiter.'<li>'.get_the_title().'</li>';
							}
							else{
								echo '<li><a>'. esc_html__('Uncategorized','infinito') .'</a></li>'.$delimiter.'<li>'.get_the_title().'</li>';
							}
							
						}
						
					}	

				} 
			  
				//taxonomy
				elseif( ! is_page() && get_post_taxonomies() ){
				  
					// portfolio
					$post_type = get_post_type_object( get_post_type() );
					if( $post_type->name == 'portfolio' && $portfolio_page_id = $wow_options['portfolio_page'] ) {
						echo '<li><a href="' . esc_url( get_page_link( $portfolio_page_id ) ) . '">'. get_the_title( $portfolio_page_id ) .'</a></li>'.$delimiter.'';
					}

					echo '<li><a href="'.esc_url( wow_current_url() ).'">' . single_cat_title('', false) . '</a></li>';

				}	  
			  
				// not single, not page, not post, not 404
				elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) {  
					$post_type = get_post_type_object(get_post_type());
					echo $beforeTag . $post_type->labels->singular_name . $afterTag;
					 
				} 
			 
				// attachment
				elseif ( is_attachment() ) {	 
					$parent = get_post($post->post_parent);
					$cat = get_the_category($parent->ID); $cat = $cat[0];
					echo '<li>'.get_category_parents($cat, TRUE, '</li> ' . $delimiter . ' ');
					echo '<li><a href="' . esc_url( get_permalink($parent) ) . '">' . $parent->post_title . '</a></li>';
					if ($showCurrent == 1) echo ' ' . $delimiter . ' ' . $beforeTag . get_the_title() . $afterTag;		  
				} 
			 
				// for portfolio
				elseif ( is_page() && !$post->post_parent ) {
					$title =($showTitle)? get_the_title() : $post->post_name;
					$portfolio_page_id 	= $wow_options['portfolio_page'];
					
					//we get the portfolio page title from theme options
					$portfolio_page_title = ( $wow_options['portfolio_page_title'] != 'Portfolio' ) ? esc_attr( $wow_options['portfolio_page_title'] ) : __('Portfolio','infinito');	
					
					if( is_page_template('portfolio.php') && $portfolio_page_id ){
						echo '<li><a href="' . esc_url( get_page_link( $portfolio_page_id ) ) . '">'. $portfolio_page_title .'</a></li>';	
					}
					else{
						if ($showCurrent == 1) { echo $beforeTag .  $title . $afterTag; }
					}
				} 
			  
				// page and post parrent
				elseif ( is_page() && $post->post_parent ) {
				
					$parent_id  = $post->post_parent;
					$breadcrumbs = array();
					while ($parent_id) {
						$page = get_page($parent_id);
						$breadcrumbs[] = '<li><a href="' . esc_url( get_permalink($page->ID) ) . '">' . get_the_title($page->ID) . '</a></li>';
						$parent_id  = $page->post_parent;
					}
					
					$breadcrumbs = array_reverse($breadcrumbs);
					
					for ($i = 0; $i < count($breadcrumbs); $i++) {
						echo $breadcrumbs[$i];
						if ($i != count($breadcrumbs)-1) echo ' ' . $delimiter . ' ';
					}
					
					$title =($showTitle)? get_the_title():$post->post_name;
				   
					if ($showCurrent == 1) { echo ' ' . $delimiter . ' ' . $beforeTag . $title . $afterTag; }

				} 
		 
				//404 page
				elseif ( is_404() ) { 
					echo $beforeTag .esc_html__('Error 404','infinito'). $afterTag; 
				}
			  
			  
				//pagination
				if ( get_query_var('paged') ) {
					if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() || is_tax()) echo ' ';
					echo $delimiter.'<li>'.esc_html__('Page','infinito') . ' ' . get_query_var('paged').'</li> ';
					if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() || is_tax()) echo ' ';
				}
				
			
			}
	
	}//big else end
		echo '</ul>';
	echo '</div><!-- /breadcrumb_holder -->';	
}

/*
=================================================================================================================
wow_show_page_title() - Display the page title before breadcrumb
=================================================================================================================
*/
function wow_show_page_title() {
	global $wow_options,$author;
	
	//we get the blog page title from theme options
	$blog_page_title = ( $wow_options['blog_page_title'] != 'Blog' ) ? esc_attr( $wow_options['blog_page_title'] ) : __('Blog','infinito');	
	
	//we get the portfolio page title from theme options
	$portfolio_page_title = ( $wow_options['portfolio_page_title'] != 'Portfolio' ) ? esc_attr( $wow_options['portfolio_page_title'] ) : __('Portfolio','infinito');

	//author user data
	$userdata = get_userdata($author);
	
	echo '<h1>';
		if ( is_tax() ) {
			echo esc_attr( single_cat_title('', false) ); 
		} 
		elseif ( is_home() ) {
			echo $blog_page_title; //escaped above
		}		
		elseif ( is_category() ) {
			echo esc_attr( single_cat_title('', false) );
		}		
		elseif ( is_day() ) {
			echo esc_attr( get_the_time('d').' '.get_the_time('F').' '.get_the_time('Y') );
		}		
		elseif ( is_month() ) {
			echo esc_attr( get_the_time('F').' '.get_the_time('Y') );
		}		
		elseif ( is_year() ) {
			echo esc_attr( get_the_time('Y') );
		}		
		elseif ( is_author() ) {
			echo esc_attr( $userdata->display_name );
		}		
		elseif ( is_tag() ) {
			echo esc_html__( 'Posts tagged', 'infinito' ).' '.esc_attr( single_tag_title ( '', false ) );
		}		
		elseif ( is_404() ) {
			echo esc_html__( 'Error 404', 'infinito' );
		}
		elseif ( is_search() ) {
			echo esc_html__( 'Search results for', 'infinito' ).' "'.get_search_query().'"';
		}
		elseif ( is_page_template('portfolio.php')  ){
			echo $portfolio_page_title; //escaped above
		}
		elseif ( class_exists('WooCommerce') &&  wow_is_realy_woocommerce_page () ){
			if ( is_shop() ) {
				echo esc_attr( woocommerce_page_title() );
			}
			else {
				echo html_entity_decode( esc_attr( get_the_title() ) );
			}
		}
		else{
			echo html_entity_decode( esc_attr( get_the_title() ) );
		}
	echo '</h1>';
}
	

/*
=================================================================================================================
wow_customtaxonomy_archive_display() - Fix for custom taxonomy pagination
=================================================================================================================
*/
function wow_customtaxonomy_archive_display ( $query ) {
	if (($query->is_main_query()) && (is_tax('portfolio_category'))){
		$query->set( 'post_type', 'portfolio' );                 
		$query->set( 'posts_per_page', '1' );
	}
}
add_action( 'pre_get_posts', 'wow_customtaxonomy_archive_display' );


/*
=================================================================================================================
wow_get_the_post_id() - Return the post/page id inside or outside the loop
=================================================================================================================
*/
function wow_get_the_post_id() {
  if (in_the_loop()) {
       $post_id = get_the_ID();
  } else {
       global $wp_query;
       $post_id = $wp_query->get_queried_object_id();
         }
  return $post_id;
}

/*
=================================================================================================================
wow_duplicate_post_as_draft() - creates post duplicate as a draft and redirects then to the edit post screen
=================================================================================================================
*/
function wow_duplicate_post_as_draft(){
	global $wpdb;
	if (! ( isset( $_GET['post']) || isset( $_POST['post'])  || ( isset($_REQUEST['action']) && 'wow_duplicate_post_as_draft' == $_REQUEST['action'] ) ) ) {
		wp_die('No post to duplicate has been supplied!');
	}
 
	/*
	 * Nonce verification
	 */
	if ( !isset( $_GET['duplicate_nonce'] ) || !wp_verify_nonce( $_GET['duplicate_nonce'], basename( __FILE__ ) ) )
		return;
 
	/*
	 * get the original post id
	 */
	$post_id = (isset($_GET['post']) ? absint( $_GET['post'] ) : absint( $_POST['post'] ) );
	/*
	 * and all the original post data then
	 */
	$post = get_post( $post_id );
 
	/*
	 * if you don't want current user to be the new post author,
	 * then change next couple of lines to this: $new_post_author = $post->post_author;
	 */
	$current_user = wp_get_current_user();
	$new_post_author = $current_user->ID;
 
	/*
	 * if post data exists, create the post duplicate
	 */
	if (isset( $post ) && $post != null) {
 
		/*
		 * new post data array
		 */
		$args = array(
			'comment_status' => $post->comment_status,
			'ping_status'    => $post->ping_status,
			'post_author'    => $new_post_author,
			'post_content'   => $post->post_content,
			'post_excerpt'   => $post->post_excerpt,
			'post_name'      => $post->post_name,
			'post_parent'    => $post->post_parent,
			'post_password'  => $post->post_password,
			'post_status'    => 'draft',
			'post_title'     => $post->post_title,
			'post_type'      => $post->post_type,
			'to_ping'        => $post->to_ping,
			'menu_order'     => $post->menu_order
		);
 
		/*
		 * insert the post by wp_insert_post() function
		 */
		$new_post_id = wp_insert_post( $args );
 
		/*
		 * get all current post terms ad set them to the new post draft
		 */
		$taxonomies = get_object_taxonomies($post->post_type); // returns array of taxonomy names for post type, ex array("category", "post_tag");
		foreach ($taxonomies as $taxonomy) {
			$post_terms = wp_get_object_terms($post_id, $taxonomy, array('fields' => 'slugs'));
			wp_set_object_terms($new_post_id, $post_terms, $taxonomy, false);
		}
 
		/*
		 * duplicate all post meta just in two SQL queries
		 */
		$post_meta_infos = $wpdb->get_results("SELECT meta_key, meta_value FROM $wpdb->postmeta WHERE post_id=$post_id");
		if (count($post_meta_infos)!=0) {
			$sql_query = "INSERT INTO $wpdb->postmeta (post_id, meta_key, meta_value) ";
			foreach ($post_meta_infos as $meta_info) {
				$meta_key = $meta_info->meta_key;
				if( $meta_key == '_wp_old_slug' ) continue;
				$meta_value = addslashes($meta_info->meta_value);
				$sql_query_sel[]= "SELECT $new_post_id, '$meta_key', '$meta_value'";
			}
			$sql_query.= implode(" UNION ALL ", $sql_query_sel);
			$wpdb->query($sql_query);
		}
 
 
		/*
		 * finally, redirect to the edit post screen for the new draft
		 */
		wp_redirect( admin_url( 'post.php?action=edit&post=' . $new_post_id ) );
		exit;
	} else {
		wp_die('Post creation failed, could not find original post: ' . $post_id);
	}
}
add_action( 'admin_action_wow_duplicate_post_as_draft', 'wow_duplicate_post_as_draft' );


/*
=================================================================================================================
wow_duplicate_post_link() - Add the duplicate link to action list for post_row_actions
=================================================================================================================
*/
function wow_duplicate_post_link( $actions, $post ) {
	if (current_user_can('edit_posts')) {
		$actions['duplicate'] = '<a href="' . esc_url( wp_nonce_url('admin.php?action=wow_duplicate_post_as_draft&post=' . $post->ID, basename(__FILE__), 'duplicate_nonce' ) ) . '" title="Duplicate this item" rel="permalink">Duplicate post</a>';
	}
	return $actions;
}
add_filter( 'post_row_actions', 'wow_duplicate_post_link', 10, 2 );


/*
=================================================================================================================
wow_duplicate_page_link() - Add the duplicate link to action list for page_row_actions
=================================================================================================================
*/
function wow_duplicate_page_link( $actions, $post ) {
	if (current_user_can('edit_posts')) {
		$actions['duplicate'] = '<a href="' . esc_url( wp_nonce_url('admin.php?action=wow_duplicate_post_as_draft&post=' . $post->ID, basename(__FILE__), 'duplicate_nonce' ) ) . '" title="Duplicate this item" rel="permalink">Duplicate page</a>';
	}
	return $actions;
}
add_filter('page_row_actions', 'wow_duplicate_page_link', 10, 2);


/*
=================================================================================================================
wow_disable_gutenberg() - Disable the gutenberg editor across all website( User controled - by default it's enabled )
=================================================================================================================
*/
function wow_disable_gutenberg() {
	
	global $wow_options;
	if ( $wow_options['gutenberg'] == '0' ){

		if (version_compare($GLOBALS['wp_version'], '5.0-beta', '>')) {
			// disable for posts
			add_filter('use_block_editor_for_post', '__return_false', 10);

			// disable for post types
			add_filter('use_block_editor_for_post_type', '__return_false', 10);		
		} 
		else {
			// disable for posts
			add_filter('gutenberg_can_edit_post', '__return_false', 10);

			// disable for post types
			add_filter('gutenberg_can_edit_post_type', '__return_false', 10);
				
		}
		
	}
}
add_action('admin_init','wow_disable_gutenberg');


/*
=================================================================================================================
wow_hide_gutenberg_button() - Hide the Gutenberg Editor button across all website( User controled - by default it's enabled )
=================================================================================================================
*/
function wow_hide_gutenberg_button() {
	
	global $wow_options;
	if ( $wow_options['gutenberg'] == '0' ){
	
		echo '<style type="text/css">';
			echo 'a.wpb_switch-to-gutenberg{ display:none !important }';
		echo '</style>';
		
	}
}
add_action('admin_footer','wow_hide_gutenberg_button');