<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/*
=================================================================================================================
wow_get_demo_file() - get the demo zip file
=================================================================================================================
*/
function wow_get_demo_file( $demo ){

	if( !$demo ) return false;
	
	$query = add_query_arg( array(
		'code' => wow_get_envato_purchase_code(),
		'site_url' => get_site_url(),
		'demo' => $demo,
	), 'https://wowlayers.com/auth/infinito/download.php' );

	$content = wp_remote_get( $query , array( 'timeout' => 60 )  ) ;

	if ( is_wp_error( $content ) ) {
		return esc_html__( 'Could not communicate with Infinito server. Please try again or contact us if the problem persists.','infinito' ) ;
	}
	
	$content_type =  wp_remote_retrieve_header( $content, 'content-type' );
	
	$error = $content_type == 'application/zip' ? false : true;
	
	if( $error ){
		return esc_attr( $content["body"] );
	}
	else{
		if( $content["body"] ){
			
			$access_type = get_filesystem_method();
			
			if($access_type === 'direct')
			{
				
				/* you can safely run request_filesystem_credentials() without any issues and don't need to worry about passing in a URL */
				$creds = request_filesystem_credentials(site_url() . '/wp-admin/', '', false, false, array());
				
				/* initialize the API */
				if ( ! WP_Filesystem($creds) ) {
					/* any problems and we exit */
					return false;
				}

				//save file to temp folder
				$upload_dir = wp_get_upload_dir();
				$zip_path = $upload_dir["path"] . "/infinito_tmp_folder/";
				$file = $zip_path . "infinito-".esc_attr( $demo )."/infinito-".esc_attr( $demo ).".zip";	

				if ( !file_exists( $zip_path ) ) {
					mkdir( $zip_path , 0755);
				}				
				if ( !file_exists( $zip_path . "infinito-".esc_attr( $demo ) ) ) {
					mkdir( $zip_path . "infinito-".esc_attr( $demo ) , 0755);
				}
				
				$file_saved = file_put_contents( $file , $content["body"] );
				
				if( $file_saved === false ){
					return esc_html__( "Temp file was not saved",'infinito' ); 
				}
			}			
			else{
				/* don't have direct write access. Prompt user with our notice */
				return esc_html__( "You don't have permission to write.",'infinito' ); 	
			}						
			
			//get path
			$path = pathinfo( realpath( $file ), PATHINFO_DIRNAME );

			$unzipfile = unzip_file( $file , $path );
			
			if ( !$unzipfile ) {
				return esc_html__( "There was an error unzipping the temp file.",'infinito' );       
			}					
			
			return "success";					
		}
	}
}

/*
=================================================================================================================
wow_set_shop_pages() - if a shop demo is installed, set shop, cart, checkout and myaccount pages 
=================================================================================================================
*/
function wow_set_shop_pages( $demo ){
	
	$is_shop_demo = in_array( $demo, array('bike-shop','shoes-shop'));
	
	if( $is_shop_demo ){
		
		$pages = array( "woocommerce_shop_page_id" => "Shop" , "woocommerce_cart_page_id" => "Cart" , "woocommerce_checkout_page_id" => "Checkout" , "woocommerce_myaccount_page_id" => "My account"  );
		
		foreach( $pages as $option => $page){
			$page_obj = get_page_by_title( $page );
			if( $page_obj->ID ){
				update_option( $option , $page_obj->ID );
			}
		}
	}
	
}

/*
=================================================================================================================
wow_importer_ajax_handler() - importer ajax handler
=================================================================================================================
*/
function wow_importer_ajax_handler() {
	$error_msg = array();
	$success = true;
	
	if( get_option( "infinito_license_active" ) != "active" ){
		echo json_encode(array("success"=>"Activate theme","site_url"=>esc_url( get_site_url() ),"theme_options_url" =>  esc_url( get_admin_url() )."admin.php?page=infinito_options","title"=>$title));
		die();
	}

    if ( current_user_can( 'manage_options' )) {
		
		if( isset( $_POST['action'] )  &&  isset( $_POST['demo'] )   &&  isset( $_POST['title'] )  ){
			
			$action 				= stripslashes( wp_filter_kses( $_POST['action'] ));
			$import_content 		= stripslashes( wp_filter_kses( $_POST['import_content'] ));
			$import_theme_options 	= stripslashes( wp_filter_kses( $_POST['import_theme_options'] ));
			$demo 					= stripslashes( wp_filter_kses( $_POST['demo'] ));		
			$title 					= stripslashes( wp_filter_kses( $_POST['title'] ));
			
			$delete_import_content 	= stripslashes( wp_filter_kses( $_POST['delete_import_content'] ));
			$delete_posts 			= stripslashes( wp_filter_kses( $_POST['delete_posts'] ));
			$delete_pages 			= stripslashes( wp_filter_kses( $_POST['delete_pages'] ));
			$delete_portfolio 		= stripslashes( wp_filter_kses( $_POST['delete_portfolio'] ));
			$delete_products 		= stripslashes( wp_filter_kses( $_POST['delete_products'] ));
			$delete_widgets 		= stripslashes( wp_filter_kses( $_POST['delete_widgets'] ));
			$delete_menus 			= stripslashes( wp_filter_kses( $_POST['delete_menus'] ));
			$delete_media 			= stripslashes( wp_filter_kses( $_POST['delete_media'] ));
			
			if( $delete_import_content ){
				
				if( $delete_posts ){
					if ( $delete_posts == 'trash' ){
						wow_get_all_posts_for_deletion( "post" );
					}
					else{
						wow_get_all_posts_for_deletion( "post" , true );
					}
				}
				
				if( $delete_pages ){
					if ( $delete_pages == 'trash' ){
						wow_get_all_posts_for_deletion( "page" );
					}
					else{
						wow_get_all_posts_for_deletion( "page" , true );
					}
				}
				
				if( $delete_portfolio ){
					if ( $delete_portfolio == 'trash' ){
						wow_get_all_posts_for_deletion( "portfolio" );
					}
					else{
						wow_get_all_posts_for_deletion( "portfolio" , true );
					}
				}				
				
				if( $delete_products ){
					if ( $delete_products == 'trash' ){
						wow_get_all_posts_for_deletion( "product" );
					}
					else{
						wow_get_all_posts_for_deletion( "product" , true );
					}
				}
				
				if( $delete_widgets ){
					
					if ( $delete_widgets == 'inactive' ){
						wow_set_inactive_widgets();
					}
					else{
						wow_delete_widgets();
					}
				}					
				if( $delete_menus ){
					wp_delete_nav_menu('Main');
					wp_delete_nav_menu('Homepage main');
					wp_delete_nav_menu('Main left');
					wp_delete_nav_menu('Main right');
					wp_delete_nav_menu('Footer links');
					wp_delete_nav_menu('WooCommerce info bar');					
				}
				
				if ( $delete_media ){
					wow_delete_media();
				}
				
			}

			if( $action == 'wow_importer' && $demo ){
				
				//get file to temp folder
				$response = wow_get_demo_file( $demo );
				if( $response != 'success' ){
					echo json_encode(array("success"=>esc_attr( $response ),"site_url"=>esc_url( get_site_url() ),"theme_options_url" =>  esc_url( get_admin_url() )."admin.php?page=infinito_options","title"=>$title));
					die();
				}
				
				//import theme options

				if( $import_theme_options == "true" ){
					
					$response = wow_importer_theme_options( $demo );
					if( $response != 'success' ){
						$error_msg []= $response;
						$success = false;
					}
					
				}

				//import content
				if( $import_content  == "true" ){
					
					//display a message to user if execution time exceeded
					function wow_handleFatalPhpError() {
					   $last_error = error_get_last();
					   if( $last_error['type'] === E_ERROR ) {
						 if ( stripos( $last_error['message'] , 'Maximum execution' ) !== false ){
							die();
						 }
					   }
					}

					register_shutdown_function('wow_handleFatalPhpError');							
					
					//import wordpress content
					$response = wow_importer_wp( $demo );
					if( $response != 'success' ){
						$error_msg []= $response;
						$success = false; 						
					}
					else{
						wow_importer_menus();
					}
					
					//import rev slider
					if ( wow_importer_revolution_slider_is_required( $demo ) ){
						$response = wow_importer_revolution_slider( $demo );
						if( $response != 'success' ){
							$error_msg []= $response;
							$success = false;
						}
					}					

					//import widgets
					$response = wow_importer_widgets( $demo );
					if( $response != 'success' ){
						$error_msg []= $response;
						$success = false;
					}						

					// Set reading options
					// Front Page
					$homepage = get_page_by_title( 'Homepage' );
					if( $homepage->ID ){
						update_option( 'show_on_front', 'page' );
						update_option( 'page_on_front', $homepage->ID ); 
					}
					
					// Blog Page
					$posts_page = get_page_by_title( 'Blog' );
					if( $posts_page->ID ){
						update_option( 'page_for_posts', $posts_page->ID ); 
					}
					
					wow_set_shop_pages( $demo );
					
				}

				//clean the mess - delete zip file and demo directory after importing
				$upload_dir = wp_get_upload_dir();
				$temp_dir = $upload_dir["path"] . "/infinito_tmp_folder/";
				wow_delete_temp_Directory( $temp_dir );
				
				if( $success == true ){
					echo json_encode(array("success"=>"success","site_url"=>esc_url( get_site_url() ),"theme_options_url" =>  esc_url( get_admin_url() )."admin.php?page=infinito_options","title"=>$title));
				}
				else{
					echo json_encode(array("success"=>$error_msg,"site_url"=>esc_url( get_site_url() ),"theme_options_url" =>  esc_url( get_admin_url() )."admin.php?page=infinito_options","title"=>$title), JSON_FORCE_OBJECT);					
				}
				
				die();			
			}
		}		
	}
	echo json_encode(array("success"=>"fail","site_url"=>esc_url( get_site_url() ),"theme_options_url" => esc_url( get_admin_url() )."admin.php?page=infinito_options"));
	die();
} 
add_action('wp_ajax_wow_importer', 'wow_importer_ajax_handler'); // wp_ajax_{action}

/*
=================================================================================================================
wow_importer_theme_options() - theme options importer
=================================================================================================================
*/
function wow_importer_theme_options	( $demo = null ){

	if( !$demo ) return esc_html__( 'For some reason theme options were not imported.','infinito' );
	
	$upload_dir = wp_get_upload_dir(); 
	
	$file = $upload_dir["path"] . "/infinito_tmp_folder/infinito-" . $demo . "/wow_options.json";

	$content = file_get_contents( $file );
	$options = json_decode($content, true);
	
	$update = update_option('wow_options',$options);

	if( $update == true ){
		return "success";
	}
	return esc_html__( 'For some reason theme options were not imported.','infinito' );
}


/*
=================================================================================================================
wow_importer_wp() - wordpress content importer
=================================================================================================================
*/	
function wow_importer_wp( $demo = null ){
	
	if( !$demo ) return esc_html__( 'For some reason content was not imported.','infinito' );
		
	if ( !defined('WP_LOAD_IMPORTERS') ) define('WP_LOAD_IMPORTERS', true); // we are loading importers

	if ( ! class_exists( 'WP_Importer' ) ) { // if main importer class doesn't exist
		$wp_importer = ABSPATH . 'wp-admin/includes/class-wp-importer.php';
		include $wp_importer;
	}

	$wp_import = WOW_DIR . '/inc/importer/wordpress-importer.php';
	include $wp_import;

	if ( class_exists( 'WP_Importer' ) && class_exists( 'WP_Import_Infinito' ) ) { // check for main import class and wp import class


		$upload_dir = wp_get_upload_dir(); 
		$file = $upload_dir["path"] . "/infinito_tmp_folder/infinito-" . $demo . "/content.xml";
					
		$importer = new WP_Import_Infinito();
		$file_clean = trim(preg_replace('/\s+/', ' ', $file)); //importer is buggy if has the XML file contain strings with new lines
		$importer->fetch_attachments = true;
		ob_start();
		$importer->import($file_clean);
		ob_end_clean();						
						
		return "success";
	}
	
	return esc_html__( 'For some reason content was not imported.','infinito' );
}

/*
=================================================================================================================
wow_importer_revolution_slider_is_required() - revolution slider is required for content import
=================================================================================================================
*/
function wow_importer_revolution_slider_is_required( $demo ){
	
	require_once( WOW_DIR . "/functions/admin/demos-list.php");
	
	foreach( $demos_array as $val ){
		
		if( $val["basename"] ==  $demo ){
			
			if( in_array("Revolution Slider", $val["plugins"]["required"] ) ){
				return true;
			}
			else return false;
			
		}		
	}
	return false;
}


/*
=================================================================================================================
wow_importer_revolution_slider() - revolution slider importer
=================================================================================================================
*/
function wow_importer_revolution_slider( $demo = null ){

	if( !$demo ) return esc_html__( 'For some reason Revolution Slides was not imported.','infinito' );
	
	if( ! class_exists( 'RevSliderSlider' ) ){
		return false;
	}

	$upload_dir = wp_get_upload_dir(); 
	$path = $upload_dir["path"] . "/infinito_tmp_folder/infinito-" . $demo;
	$files = wow_parse_temp_files( $path );

	ob_start();
		
	foreach( $files as $file ){
			$filepath = wp_normalize_path( $file );
			$slider = new RevSliderSlider();
			$return = $slider->importSliderFromPost( true, false, $filepath );			
	}
		
	ob_clean();
	ob_end_clean();
	
	if( is_array( $return ) ){
		return "success";
	}
		
	return esc_html__( 'For some reason Revolution Slides was not imported.','infinito' );
		
}

/*
=================================================================================================================
wow_parse_temp_files() - parse all the files in a given path
=================================================================================================================
*/
function wow_parse_temp_files( $path ){
$return = array();
	$files = array_diff( scandir( $path ), array( '..', '.' ) );
	foreach( $files as $file ){
		
		if ( strpos( $file, 'rev_slider') !== false) {
			$return []= $path."/".$file;
		}		
	}
	return $return;
}
	
/*
=================================================================================================================
wow_importer_menus() - menu importer
=================================================================================================================
*/
function wow_importer_menus(){
	$locations = array();

    $menus = wp_get_nav_menus(); // registered menus
	
		if( is_array( $menus ) ){
				
			foreach( $menus as $menu ) {
					
				if( $menu->name == 'Main' ) {
					$locations['main_nav'] = $menu->term_id;
				}
				
				if( $menu->name == 'WooCommerce info bar' ) {
					$locations['woo_nav'] = $menu->term_id;
				}
				
				if( $menu->name == 'Main left' ) {
					$locations['main_nav_left'] = $menu->term_id;
				}
				
				if( $menu->name == 'Main right' ) {
					$locations['main_nav_right'] = $menu->term_id;
				}				
				if( $menu->name == 'Homepage main' ) {
					$homepage = get_page_by_title( 'Homepage' );
					$page_ID = $homepage->ID;
					update_post_meta( $page_ID , 'wow-different-menu', $menu->term_id );
				}
			}

			set_theme_mod( 'nav_menu_locations', $locations ); // set Main menu to locations
			return true;
		}
		
	return false;
}


/*
=================================================================================================================
wow_importer_widgets() - widgets importer
=================================================================================================================
*/
function wow_importer_widgets( $demo ){
	
	if( !$demo ) return false;
	global $wp_filesystem;

	$upload_dir = wp_get_upload_dir(); 
	$file = $upload_dir["path"] . "/infinito_tmp_folder/infinito-" . $demo . "/widget_data.json";
		
	$content = file_get_contents( $file );	
	return wow_parse_widgets( $content );
	
}

/*
=================================================================================================================
wow_parse_widgets() - parse widgets
=================================================================================================================
*/
function wow_parse_widgets( $data ) {
    
	$widgets = array();
    $json_data = json_decode( $data, true );

    $sidebar_data = $json_data[0];
    $widget_data = $json_data[1];
	
	if( !is_array( $sidebar_data ) && empty( $sidebar_data ) && !is_array( $widget_data ) && empty( $widget_data ) ){
		return esc_html__( 'Something went wrong with the widget import. Code:200.','infinito' );		
	}
	
	foreach( $widget_data as $key=> $val){

		foreach(  $val as $jjj => $number){
	
			if( is_int($jjj) ){
				$widgets[$key][$jjj] = 'on';
			}
		}
	}

	foreach ( $sidebar_data as $title => $sidebar ) {
		$count = count( $sidebar );
		for ( $i = 0; $i < $count; $i++ ) {
			$widget = array( );
			$widget['type'] = trim( substr( $sidebar[$i], 0, strrpos( $sidebar[$i], '-' ) ) );
			$widget['type-index'] = trim( substr( $sidebar[$i], strrpos( $sidebar[$i], '-' ) + 1 ) );
			
			
			if ( !isset( $widgets[$widget['type']][$widget['type-index']] ) ) {
				unset( $sidebar_data[$title][$i] );
			}
			
		}
		$sidebar_data[$title] = array_values( $sidebar_data[$title] );
	}

	foreach ( $widgets as $widget_title => $widget_value ) {
		foreach ( $widget_value as $widget_key => $widget_value ) {
			$widgets[$widget_title][$widget_key] = $widget_data[$widget_title][$widget_key];
		}
	}

	$sidebar_data = array( array_filter( $sidebar_data ), $widgets );

    return wow_parse_widgets_data( $sidebar_data );
}

/*
=================================================================================================================
wow_parse_widgets_data() - parse widgets data
=================================================================================================================
*/
function wow_parse_widgets_data( $import_array ) {
    global $wp_registered_sidebars;

	if(  !is_array( $import_array ) && empty( $import_array ) ){
		return esc_html__( 'Something went wrong with the widget import. Code:201.','infinito' );	
	}

    $sidebars_data = $import_array[0];
    $widget_data = $import_array[1];
	
    $current_sidebars = get_option( 'sidebars_widgets' );
    $new_widgets = array( );

	foreach ( $sidebars_data as $import_sidebar => $import_widgets ) {

		foreach ( $import_widgets as $import_widget ) {
								
				$title = trim( substr( $import_widget, 0, strrpos( $import_widget, '-' ) ) );
				$index = trim( substr( $import_widget, strrpos( $import_widget, '-' ) + 1 ) );
				$current_widget_data = get_option( 'widget_' . $title );
				$new_widget_name = wow_get_new_widget_name( $title, $index );
				$new_index = trim( substr( $new_widget_name, strrpos( $new_widget_name, '-' ) + 1 ) );

				if ( !empty( $new_widgets[ $title ] ) && is_array( $new_widgets[$title] ) ) {
					while ( array_key_exists( $new_index, $new_widgets[$title] ) ) {
						$new_index++;
					}
				}
					
				$current_sidebars[$import_sidebar][] = $title . '-' . $new_index;
					
				if ( array_key_exists( $title, $new_widgets ) ) {
					$new_widgets[$title][$new_index] = $widget_data[$title][$index];
					$multiwidget = $new_widgets[$title]['_multiwidget'];
					unset( $new_widgets[$title]['_multiwidget'] );
					$new_widgets[$title]['_multiwidget'] = $multiwidget;
				}
					
				else {
					$current_widget_data[$new_index] = $widget_data[$title][$index];
					$current_multiwidget = array_key_exists('_multiwidget', $current_widget_data) ? $current_widget_data['_multiwidget'] : false;
					$new_multiwidget = array_key_exists('_multiwidget', $widget_data[$title]) ? $widget_data[$title]['_multiwidget'] : false;
					$multiwidget = ($current_multiwidget != $new_multiwidget) ? $current_multiwidget : 1;
					unset( $current_widget_data['_multiwidget'] );
					$current_widget_data['_multiwidget'] = $multiwidget;
					$new_widgets[$title] = $current_widget_data;
				}
				

		}
	}

	if ( isset( $new_widgets ) && isset( $current_sidebars ) ) {
		update_option( 'sidebars_widgets', $current_sidebars );

		foreach ( $new_widgets as $title => $content ) {
			
			//Navigation menu widget : add the id of the menu
			if( $title == 'nav_menu' ){
				$content = wow_change_widget_menu_id( "nav_menu", $content );				
			}
			
			$content = apply_filters( 'widget_data_import', $content, $title );
			update_option( 'widget_' . $title, $content );
		}

		return "success";
	}

	return esc_html__( 'Something went wrong with the widget import. Code:202.','infinito' );
}

/*
=================================================================================================================
wow_change_widget_menu_id() - change the id of the menu for Navigation menu widget
=================================================================================================================
*/
function wow_change_widget_menu_id( $needle_key,  $array ){
  
  foreach($array AS $key => &$value){   
    if(is_array($value)){
		foreach( $value AS $key2 => &$value2 ){
			if( $key2 == $needle_key ){
				$value2 =  wow_get_menu_id_for_nav_menu_widget();
			}
		}
    }
  }	
  return $array;
}



/*
=================================================================================================================
wow_get_menu_for_nav_menu_widget() - Footer links menu id or some valid menu id
=================================================================================================================
*/
function wow_get_menu_id_for_nav_menu_widget(){
    $menus = wp_get_nav_menus(); // registered menus
		if(is_array($menus)){
				
			foreach($menus as $menu) {
					
				if( $menu->name == 'Footer links' ) {
					return $menu->term_id;
				} 
			}
			//if menu Footer links is not found get another menu
			return $menu->term_id;
		}	
}

/*
=================================================================================================================
wow_get_new_widget_name() - get widgets name
=================================================================================================================
*/
function wow_get_new_widget_name( $widget_name, $widget_index ) {
		
		$current_sidebars = get_option( 'sidebars_widgets' );
		$all_widget_array = array( );
		foreach ( $current_sidebars as $sidebar => $widgets ) {
			if ( !empty( $widgets ) && is_array( $widgets ) && $sidebar != 'wp_inactive_widgets' ) {
				foreach ( $widgets as $widget ) {
					$all_widget_array[] = $widget;
				}
			}
		}
		while ( in_array( $widget_name . '-' . $widget_index, $all_widget_array ) ) {
			$widget_index++;
		}
		$new_widget_name = $widget_name . '-' . $widget_index;
		return $new_widget_name;
}

/*
=================================================================================================================
wow_get_all_posts_for_deletion() - get all posts by $post_type and delete / trash them
=================================================================================================================
*/
function wow_get_all_posts_for_deletion( $post_type , $permanently = false ){
	
	$query = new WP_Query( array(
		'post_type' => $post_type,
		'post_status' => 'publish',
		'posts_per_page' => -1
	));

	while ( $query->have_posts() ) {
		$query->the_post();
		if ( $post_type === 'post' or $post_type === 'page' ){
			wp_delete_post( get_the_ID(), $permanently );
		}
		else{
			if ( $permanently === true ){
				wp_delete_post( get_the_ID(), true );
			}
			else{
				wp_trash_post ( get_the_ID() );
			}
		}
	}

	wp_reset_query();
	
}

/*
=================================================================================================================
wow_set_inactive_widgets() - set all widgets to inactive
=================================================================================================================
*/
function wow_set_inactive_widgets( $remove = null ){
	
	$temp = array();	
	$sidebars_widgets = get_option("sidebars_widgets");	

	foreach( $sidebars_widgets as $sidebars_widget_name => $sidebars_widget ){
		
		$is_dinamic = substr( $sidebars_widget_name, 0, 7 );
		
		if( $sidebars_widget_name == 'left_sidebar' ||  $sidebars_widget_name == 'right_sidebar' || $is_dinamic =="footer_"  ){
			
			foreach( $sidebars_widget as $key => $val ){
				$temp[$val] = '1';				
			}
			unset( $sidebars_widgets["left_sidebar"] );
			unset( $sidebars_widgets["right_sidebar"] );
			
			$sidebars_widgets["left_sidebar"] = array();
			$sidebars_widgets["right_sidebar"] = array();
			
			if( $is_dinamic ){
				unset( $sidebars_widgets[$sidebars_widget_name] );
			}			
		}
	}
	
	foreach( $temp as $key => $val ){
		$sidebars_widgets["wp_inactive_widgets"][] = $key;
	}
	
	update_option( "sidebars_widgets" , $sidebars_widgets );
	
}

/*
=================================================================================================================
wow_delete_widgets() - remove all widgets
=================================================================================================================
*/
function wow_delete_widgets(){
	
	$sidebars_widgets = get_option("sidebars_widgets");
	
	unset( $sidebars_widgets["wp_inactive_widgets"] );
	unset( $sidebars_widgets["left_sidebar"] );
	unset( $sidebars_widgets["right_sidebar"] );
		
	$sidebars_widgets["wp_inactive_widgets"] = array();
	$sidebars_widgets["left_sidebar"] = array();
	$sidebars_widgets["right_sidebar"] = array();
	
	foreach( $sidebars_widgets as $sidebars_widget_name => $sidebars_widget ){
		
		$is_dinamic = substr( $sidebars_widget_name, 0, 7 );
		
		if( $is_dinamic == "footer_" ){
			unset( $sidebars_widgets[$sidebars_widget_name] );
			$sidebars_widgets[$sidebars_widget_name] = array();
		}
	
	}
	
	update_option( "sidebars_widgets" , $sidebars_widgets );

}

/*
=================================================================================================================
wow_delete_media() - remove all media attachments
=================================================================================================================
*/
function wow_delete_media(){
$attachments = get_posts(
	array(
		'post_type'      => 'attachment',
		'posts_per_page' => -1,
		'post_status'    => 'any',
	)
	);
	foreach ( $attachments as $attachment ) {
		wp_delete_attachment( $attachment->ID );
	}
}

/*
=================================================================================================================
wow_delete_temp_Directory() - delete temp directory/directories/files created when importing a demo
=================================================================================================================
*/
function wow_delete_temp_Directory( $dir ) {
	
    if ( !file_exists( $dir ) ) {
        return true;
    }

    if ( !is_dir( $dir ) ) {
        return unlink( $dir );
    }

    foreach ( scandir( $dir ) as $item ) {
        if ( $item == '.' || $item == '..' ) {
            continue;
        }

        if ( !wow_delete_temp_Directory( $dir . DIRECTORY_SEPARATOR . $item ) ) {
            return false;
        }

    }

    return rmdir( $dir );
}