<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/*
=================================================================================================================
About us widget
=================================================================================================================
*/
add_action( 'widgets_init', 'wow_about_us_widget' );
function wow_about_us_widget() {
	register_widget('wow_about_us_widget');
}

class wow_about_us_widget extends WP_Widget {

	function __construct() {
		global $wow_theme_name;
	
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'wow_about_us_widget', 'description' => 'Add a fancy description and details of your company.' );
		 
		/* Widget control settings. */
		$control_ops = array( 'id_base' => 'wow_about_us_widget' );
		 
		/* Create the widget. */
		parent::__construct( 'wow_about_us_widget', ''.$wow_theme_name.' About Us', $widget_ops, $control_ops );
	}
	 
	function widget( $args, $instance ) {
		
		global $wow_options;
				
		//add icon to widget title from theme options
		$icon = (!empty($wow_options['blog-widget-heading-icon'])) ? '<i class="widget-icon '.esc_attr($wow_options['blog-widget-heading-icon']).'"></i>' : '';	
		
		extract( $args );
		global $wow_options;
		$social = (!empty($instance[ 'social' ])) ? 'on' : '';
		$align   	= (!empty($instance['align'])) ? $instance['align'] : '';
		
		
		//custom css class
		$custom_css_class = 'custom_css_'.uniqid("", true);
		$custom_css_class = str_replace('.','-',$custom_css_class);
		$custom_css_class_w_dot = '.'.$custom_css_class;		
		
		if(!empty($instance[ 'align' ])){
			
			if ( $instance[ 'align' ] == 'center' ){
				echo '<style type="text/css">.about-us-content' . esc_attr( $custom_css_class_w_dot ) . '{text-align:'.esc_attr( $align ).';display:table; margin:auto} .widget .about-us-content' . esc_attr( $custom_css_class_w_dot ) . ' a img { margin:auto; margin-bottom: 20px } .about-us-content' . esc_attr( $custom_css_class_w_dot ) . ' ul.social {margin:auto;  margin-top: 20px;}</style>';
			}			
			elseif ( $instance[ 'align' ] == 'left' ) {
				echo '<style type="text/css">.about-us-content' . esc_attr( $custom_css_class_w_dot ) . '{float:'.esc_attr( $align ).';text-align:'.esc_attr( $align ).'; width:100%; clear:both}</style>';
			}
			else{
				echo '<style type="text/css">.about-us-content' . esc_attr( $custom_css_class_w_dot ) . '{float:'.esc_attr( $align ).';text-align:'.esc_attr( $align ).'; width:100%; clear:both} .about-us-content' . esc_attr( $custom_css_class_w_dot ) . ' > a {width: 100%; clear: both; display: table;} .about-us-content' . esc_attr( $custom_css_class_w_dot ) . ' img {float:'.esc_attr( $align ).'}.about-us-content' . esc_attr( $custom_css_class_w_dot ) . ' ul.social {float:'.esc_attr( $align ).'} .about-us-content' . esc_attr( $custom_css_class_w_dot ) . ' ul.details {clear:both}</style>';
			}
			  
		}
		if(!empty($instance[ 'css' ])){
			echo '<style type="text/css">' . esc_attr( $instance[ 'css' ] ) . '</style>';
		}			

		?>

		<div class="widget"><!-- widget -->
				<div class="title"><!-- title -->
						<?php if(!empty($instance['title'])) : ?>
							<?php echo wow_widget_heading_icon( $instance['title'] ); ?>
						<?php endif; ?>
				</div><!--/ title -->
				
				<div class="about-us-content <?php echo esc_attr($custom_css_class) ?>"><!-- about-us-content -->		
					<?php if(!empty($instance['image_uri'])) : ?>
						<a href="<?php echo esc_url( home_url() ); ?>"><img src="<?php echo esc_url($instance['image_uri']); ?>" /></a>
					<?php endif; ?>
					<?php if(!empty($instance['about_us_content'])) : ?>
						<p><?php echo esc_attr(html_entity_decode($instance['about_us_content']));?></p>
					<?php endif; ?>
					
					<?php if ($social == 'on') :	?>
						<ul class="social">
							<?php $socials = array('facebook' , 'skype' ,'google-plus' ,'twitter' ,'vimeo' ,'youtube' ,'flickr' ,'linkedin' ,'pinterest' ,'dribbble' ,'instagram' ,'behance' ,'tumblr' ,'viadeo' , 'xing' );
								$social_html = '';
								foreach($socials as $social){
									if (!empty($wow_options[$social])){
										$social_html.=  '
											<li><a href="'.esc_url($wow_options[$social]).'"><i class="wow-social-'. esc_attr(strtolower($social)).'"></i></a></li>
										';
									}
								}
								echo $social_html; //escaped all variables inside this above
							?>
						</ul>
					<?php endif; ?>
					
					<ul class="details">
						<?php if(!empty($instance['about_us_location'])) : ?>
							<li><i class="pe-7s-map-marker themecolor1"></i><?php echo esc_attr($instance['about_us_location']);?></li>
						<?php endif; ?>		
						
						<?php if(!empty($instance['about_us_email'])) : ?>	
							<li><i class="pe-7s-mail themecolor1"></i><?php echo esc_attr($instance['about_us_email']);?></li>
						<?php endif; ?>		
						
						<?php if(!empty($instance['about_us_phone'])): ?>	
							<li><i class="pe-7s-headphones themecolor1"></i><?php echo esc_attr($instance['about_us_phone']);?></li>
						<?php endif; ?>		
						
						<?php if(!empty($instance['about_us_time'])) : ?>
							<li><i class="pe-7s-alarm themecolor1"></i><?php echo esc_attr($instance['about_us_time']);?></li>
						<?php endif; ?>	
						
					</ul>
			</div><!--/ about-us-content -->
		</div><!--/ widget -->

	
	<?php }
	 
	function update( $new_instance, $old_instance ) {

		$instance = $old_instance;
		$instance['image_uri']			=  strip_tags( esc_url($new_instance['image_uri'] ));
		$instance['social']				=  strip_tags( esc_attr($new_instance['social'] ));
		$instance['title']              =  strip_tags(esc_attr($new_instance['title']));
		$instance['about_us_content']   =  htmlentities(esc_attr($new_instance['about_us_content']));
		$instance['about_us_location']  =  strip_tags(esc_attr($new_instance['about_us_location']));
		$instance['about_us_email']     =  strip_tags(esc_attr($new_instance['about_us_email']));
		$instance['about_us_phone']     =  strip_tags(esc_attr($new_instance['about_us_phone']));
		$instance['about_us_time']      =  strip_tags(esc_attr($new_instance['about_us_time']));
		$instance['align'] 		=  strip_tags( esc_attr($new_instance['align']));
		$instance['css']		=  strip_tags( esc_attr($new_instance['css'] ));
		
		
		return $instance;
	}
	 
	function form( $instance ) {

		$defaults = array(  );
		$instance = wp_parse_args( (array) $instance, $defaults ); 
	
		/* Set up some default widget settings. */
		
		$image_uri	          = isset( $instance['image_uri']) ? strip_tags(esc_url( $instance['image_uri'] )) : '';
		$title	              = isset( $instance['title']) ? strip_tags(esc_attr( $instance['title'] )) : 'About us';
		$instance['social']	  = !empty( $instance['social']) ? 'on' : '';
		$about_us_content     = isset( $instance['about_us_content']) ? htmlentities(esc_attr($instance['about_us_content'])) : htmlentities(esc_attr('Chia direct trade VHS cred. Raw denim cool. Food truck meggings beard kitsch.'));
		$about_us_location	  = isset( $instance['about_us_location']) ? strip_tags(esc_attr( $instance['about_us_location'] )) : 'Salt Lake City, UT 87234';
		$about_us_email       = isset( $instance['about_us_email']) ? strip_tags(esc_attr( $instance['about_us_email'] )) : 'awesome@example.com';
		$about_us_phone	      = isset( $instance['about_us_phone']) ? strip_tags(esc_attr( $instance['about_us_phone'] )) : '(871) 321-6567';
		$about_us_time	      = isset( $instance['about_us_time']) ? strip_tags(esc_attr( $instance['about_us_time'] )) : 'Monday-Friday 08:00 - 18:00';
		$align 	  			  = !empty( $instance['align']) ? $instance['align'] : '';
		$css                  = !empty( $instance['css']) ? $instance['css'] : '';
		?>
		<p>
		<label for="<?php echo esc_attr($this->get_field_id('image_uri')); ?>"><?php esc_html_e('Logo Image','infinito-widgets') ?></label><br />
		<div class="custom_media_url_remove_holder"><a class="custom_media_url_remove" href="javascript:void(0);">X</a></div>
		<img class="custom_media_image" src="<?php if(!empty($instance['image_uri'])){echo esc_url($instance['image_uri']);} ?>" style="margin:0;padding:0;max-width:100px;float:left;display:inline-block" />
		<input type="text" class="widefat custom_media_url" name="<?php echo esc_attr($this->get_field_name('image_uri')); ?>" id="<?php echo esc_attr($this->get_field_id('image_uri')); ?>" value="<?php echo esc_attr($image_uri); ?>">
		<input type="button" value="<?php esc_html_e( 'Upload Image', 'infinito-widgets' ); ?>" class="button custom_media_upload" id="custom_image_uploader"/>
		</p>
		
		<p>
		<label for="<?php  echo esc_attr($this->get_field_id( 'social' )); ?>"><?php esc_html_e('Show Social Box?','infinito-widgets') ?></label>
		<input type="checkbox" class="checkbox" id="<?php echo esc_attr($this->get_field_id( 'social' )); ?>" value="<?php echo esc_attr($this->get_field_id( 'social' )); ?>" <?php checked( $instance[ 'social' ], 'on' ); ?> name="<?php echo esc_attr($this->get_field_name( 'social' )); ?>">
		</p>
		<p>
		<label for="<?php echo esc_attr($this->get_field_id('align')); ?>"><?php esc_html_e('Text align','infinito-widgets') ?>
			<select class='widefat' id="<?php echo esc_attr($this->get_field_id('align')); ?>"
                name="<?php echo $this->get_field_name('align'); ?>" type="text">
				  <option value='left'<?php echo (esc_attr($align)=='left')?'selected':''; ?>>
					<?php esc_html_e('Left','infinito-widgets') ?>
				  </option>
				  <option value='center'<?php echo (esc_attr($align)=='center')?'selected':''; ?>>
					<?php esc_html_e('Center','infinito-widgets') ?>
				  </option> 
				  <option value='right'<?php echo (esc_attr($align )=='right')?'selected':''; ?>>
					<?php esc_html_e('Right','infinito-widgets') ?>
				  </option> 
				  </select>                
			</label>
        </p>		
		<p>
		<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e('Title','infinito-widgets') ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" value="<?php echo esc_attr($title); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>">
		</p>
		
		<p>
		<label for="<?php echo esc_attr($this->get_field_id( 'about_us_content' )); ?>"><?php esc_html_e('About text','infinito-widgets') ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'about_us_content' )); ?>" value="<?php echo htmlentities(esc_attr($about_us_content)); ?>" name="<?php echo esc_attr($this->get_field_name( 'about_us_content' )); ?>">
		</p>
		
		<p>
		<label for="<?php echo esc_attr($this->get_field_id( 'about_us_location' )); ?>"><?php esc_html_e('Location','infinito-widgets') ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'about_us_location' )); ?>" value="<?php echo esc_attr($about_us_location); ?>" name="<?php echo esc_attr($this->get_field_name( 'about_us_location' )); ?>">
		</p>
		
		<p>
		<label for="<?php echo esc_attr($this->get_field_id( 'about_us_email' )); ?>"><?php esc_html_e('Email)','infinito-widgets') ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'about_us_email' )); ?>" value="<?php echo esc_attr($about_us_email); ?>" name="<?php echo $this->get_field_name( 'about_us_email' ); ?>">
		</p>
		
		<p>
		<label for="<?php echo esc_attr($this->get_field_id( 'about_us_phone' )); ?>"><?php esc_html_e('Phone','infinito-widgets') ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'about_us_phone' )); ?>" value="<?php echo esc_attr($about_us_phone); ?>" name="<?php echo esc_attr($this->get_field_name( 'about_us_phone' )); ?>">
		</p>
		
		<p>
		<label for="<?php echo esc_attr($this->get_field_id( 'about_us_time' )); ?>"><?php esc_html_e('Schedule','infinito-widgets') ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'about_us_time' )); ?>" value="<?php echo esc_attr($about_us_time); ?>" name="<?php echo esc_attr($this->get_field_name( 'about_us_time' )); ?>">
		</p>
		<p>
		<label for="<?php  echo esc_attr($this->get_field_id( 'css' )); ?>"><?php esc_html_e('Custom CSS','infinito-widgets') ?></label>
		<textarea class="widefat" rows="16" cols="20" id="<?php echo esc_attr($this->get_field_id('css')); ?>" name="<?php echo esc_attr($this->get_field_name('css')); ?>"><?php echo esc_textarea($css); ?></textarea>
		</p>
		<p>
			<?php esc_html_e('For custom css I.e .about-us-content{ margin:50px }','infinito-widgets'); ?>
		</p>		
	<?php
	}
}