<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/*
=================================================================================================================
Portfolio Posts widget
=================================================================================================================
*/
add_action( 'widgets_init', 'wow_portfolio_widget' );
function wow_portfolio_widget() {
	register_widget('wow_portfolio_widget');
}

class wow_portfolio_widget extends WP_Widget {

	function __construct() {
		global $wow_theme_name;
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'wow_portfolio_widget', 'description' => 'Latest portfolio posts' );
		 
		/* Widget control settings. */
		$control_ops = array( 'id_base' => 'wow_portfolio_widget' );
		 
		/* Create the widget. */
		parent::__construct( 'wow_portfolio_widget', ''.$wow_theme_name.' Portfolio Posts', $widget_ops, $control_ops );
	}
	 
	function widget( $args, $instance ) {
		
		global $wow_options;
				
		//add icon to widget title from theme options
		$icon = (!empty($wow_options['blog-widget-heading-icon'])) ? '<i class="widget-icon '.esc_attr($wow_options['blog-widget-heading-icon']).'"></i>' : '';

		extract( $args );
		?>

		<div class="widget"><!-- widget -->
				<div class="title"><!-- title -->
						<?php if(!empty($instance['title'])) : ?>
							<?php echo wow_widget_heading_icon( $instance['title'] ); ?>
						<?php endif; ?>
				</div><!--/ title -->
				
				
				
				<?php
				
				global $wp_query;
				$args = array('post_type' => array( 'portfolio' ),'posts_per_page' => $instance['number'], 'meta_query' => array( array( 'key' => '_thumbnail_id', 'value' => '','compare' => '!=' ) ) );
				$query_portfolio = new WP_Query( $args );
				?>
				
				<div class="portfolio-content"><!-- portfolio-content -->
				<?php foreach($query_portfolio->posts as $post) : ?>
					<?php 
						//post thumbnail
						$post_thumbnail_arr = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'medium' );
						$post_thumbnail     = $post_thumbnail_arr[0];
						$thumb_resized      = aq_resize($post_thumbnail, 95, 75, true);
						
						//post thumbnail id
						$post_thumbnail_id = get_post_thumbnail_id( $post->ID );
										
						//image alt title
						$img_alt_title = get_the_title($post_thumbnail_id);
						
						//post url
						$post_link = get_post_permalink($post->ID);
						
						echo '
						<a href="'.esc_url($post_link).'">
							<img src="'.esc_url($thumb_resized).'" alt="'.esc_attr($img_alt_title).'" />
							<div class="image_wrapper"></div>
						</a>
						';
						
					?>
				<?php endforeach; wp_reset_query(); ?>
				</div><!--/ portfolio-content -->	
				
		</div><!--/ widget -->

	
	<?php }
	 
	function update( $new_instance, $old_instance ) {

		$instance = $old_instance;
		$instance['title']		=  strip_tags( esc_attr($new_instance['title'] ));
		$instance['number']		=  strip_tags( esc_attr($new_instance['number'] ));
		
		
		return $instance;
	}
	 
	function form( $instance ) {

		$defaults = array(  );
		$instance = wp_parse_args( (array) $instance, $defaults ); 
	
		/* Set up some default widget settings. */
		$title	              = isset( $instance['title']) ? strip_tags(esc_attr( $instance['title'] ) ) : '';
		$number	              = isset( $instance['number']) ? strip_tags(esc_attr( absint($instance['number'] ) ) ) : '8';

		?>
		

		<p>
		<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e('Title','infinito-widgets') ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" value="<?php echo esc_attr($title); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>">
		</p>		
		
		<p>
		<label for="<?php echo esc_attr($this->get_field_id( 'number' )); ?>"><?php esc_html_e('Number of portfolio posts','infinito-widgets') ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'number' )); ?>" value="<?php echo esc_attr($number); ?>" name="<?php echo esc_attr($this->get_field_name( 'number' )); ?>">
		</p>
		

	
	<?php
	}
}