<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/*
=================================================================================================================
Recent Posts Widget
=================================================================================================================
*/
add_action( 'widgets_init', 'wow_recent_posts_widget' );
function wow_recent_posts_widget() {
	register_widget('wow_recent_posts_widget');
	wp_enqueue_style( 'wow-webapplication', WOW_URI.'/fonts/icons/webapplication/style.css');
	wp_enqueue_style( 'wow-multimedia', WOW_URI.'/fonts/icons/multimedia/style.css');
}

class wow_recent_posts_widget extends WP_Widget {
	function __construct() {
		global $wow_theme_name;
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'wow_recent_posts_widget', 'description' => 'Display Recent Posts in a nice style' );
		 
		/* Widget control settings. */
		$control_ops = array( 'id_base' => 'wow_recent_posts_widget' );
		 
		/* Create the widget. */
		parent::__construct( 'wow_recent_posts_widget', ''.$wow_theme_name.' Recent Posts', $widget_ops, $control_ops );
	}
	 
	function widget( $args, $instance ) {
		
		global $wow_options;
		
		extract( $args );
		$post_no =  !empty($instance['post_no']) ?  strip_tags(absint($instance['post_no']))  : '' ;
		$title   = !empty($instance['title']) ?  strip_tags(esc_attr($instance['title']))  : '' ;
	?>
	
<?php $args = array('posts_per_page' => $post_no ); query_posts( $args ); ?>
	<div class="widget"><!-- widget -->
		<div class="latest_news_widget"><?php echo wow_widget_heading_icon( $title ); ?></div>
			<div class="sidebar-posts-body">
				
				<?php while ( have_posts() ) { the_post();
					
					$post_format = get_post_format();
					
					//custom css class for standard post format with no thumbnail
					$no_thumb_class = ( !has_post_thumbnail() and $post_format == false ) ? ' no-thumb' : ''; 
					
					//custom css class for others post format with no thumbnail
					$no_standard_class = ( $post_format == 'video' || $post_format == 'audio' || $post_format == 'quote' ) ? ' not-standard' : ''; 
					
				?>
					
					<div class="sidebar-posts-box"><!-- sidebar-posts-box -->
						<div class="sidebar-post-thumb<?php echo esc_attr($no_thumb_class); ?>"><!-- sidebar-post-thumb -->
							
							<?php 
							//custom css class for standard post format
							$standard_class = ( $post_format == false and has_post_thumbnail() ) ? ' standard' : '';
							?>
							
							<?php if ( $post_format == false ) : // standard post format ?>
								<?php
									if ( has_post_thumbnail() ) {
									$id_img = get_post_thumbnail_id();
									$img_url = wp_get_attachment_url( $id_img,'full');
									$thumb = aq_resize($img_url, 116, 70, true); if ( !$thumb ) $thumb = $img_url;
								?>
								<a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'infinito-widgets' ), the_title_attribute('echo=0' ) ); ?>">
									<?php echo '
										<img src="'.esc_url($thumb).'" alt="'.esc_attr(get_the_title()).'" class="categ-thumb"/>
										<div class="image_wrapper"></div>';
									?>
								</a>	
								<?php } ?>
							<?php endif; ?>
							
							<?php if ( $post_format == 'video' ) : // video post format ?>
								<div class="video"><i class="wow-multimedia-video-alt themecolor1"></i></div>
							<?php endif; ?>							
							
							<?php if ( $post_format == 'audio' ) : // audio post format ?>
								<div class="audio"><i class="wow-webapplication-audio themecolor1"></i></div>
							<?php endif; ?>							
							
							<?php if ( $post_format == 'quote' ) : // quote post format ?>
								<div class="quote"><i class="wow-webapplication-quote-right themecolor1"></i></div>
							<?php endif; ?>		
							
						</div><!--/ sidebar-post-thumb -->
						
						<div class="sidebar-posts<?php echo esc_attr($standard_class); echo esc_attr($no_standard_class); ?>"><!-- sidebar-posts -->
							<h6><a href="<?php the_permalink() ?>"><?php the_title(); ?></a></h6>
							<p><?php echo esc_attr(the_time('d M Y')); ?></p>
						</div><!--/ sidebar-posts -->
						
					</div><!--/ sidebar-posts-box -->
				<?php } wp_reset_query(); ?>
			</div>
	</div><!--/ widget -->
<?php	
}
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		 
		/* Strip tags (if needed) and update the widget settings. */
		$instance['title']   		 =   strip_tags(esc_attr($new_instance['title']));
		$instance['post_no'] 		 =   strip_tags(absint($new_instance['post_no']));
		return $instance;
	}

	function form( $instance ) {
		
		/* Set up some default widget settings. */
		$title	  			= isset($instance['title']) ? strip_tags(esc_attr($instance['title'])) : 'Latest news';
		$post_no  			= isset($instance['post_no']) ? strip_tags(absint( $instance['post_no'])) : 2;
	

		?>
		<p>
		<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e('Title','infinito-widgets'); ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr($title); ?>">
		</p>
		
		<p>
		<label for="<?php echo esc_attr($this->get_field_id( 'post_no' )); ?>"><?php esc_html_e('Number of posts','infinito-widgets'); ?></label>
		<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'post_no' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'post_no' )); ?>" value="<?php echo esc_attr($post_no); ?>">
		</p>
		
	<?php
	}
}