<?php
/*
Plugin Name: WP Editor Widget
Plugin URI: https://github.com/feedmeastraycat/wp-editor-widget
Description: WP Editor Widget adds a WYSIWYG widget using the wp_editor().
Author: David M&aring;rtensson, Odd Alice
Version: 0.6.0
Author URI: http://www.feedmeastraycat.net/
Text Domain: wp-editor-widget
Domain Path: /langs
*/

//avoid direct calls to this file
if ( ! defined( 'ABSPATH' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}


/**
 * Adds WP_Editor_Widget widget.
 */
if ( !class_exists ( 'WP_Editor_Widget' ) ){
class WP_Editor_Widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	public function __construct() {
		
		global $wow_theme_name;
		
		$widget_name = esc_attr( $wow_theme_name ).esc_html__( ' Editor', 'infinito-widgets' );

		$widget_ops = apply_filters(
			'wp_editor_widget_ops',
			array(
				'classname' 	=> 'WP_Editor_Widget',
				'description' 	=> __( 'Arbitrary text, HTML or rich text through the standard WordPress visual editor.', 'infinito-widgets' ),
			)
		);
		
		parent::__construct(
			'WP_Editor_Widget',
			$widget_name,
			$widget_ops
		);

	} // END __construct()

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {

		global $wow_options;
		$icon = (!empty($wow_options['blog-widget-heading-icon'])) ? '<i class="widget-icon '.esc_attr($wow_options['blog-widget-heading-icon']).'"></i>' : '';
		
		
		$title			= !empty($instance['title']) ? apply_filters( 'wp_editor_widget_title', $instance['title'] ) : '';
		$output_title	= !empty($instance['output_title']) ? apply_filters( 'wp_editor_widget_output_title', $instance['output_title'] ) : '';
		$content		= !empty($instance['content']) ? apply_filters( 'wp_editor_widget_content', $instance['content'] ) : '';
		
		?>
		
		<?php if ( $content ): ?>
			<div class="widget editor-widget">
			<?php if ($output_title): ?><div class="title"><h3><?php echo $icon ; //escaped above ?><?php echo esc_attr( $title );?></h3></div><?php endif; ?>
			<div class="wp-editor-content-infinito"><?php echo wp_kses_post( $content ) ;?></div>
			</div>
		<?php endif; ?>
		
	<?php	

	} // END widget()

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		if ( isset( $instance['title'] ) ) {
			$title = $instance['title'];
		}
		else {
			$title = __( 'New title', 'infinito-widgets' );
		}

		if ( isset( $instance['content'] ) ) {
			$content = $instance['content'];
		}
		else {
			$content = '';
		}

		$output_title = ( isset( $instance['output_title'] ) && '1' == $instance['output_title'] ? true : false );
		?>
		<input type="hidden" id="<?php echo esc_attr( $this->get_field_id( 'content' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'content' ) ); ?>" value="<?php echo esc_attr( $content ); ?>">
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Title', 'infinito-widgets' ); ?>:</label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<p>
			<a href="javascript:WPEditorWidget.showEditor('<?php echo esc_attr( $this->get_field_id( 'content' ) ); ?>');" class="button"><?php _e( 'Edit content', 'infinito-widgets' ) ?></a>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'output_title' ) ); ?>">
				<input type="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'output_title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'output_title' ) ); ?>" value="1" <?php checked( $output_title, true ) ?>> <?php _e( 'Output title', 'infinito-widgets' ); ?>
			</label>
		</p>
		<?php
			
		do_action( 'wp_editor_widget_form', $this, $instance );

	} // END form()

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {

		$instance = array();

		$instance['title']			= ( ! empty( $new_instance['title'] ) ? strip_tags( $new_instance['title'] ) : '' );
		$instance['content']		= ( ! empty( $new_instance['content'] ) ? $new_instance['content'] : '' );
		$instance['output_title']	= ( isset( $new_instance['output_title'] ) && '1' == $new_instance['output_title'] ? 1 : 0 );

		do_action( 'wp_editor_widget_update', $new_instance, $instance );

 	 	return apply_filters( 'wp_editor_widget_update_instance', $instance, $new_instance );

	} // END update()

} // END class WP_Editor_Widget
}







/**
 * WP Editor Widget singelton
 */
if ( !class_exists ( 'WPEditorWidget' ) ){
class WPEditorWidget {

	/**
	 * @var string
	 */
	const VERSION = '0.6.0';

	/**
	 * Action: init
	 */
	public function __construct() {

		add_action( 'widgets_init', array( $this, 'widgets_init' ) );
		add_action( 'load-widgets.php', array( $this, 'load_admin_assets' ) );
		add_action( 'load-customize.php', array( $this, 'load_admin_assets' ) );
		add_action( 'widgets_admin_page', array( $this, 'output_wp_editor_widget_html' ), 100 );
		add_action( 'customize_controls_print_footer_scripts', array( $this, 'output_wp_editor_widget_html' ), 1 );
		add_action( 'customize_controls_print_footer_scripts', array( $this, 'customize_controls_print_footer_scripts' ), 2 );
		add_action( 'plugins_loaded', array( $this, 'plugins_loaded' ) );
		
		add_filter( 'wp_editor_widget_content', 'wptexturize' );
		add_filter( 'wp_editor_widget_content', 'convert_smilies' );
		add_filter( 'wp_editor_widget_content', 'convert_chars' );
		add_filter( 'wp_editor_widget_content', 'wpautop' );
		add_filter( 'wp_editor_widget_content', 'shortcode_unautop' );
		add_filter( 'wp_editor_widget_content', 'do_shortcode', 11 );

	} // END __construct()

	/**
	 * Action: load-widgets.php
	 * Action: load-customize.php
	 */
	public function load_admin_assets() {

		wp_register_script( 'wp-editor-widget-js', WOW_URI.'/inc/widgets/wp-editor-widget/js/admin.js' , array( 'jquery' ), self::VERSION );
		wp_enqueue_script( 'wp-editor-widget-js' );

		wp_register_style( 'wp-editor-widget-css', WOW_URI.'/inc/widgets/wp-editor-widget/css/admin.css', array(), self::VERSION );
		wp_enqueue_style( 'wp-editor-widget-css' );

	} // END load_admin_assets()

	/**
	 * Action: plugins_loaded
	 */
	public function plugins_loaded() {

		// Load translations
		load_plugin_textdomain( 'infinito-widgets', false, dirname( plugin_basename( __FILE__ ) ) . '/langs/' );

	} // END plugins_loaded()
	
	/**
	 * Action: widgets_admin_page
	 * Action: customize_controls_print_footer_scripts
	 */
	public function output_wp_editor_widget_html() {
		
		?>
		<div id="wp-editor-widget-container" style="display: none;">
			<a class="close" href="javascript:WPEditorWidget.hideEditor();" title="<?php esc_attr_e( 'Close', 'infinito-widgets' ); ?>"><span class="icon"></span></a>
			<div class="editor">
				<?php
				$settings = array(
					'textarea_rows' => 20,
				);
				wp_editor( '', 'wpeditorwidget', $settings );
				?>
				<p>
					<a href="javascript:WPEditorWidget.updateWidgetAndCloseEditor(true);" class="button button-primary"><?php _e( 'Save and close', 'infinito-widgets' ); ?></a>
				</p>
			</div>
		</div>
		<div id="wp-editor-widget-backdrop" style="display: none;"></div>
		<?php
		
	} // END output_wp_editor_widget_html
	
	/**
	 * Action: customize_controls_print_footer_scripts
	 */
	public function customize_controls_print_footer_scripts() {
	
		// Because of https://core.trac.wordpress.org/ticket/27853
		// Which was fixed in 3.9.1 so we only need this on earlier versions
		$wp_version = get_bloginfo( 'version' );
		if ( version_compare( $wp_version, '3.9.1', '<' ) && class_exists( '_WP_Editors' ) ) {
			_WP_Editors::enqueue_scripts();
		}
		
	} // END customize_controls_print_footer_scripts

	/**
	 * Action: widgets_init
	 */
	public function widgets_init() {

		register_widget( 'WP_Editor_Widget' );

	} // END widgets_init()

} // END class WPEditorWidget
}

global $wp_editor_widget;
$wp_editor_widget = new WPEditorWidget;