<?php
/**
 * Cart totals
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart-totals.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     2.3.6
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

?>
<div class="cart_totals wow_woocommerce_totals <?php echo ( WC()->customer->has_calculated_shipping() ) ? 'calculated_shipping' : ''; ?>">


	<?php do_action( 'woocommerce_before_cart_totals' ); ?>

	<div class="woocommerce-big-info no_padding">
		<div class="woocommerce-big-info-wrap">	
	<h3><?php esc_html_e( 'Cart totals', 'infinito-woocommerce' ); ?></h3>
	</div>	<!--  woocommerce-big-info-wrap -->
	<ul class="shop_table shop_table_responsive">

		<ul class="cart-subtotal">
			<li><?php esc_html_e( 'Subtotal', 'infinito-woocommerce' ); ?></li>
			<li data-title="<?php esc_attr_e( 'Subtotal', 'infinito-woocommerce' ); ?>"><?php wc_cart_totals_subtotal_html(); ?></li>
		</ul>

		<?php foreach ( WC()->cart->get_coupons() as $code => $coupon ) : ?>
			<ul class="cart-discount coupon-<?php echo esc_attr( sanitize_title( $code ) ); ?>">
				<li><?php wc_cart_totals_coupon_label( $coupon ); ?></li>
				<li data-title="<?php echo esc_attr( wc_cart_totals_coupon_label( $coupon, false ) ); ?>"><?php wc_cart_totals_coupon_html( $coupon ); ?></lili>
			</ul>
		<?php endforeach; ?>

		<?php if ( WC()->cart->needs_shipping() && WC()->cart->show_shipping() ) : ?>

			<?php do_action( 'woocommerce_cart_totals_before_shipping' ); ?>

			<?php wc_cart_totals_shipping_html(); ?>

			<?php do_action( 'woocommerce_cart_totals_after_shipping' ); ?>

		<?php elseif ( WC()->cart->needs_shipping() && 'yes' === get_option( 'woocommerce_enable_shipping_calc' ) ) : ?>

			<ul class="shipping">
				<li><?php esc_html_e( 'Shipping', 'infinito-woocommerce' ); ?></li>
				<li data-title="<?php esc_attr_e( 'Shipping', 'infinito-woocommerce' ); ?>"><?php woocommerce_shipping_calculator(); ?></li>
			</ul>

		<?php endif; ?>

		<?php foreach ( WC()->cart->get_fees() as $fee ) : ?>
			<ul class="fee">
				<li><?php echo esc_html( $fee->name ); ?></li>
				<li data-title="<?php echo esc_attr( $fee->name ); ?>"><?php wc_cart_totals_fee_html( $fee ); ?></li>
			</ul>
		<?php endforeach; ?>

		<?php if ( wc_tax_enabled() && 'excl' === WC()->cart->tax_display_cart ) :
			$taxable_address = WC()->customer->get_taxable_address();
			$estimated_text  = WC()->customer->is_customer_outside_base() && ! WC()->customer->has_calculated_shipping()
					? sprintf( ' <small>' . esc_html__( '(estimated for %s)', 'infinito-woocommerce' ) . '</small>', WC()->countries->estimated_for_prefix( $taxable_address[0] ) . WC()->countries->countries[ $taxable_address[0] ] )
					: '';

			if ( 'itemized' === get_option( 'woocommerce_tax_total_display' ) ) : ?>
				<?php foreach ( WC()->cart->get_tax_totals() as $code => $tax ) : ?>
					<ul class="tax-rate tax-rate-<?php echo sanitize_title( $code ); ?>">
						<li><?php echo esc_html( $tax->label ) . $estimated_text; ?></li>
						<li data-title="<?php echo esc_attr( $tax->label ); ?>"><?php echo wp_kses_post( $tax->formatted_amount ); ?></li>
					</ul>
				<?php endforeach; ?>
			<?php else : ?>
				<ul class="tax-total">
					<li><?php echo esc_html( WC()->countries->tax_or_vat() ) . $estimated_text; ?></li>
					<li data-title="<?php echo esc_attr( WC()->countries->tax_or_vat() ); ?>"><?php wc_cart_totals_taxes_total_html(); ?></li>
				</ul>
			<?php endif; ?>
		<?php endif; ?>

		<?php do_action( 'woocommerce_cart_totals_before_order_total' ); ?>

		<ul class="order-total">
			<li><?php esc_html_e( 'Total', 'infinito-woocommerce' ); ?></li>
			<li data-title="<?php esc_attr_e( 'Total', 'infinito-woocommerce' ); ?>"><?php wc_cart_totals_order_total_html(); ?></li>
		</ul>

		<?php do_action( 'woocommerce_cart_totals_after_order_total' ); ?>

	</ul>
</div>	<!--  woocommerce-big-info -->
	<div class="wc-proceed-to-checkout">
		<?php do_action( 'woocommerce_proceed_to_checkout' ); ?>
	</div>
	
	<?php do_action( 'woocommerce_after_cart_totals' ); ?>

</div>
