<?php
/**
 * Cart Page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 100
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

wc_print_notices();

do_action( 'woocommerce_before_cart' ); ?>

<form class="woocommerce-cart-form" action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">
	<?php do_action( 'woocommerce_before_cart_table' ); ?>
	<div class="woocommerce-big-info no_padding">
		<div class="woocommerce-big-info-wrap">
		<h3 class="no_line"><?php esc_html_e( 'Cart Products', 'infinito-woocommerce' ); ?></h3>
	<ul class="shop_table shop_table_responsive cart woocommerce-cart-form__contents" cellspacing="0">
			<ul class="cart-product-list-headings">
				<li>&nbsp;</li>
				<li>&nbsp;</li>
				<li><?php esc_html_e( 'Product', 'infinito-woocommerce' ); ?></li>
				<li><?php esc_html_e( 'Price', 'infinito-woocommerce' ); ?></li>
				<li><?php esc_html_e( 'Quantity', 'infinito-woocommerce' ); ?></li>
				<li><?php esc_html_e( 'Total', 'infinito-woocommerce' ); ?></li>
			</ul>
			<?php do_action( 'woocommerce_before_cart_contents' ); ?>

			<?php
			foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
				$_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
				$product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

				if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
					$product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
					?>
					<ul class="woocommerce-cart-form__cart-item <?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">

						<li class="product-remove">
							<?php
								echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
									'<a href="%s" class="remove themecolor1_bg" aria-label="%s" data-product_id="%s" data-product_sku="%s">&times;</a>',
									esc_url( wc_get_cart_remove_url ( $cart_item_key ) ),
									esc_html__( 'Remove this item', 'infinito-woocommerce' ),
									esc_attr( $product_id ),
									esc_attr( $_product->get_sku() )
								), $cart_item_key );
							?>
						</li>

						<li class="product-thumbnail">
							<?php
								$thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );

								if ( ! $product_permalink ) {
									echo $thumbnail;
								} else {
									printf( '<a href="%s">%s</a>', esc_url( $product_permalink ), $thumbnail );
								}
							?>
						</li>

						<li class="product-name" data-title="<?php esc_attr_e( 'Product', 'infinito-woocommerce' ); ?>">
							<span class="responsive-heading"><?php esc_html_e( 'Product', 'infinito-woocommerce' ); ?></span>
							<span class="responsive-description">
							<?php
								if ( ! $product_permalink ) {
									echo '<span>'.apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key ) . '&nbsp;</span>';
								} else {
									echo apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s</a>', esc_url( $product_permalink ), $_product->get_name() ), $cart_item, $cart_item_key );
								}

								// Meta data
								echo wc_get_formatted_cart_item_data( $cart_item );

								// Backorder notification
								if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
									echo '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'infinito-woocommerce' ) . '</p>';
								}
							?>
							</span>
						</li>

						<li class="product-price" data-title="<?php esc_attr_e( 'Price', 'infinito-woocommerce' ); ?>">
							<span class="responsive-heading"><?php esc_html_e( 'Price', 'infinito-woocommerce' ); ?></span>
							<span class="responsive-description">
							<?php
								echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
							?>
							</span>
						</li>

						<li class="product-quantity" data-title="<?php esc_attr_e( 'Quantity', 'infinito-woocommerce' ); ?>">
							<span class="responsive-heading"><?php esc_html_e( 'Qty', 'infinito-woocommerce' ); ?></span>
							<span class="responsive-description">
							<?php
								if ( $_product->is_sold_individually() ) {
									$product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
								} else {
									$product_quantity = woocommerce_quantity_input( array(
										'input_name'  => "cart[{$cart_item_key}][qty]",
										'input_value' => $cart_item['quantity'],
										'max_value'   => $_product->get_max_purchase_quantity(),
										'min_value'   => '0',
									), $_product, false );
								}

								echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item );
							?>
							</span>
						</li>

						<li class="product-subtotal" data-title="<?php esc_attr_e( 'Total', 'infinito-woocommerce' ); ?>">
							<span class="responsive-heading"><?php esc_html_e( 'Total', 'infinito-woocommerce' ); ?></span>
							<span class="responsive-description"><?php
								echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key );
							?>
							</span>
						</li>
					</ul>
					<?php
				}
			}
			?>

			<?php do_action( 'woocommerce_cart_contents' ); ?>

			
			<li class="actions">
				<div class="cart_actions">	
					<?php if ( wc_coupons_enabled() ) { ?>
						<div class="coupon">
							<input type="text" name="coupon_code" class="input-text" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', 'infinito-woocommerce' ); ?>" /> <input type="submit" class="button" name="apply_coupon" value="<?php esc_attr_e( 'Apply coupon', 'infinito-woocommerce' ); ?>" />
							<?php do_action( 'woocommerce_cart_coupon' ); ?>
						</div>
					<?php } ?>

					<input type="submit" class="button" name="update_cart" value="<?php esc_attr_e( 'Update cart', 'infinito-woocommerce' ); ?>" />

					<?php do_action( 'woocommerce_cart_actions' ); ?>

					<?php wp_nonce_field( 'woocommerce-cart' ); ?>
					</div>
			</li>
			

			<?php do_action( 'woocommerce_after_cart_contents' ); ?>
	</ul>
	</div>	<!--  woocommerce-big-info-wrap -->
	</div>	<!--  woocommerce-big-info -->
	<?php do_action( 'woocommerce_after_cart_table' ); ?>
</form>

<div class="cart-collaterals">
	<?php
		/**
		 * woocommerce_cart_collaterals hook.
		 *
		 * @hooked woocommerce_cross_sell_display
		 * @hooked woocommerce_cart_totals - 10
		 */
	 	do_action( 'woocommerce_cart_collaterals' );
	?>
</div>

<?php do_action( 'woocommerce_after_cart' ); ?>
