<?php
/**
 * Review order table
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/review-order.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.3.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
?>
<div class="shop_table woocommerce-checkout-review-order-table">
	<div class="woocommerce-big-info no_padding">
	<div class="woocommerce-big-info-wrap">
		<h3 id="order_review_heading" class="no_line"><?php esc_html_e( 'Your order', 'infinito-woocommerce' ); ?></h3>
		<div class="checkout-product-list">
				<ul class="checkout-product-list-headings">
					<li class="product-name"><span><?php esc_html_e( 'Item', 'infinito-woocommerce' ); ?></span></li>
					<li class="product-total"><span><?php esc_html_e( 'Quantity', 'infinito-woocommerce' ); ?></span></li>
					<li class="product-total"><span><?php esc_html_e( 'Unit Price', 'infinito-woocommerce' ); ?></span></li>
					<li class="product-total"><span><?php esc_html_e( 'Total', 'infinito-woocommerce' ); ?></span></li>
				</ul>
				<?php
					do_action( 'woocommerce_review_order_before_cart_contents' );
				?>
				
				
				<?php
					foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
						$_product     = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );

						if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_checkout_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
							?>
							<ul class="<?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">
								<li class="product-name">
									<span class="responsive-heading"><?php esc_html_e( 'Item', 'infinito-woocommerce' ); ?></span>
									<div class="image-title">
										<div class="product-image">
											<?php echo wp_kses($_product->get_image() , array('img' => array('src' => array(),'class' => array(),'alt' => array(),'width' => array(),'height' => array(),'srcset' => array(),'sizes' => array()))) ?>
										</div>
										<div class="product-name-desc">
											<?php echo apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key ) . '&nbsp;'; ?>
											<?php echo wc_get_formatted_cart_item_data( $cart_item ); ?>
										</div>
									</div>
								</li>

								<li class="product-quantity">
									<span class="responsive-heading"><?php esc_html_e( 'Quantity', 'infinito-woocommerce' ); ?></span>
									<span class="responsive-description"><?php echo apply_filters( 'woocommerce_checkout_cart_item_quantity',  sprintf( esc_attr( $cart_item['quantity'] ) ), $cart_item, $cart_item_key ); ?></span>
								</li>
								<li  class="product-unit">
									<span class="responsive-heading"><?php esc_html_e( 'Price', 'infinito-woocommerce' ); ?></span>
									<span class="responsive-description"><?php echo $_product->get_price_html(); ?></span>
								</li>
								<li class="product-total">
									<span class="responsive-heading"><?php esc_html_e( 'Total', 'infinito-woocommerce' ); ?></span>
									<span class="responsive-description"><?php echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key ); ?></span>
								</li>
							</ul>
							<?php
						}
					}
					?>

					<?php
					do_action( 'woocommerce_review_order_after_cart_contents' );

					
				?>

		</div>
	</div>
</div>
	<div class="vc_row wpb_row vc_row-fluid">
		<div class="half-width vc_col-lg-6 vc_col-sm-12 wow_woocommerce_coupon">		

			<?php  echo do_action( 'wow_woocommerce_review_order_between_cart_and_totals'); ?>

		</div>
		
		<div class="half-width vc_col-lg-6 vc_col-sm-12 wow_woocommerce_totals">
			
			<div class="woocommerce-big-info no-double-border no_padding">
			
				<ul class="cart-subtotal">
					<li class="field-title"><?php esc_html_e( 'Subtotal', 'infinito-woocommerce' ); ?></li>
					<li class="field-value"><?php wc_cart_totals_subtotal_html(); ?></li>
				</ul>

				<?php foreach ( WC()->cart->get_coupons() as $code => $coupon ) : ?>
					<ul class="cart-discount coupon-<?php echo esc_attr( sanitize_title( $code ) ); ?>">
						<li class="field-title"><?php wc_cart_totals_coupon_label( $coupon ); ?></li>
						<li class="field-value"><?php wc_cart_totals_coupon_html( $coupon ); ?></li>
					</ul>
				<?php endforeach; ?>
				
				<?php if ( WC()->cart->needs_shipping() && WC()->cart->show_shipping() ) : ?>

					<?php do_action( 'woocommerce_review_order_before_shipping' ); ?>
					
						<?php wc_cart_totals_shipping_html(); ?>
					
					<?php do_action( 'woocommerce_review_order_after_shipping' ); ?>

				<?php endif; ?>				
				
				<?php foreach ( WC()->cart->get_fees() as $fee ) : ?>
					<ul class="fee">
						<li class="field-value"><?php echo esc_html( $fee->name ); ?></li>
						<li class="field-value"><?php wc_cart_totals_fee_html( $fee ); ?></li>
					</ul>
				<?php endforeach; ?>				
				

				<?php if ( wc_tax_enabled() && 'excl' === WC()->cart->tax_display_cart ) : ?>
					<?php if ( 'itemized' === get_option( 'woocommerce_tax_total_display' ) ) : ?>
						<?php foreach ( WC()->cart->get_tax_totals() as $code => $tax ) : ?>
							<ul class="tax-rate tax-rate-<?php echo sanitize_title( $code ); ?>">
								<li  class="field-value"><?php echo esc_html( $tax->label ); ?></li>
								<li class="field-value"><?php echo wp_kses_post( $tax->formatted_amount ); ?></li>
							</ul>
						<?php endforeach; ?>
					<?php else : ?>
						<ul class="tax-total">
							<li  class="field-value"><?php echo esc_html( WC()->countries->tax_or_vat() ); ?></li>
							<li class="field-value"><?php wc_cart_totals_taxes_total_html(); ?></li>
						</ul>
					<?php endif; ?>
				<?php endif; ?>

				<?php do_action( 'woocommerce_review_order_before_order_total' ); ?>

				<ul class="order-total">
					<li  class="field-value"><?php esc_html_e( 'Total', 'infinito-woocommerce' ); ?></li>
					<li class="field-value"><?php wc_cart_totals_order_total_html(); ?></li>
				</ul>

				<?php do_action( 'woocommerce_review_order_after_order_total' ); ?>
			</div>
		</div>
	</div>

<div class="woocommerce-additional-fields">
	<?php do_action( 'woocommerce_before_order_notes', $checkout ); ?>

	<?php if ( apply_filters( 'woocommerce_enable_order_notes_field', 'yes' === get_option( 'woocommerce_enable_order_comments', 'yes' ) ) ) : ?>

		<?php if ( ! WC()->cart->needs_shipping() || wc_ship_to_billing_address_only() ) : ?>

			<div class="woocommerce-big-info">
				<span class="title"><?php esc_html_e( 'Additional information', 'infinito-woocommerce' ); ?></span>
			</div>

		<?php endif; ?>
		<div class="woocommerce-big-info">
			<div class="woocommerce-big-info-wrap">
				<div class="woocommerce-additional-fields__field-wrapper">
					<?php foreach ( $checkout->get_checkout_fields( 'order' ) as $key => $field ) : ?>
						<?php woocommerce_form_field( $key, $field, $checkout->get_value( $key ) ); ?>
					<?php endforeach; ?>
				</div>
			</div>
		</div><!--  woocommerce-big-info -->
		
	<?php endif; ?>

	<?php do_action( 'woocommerce_after_order_notes', $checkout ); ?>
</div>



		
</div>



