<?php
/**
 * Login Form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/form-login.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 100
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
global $wow_options;
$woo_container = ( $wow_options['woo_container'] == 'container' ) ? 'container' : '';
?>
<div class="woocommerce-start"><!-- woocommerce-start -->
	
	<div class="<?php echo esc_attr($woo_container); ?> wrapper"><!-- container wrapper-->

	<?php wc_print_notices(); ?>

	<?php do_action( 'woocommerce_before_customer_login_form' ); ?>

	<?php if ( get_option( 'woocommerce_enable_myaccount_registration' ) === 'yes' ) : //if Allow customers to create an account on the "My account" page it's ENABLED ?>

	<div class="u-columns col2-set" id="customer_login"><!-- customer_login -->

		<div class="vc_col-md-6 vc_col-sm-12 vc_col-xs-12 nopadding_left">
			<div class="woocommerce-big-info no_padding padding_bottom"><!-- woocommerce-big-info  -->
	
			<div class="woocommerce-big-info-wrap">
				<span class="title with_paddings"><?php esc_html_e( 'Login', 'infinito-woocommerce' ); ?></span>
			</div>

			<form class="woocommerce-form woocommerce-form-login login" method="post">

				<?php do_action( 'woocommerce_login_form_start' ); ?>
				<p class="description_paragraph"><?php esc_html_e( 'If you already have an account please login.', 'infinito-woocommerce' ); ?></p>
				<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
					<label for="username"><?php esc_html_e( 'Username or email address', 'infinito-woocommerce' ); ?> <span class="required">*</span></label>
					<input type="text" class="woocommerce-Input woocommerce-Input--text input-text" name="username" id="username" value="<?php echo ( ! empty( $_POST['username'] ) ) ? esc_attr( $_POST['username'] ) : ''; ?>" />
				</p>
				<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
					<label for="password"><?php esc_html_e( 'Password', 'infinito-woocommerce' ); ?> <span class="required">*</span></label>
					<input class="woocommerce-Input woocommerce-Input--text input-text" type="password" name="password" id="password" />
				</p>

				<?php do_action( 'woocommerce_login_form' ); ?>

				<p class="form-row text_center">
					<?php wp_nonce_field( 'woocommerce-login', 'woocommerce-login-nonce' ); ?>
					<label class="woocommerce-form__label woocommerce-form__label-for-checkbox inline">
						<input class="woocommerce-form__input woocommerce-form__input-checkbox" name="rememberme" type="checkbox" id="rememberme" value="forever" /> <span><?php esc_html_e( 'Remember me', 'infinito-woocommerce' ); ?></span>
					</label>
					<a class="lost_password" href="<?php echo esc_url( wp_lostpassword_url() ); ?>"><?php esc_html_e( 'Lost your password?', 'infinito-woocommerce' ); ?></a>
					<input type="submit" class="woocommerce-Button button" name="login" value="<?php esc_attr_e( 'Login', 'infinito-woocommerce' ); ?>" />
				</p>

				<?php do_action( 'woocommerce_login_form_end' ); ?>

			</form>

			</div><!-- /woocommerce-big-info  -->
		</div>


		<div class="vc_col-md-6 vc_col-sm-12 vc_col-xs-12 nopadding_right">
				<div class="woocommerce-big-info no_padding padding_bottom"><!-- woocommerce-big-info  -->
					<div class="woocommerce-big-info-wrap">
						<span class="title with_paddings"><?php esc_html_e( 'Register', 'infinito-woocommerce' ); ?></span>
					</div>

				<form method="post" class="register">

					<?php do_action( 'woocommerce_register_form_start' ); ?>
					<p class="description_paragraph"><?php esc_html_e( 'Signing up it\'s easy and will take only a few moments.', 'infinito-woocommerce' ); ?></p>
					<?php if ( 'no' === get_option( 'woocommerce_registration_generate_username' ) ) : ?>

						<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
							<label for="reg_username"><?php esc_html_e( 'Username', 'infinito-woocommerce' ); ?> <span class="required">*</span></label>
							<input type="text" class="woocommerce-Input woocommerce-Input--text input-text" name="username" id="reg_username" value="<?php echo ( ! empty( $_POST['username'] ) ) ? esc_attr( $_POST['username'] ) : ''; ?>" />
						</p>

					<?php endif; ?>

					<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
						<label for="reg_email"><?php esc_html_e( 'Email address', 'infinito-woocommerce' ); ?> <span class="required">*</span></label>
						<input type="email" class="woocommerce-Input woocommerce-Input--text input-text" name="email" id="reg_email" value="<?php echo ( ! empty( $_POST['email'] ) ) ? esc_attr( $_POST['email'] ) : ''; ?>" />
					</p>

					<?php if ( 'no' === get_option( 'woocommerce_registration_generate_password' ) ) : ?>

						<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
							<label for="reg_password"><?php esc_html_e( 'Password', 'infinito-woocommerce' ); ?> <span class="required">*</span></label>
							<input type="password" class="woocommerce-Input woocommerce-Input--text input-text" name="password" id="reg_password" />
						</p>

					<?php endif; ?>

					<?php do_action( 'woocommerce_register_form' ); ?>

					<p class="woocommerce-FormRow form-row">
						<?php wp_nonce_field( 'woocommerce-register', 'woocommerce-register-nonce' ); ?>
						<input type="submit" class="woocommerce-Button button" name="register" value="<?php esc_attr_e( 'Register', 'infinito-woocommerce' ); ?>" />
					</p>

					<?php do_action( 'woocommerce_register_form_end' ); ?>

				</form>
			</div><!-- /woocommerce-big-info  -->
		</div>

		</div><!-- customer_login -->
		
		<?php else : //else if Allow customers to create an account on the "My account" page it's DISABLED  ?>
	
		<div class="u-columns col2-set" id="customer_login"><!-- customer_login -->
			<div class="woocommerce-big-info no_padding padding_bottom"><!-- woocommerce-big-info  -->
		
				<div class="woocommerce-big-info-wrap">
					<span class="title with_paddings"><?php esc_html_e( 'Login', 'infinito-woocommerce' ); ?></span>
				</div>

				<form class="woocommerce-form woocommerce-form-login login" method="post">

					<?php do_action( 'woocommerce_login_form_start' ); ?>
					<p class="description_paragraph"><?php esc_html_e( 'If you already have an account please login.', 'infinito-woocommerce' ); ?></p>
					<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
						<label for="username"><?php esc_html_e( 'Username or email address', 'infinito-woocommerce' ); ?> <span class="required">*</span></label>
						<input type="text" class="woocommerce-Input woocommerce-Input--text input-text" name="username" id="username" value="<?php echo ( ! empty( $_POST['username'] ) ) ? esc_attr( $_POST['username'] ) : ''; ?>" />
					</p>
					<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
						<label for="password"><?php esc_html_e( 'Password', 'infinito-woocommerce' ); ?> <span class="required">*</span></label>
						<input class="woocommerce-Input woocommerce-Input--text input-text" type="password" name="password" id="password" />
					</p>

					<?php do_action( 'woocommerce_login_form' ); ?>

					<p class="form-row text_center">
						<?php wp_nonce_field( 'woocommerce-login', 'woocommerce-login-nonce' ); ?>
						<label class="woocommerce-form__label woocommerce-form__label-for-checkbox inline">
							<input class="woocommerce-form__input woocommerce-form__input-checkbox" name="rememberme" type="checkbox" id="rememberme" value="forever" /> <span><?php esc_html_e( 'Remember me', 'infinito-woocommerce' ); ?></span>
						</label>
						<a class="lost_password" href="<?php echo esc_url( wp_lostpassword_url() ); ?>"><?php esc_html_e( 'Lost your password?', 'infinito-woocommerce' ); ?></a>
						<input type="submit" class="woocommerce-Button button" name="login" value="<?php esc_attr_e( 'Login', 'infinito-woocommerce' ); ?>" />
					</p>

					<?php do_action( 'woocommerce_login_form_end' ); ?>

				</form>
			</div><!-- /woocommerce-big-info  -->

	</div><!-- /customer_login -->

	
	<?php endif; ?>

	<?php do_action( 'woocommerce_after_customer_login_form' ); ?>
	
	</div><!--/ container wrapper-->
</div><!-- woocommerce-start -->