<?php
/**
 * Display single product reviews (comments)
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product-reviews.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.9.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $product;

if ( ! comments_open() ) {
	return;
}

?>
<div id="reviews" class="woocommerce-Reviews">
	<div id="comments">
	
		<?php if ( have_comments() ) : ?>

			<ol class="commentlist">
				<?php wp_list_comments( apply_filters( 'woocommerce_product_review_list_args', array( 'callback' => 'woocommerce_comments' ) ) ); ?>
			</ol>

			<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
				echo '<nav class="woocommerce-pagination">';
				paginate_comments_links( apply_filters( 'woocommerce_comment_pagination_args', array(
					'prev_text' => '&larr;',
					'next_text' => '&rarr;',
					'type'      => 'list',
				) ) );
				echo '</nav>';
			endif; ?>

		<?php else : ?>

			<p class="woocommerce-noreviews"><h2><?php esc_html_e( 'There are no reviews yet.', 'infinito-woocommerce' ); ?></h2></p>

		<?php endif; ?>
	</div>

	<?php if ( get_option( 'woocommerce_review_rating_verification_required' ) === 'no' || wc_customer_bought_product( '', get_current_user_id(), $product->get_id() ) ) : ?>

		<div id="review_form_wrapper">
			<div id="review_form">
				<?php
					$commenter = wp_get_current_commenter();

					$comment_form = array(
						'title_reply'          => have_comments() ? '<h2 class="add_review">'.esc_html__( 'Add a review', 'infinito-woocommerce' ).'</h2>' : sprintf( '<p>'.esc_html__( 'Be the first to review %s %s %s', 'infinito-woocommerce' ), '<strong>', get_the_title(), '</strong>'.'</p>' ),
						'title_reply_to'       => esc_html__( 'Leave a Reply to %s', 'infinito-woocommerce' ),
						'title_reply_before'   => '<span id="reply-title" class="comment-reply-title">',
						'title_reply_after'    => '</span>',
						'comment_notes_after'  => '',
						'fields'               => array(
							'author' => '<div class="vc_col-md-6 nopadding_right"><div class="vc_col-md-12 nopadding"><input id="author" name="author" type="text" placeholder="Name" value="' . esc_attr( $commenter['comment_author'] ) . '" aria-required="true" required /></div>',
							'email'  => '<div class="vc_col-md-12 nopadding"><input id="email" name="email" placeholder="Email" type="email" value="' . esc_attr( $commenter['comment_author_email'] ) . '" aria-required="true" required /></div></div>',
						),
						'label_submit'  => esc_html__( 'Submit Review', 'infinito-woocommerce' ),
						'logged_in_as'  => '',
						'comment_field' => '',
						'class_submit'      => 'themecolor1_bg',
					);

					if ( $account_page_url = wc_get_page_permalink( 'myaccount' ) ) {
						$comment_form['must_log_in'] = '<p class="must-log-in">' . sprintf( esc_html__( 'You must be <a href="%s">logged in</a> to post a review.', 'infinito-woocommerce' ), esc_url( $account_page_url ) ) . '</p>';
					}

					if ( get_option( 'woocommerce_enable_review_rating' ) === 'yes' ) {
						$comment_form['comment_field'] = '<div class="comment-form-rating"><label for="rating">' . '<h3> '. esc_html__( 'Your rating', 'infinito-woocommerce' ) . '</h3></label><select name="rating" id="rating" aria-required="true" required>
							<option value="">' . esc_html__( 'Rate&hellip;', 'infinito-woocommerce' ) . '</option>
							<option value="5">' . esc_html__( 'Perfect', 'infinito-woocommerce' ) . '</option>
							<option value="4">' . esc_html__( 'Good', 'infinito-woocommerce' ) . '</option>
							<option value="3">' . esc_html__( 'Average', 'infinito-woocommerce' ) . '</option>
							<option value="2">' . esc_html__( 'Not that bad', 'infinito-woocommerce' ) . '</option>
							<option value="1">' . esc_html__( 'Very poor', 'infinito-woocommerce' ) . '</option>
						</select></div>';
					}

					$comment_form['comment_field'] .= '<div class="vc_col-md-6 nopadding"><textarea id="comment" name="comment" placeholder="Your comment" aria-required="true" required></textarea></div>';

					comment_form( apply_filters( 'woocommerce_product_review_comment_form_args', $comment_form ) );
				?>
			</div>
		</div>

	<?php else : ?>

		<p class="woocommerce-verification-required"><?php esc_html_e( 'Only logged in customers who have purchased this product can leave a review.', 'infinito-woocommerce' ); ?></p>

	<?php endif; ?>

	<div class="clear"></div>
</div>
