<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Recent Reviews Widget.
 *
 * @author   WooThemes
 * @category Widgets
 * @package  WooCommerce/Widgets
 * @version  2.3.0
 * @extends  WC_Widget
 */
class Wow_WC_Widget_Recent_Reviews extends WC_Widget_Recent_Reviews {

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->widget_cssclass    = 'woocommerce widget_recent_reviews';
		$this->widget_description = esc_html__( 'Display a list of recent reviews from your store.', 'infinito-woocommerce' );
		$this->widget_id          = 'woocommerce_recent_reviews';
		$this->widget_name        = esc_html__( 'Recent Product Reviews', 'infinito-woocommerce' );
		$this->settings           = array(
			'title'  => array(
				'type'  => 'text',
				'std'   => esc_html__( 'Recent reviews', 'infinito-woocommerce' ),
				'label' => esc_html__( 'Title', 'infinito-woocommerce' ),
			),
			'number' => array(
				'type'  => 'number',
				'step'  => 1,
				'min'   => 1,
				'max'   => '',
				'std'   => 10,
				'label' => esc_html__( 'Number of reviews to show', 'infinito-woocommerce' ),
			),
		);

		parent::__construct();
	}

	/**
	 * Output widget.
	 *
	 * @see WP_Widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	 public function widget( $args, $instance ) {
		global $comments, $comment;

		if ( $this->get_cached_widget( $args ) ) {
			return;
		}

		ob_start();

		$number   = ! empty( $instance['number'] ) ? absint( $instance['number'] ) : $this->settings['number']['std'];
		$comments = get_comments( array( 'number' => $number, 'status' => 'approve', 'post_status' => 'publish', 'post_type' => 'product', 'parent' => 0 ) );

		if ( $comments ) {
			$this->widget_start( $args, $instance );

			echo '<ul class="product_list_widget">';

			foreach ( (array) $comments as $comment ) {

				$_product = wc_get_product( $comment->comment_post_ID );

				$rating = intval( get_comment_meta( $comment->comment_ID, 'rating', true ) );

				$rating_html = wc_get_rating_html( $rating );
				echo '<li><div class="image-holder">'.wp_kses($_product->get_image() , array('img' => array('src' => array(),'class' => array(),'alt' => array(),'width' => array(),'height' => array(),'srcset' => array(),'sizes' => array()))).'</div>';				
				echo '<div class="details-holder"><a href="' . esc_url( get_comment_link( $comment->comment_ID ) ) . '">' . esc_html( $_product->get_name() ) . '</a>';
				echo wp_kses($rating_html , array('div' => array('class' => array()),'span' => array('style' => array()),'strong' => array('class' => array()) ));

				/* translators: %s: review author */
				echo '<span class="reviewer">' . sprintf( esc_html__( 'by %s', 'infinito-woocommerce' ), get_comment_author() ) . '</span>';

				echo '</div></li>';
			}

			echo '</ul>';

			$this->widget_end( $args );
		}
				
		$content = ob_get_clean();
		echo $content; //$content doesn't need to be escaped as it is done above

		$this->cache_widget( $args, $content );
	}
}
